pub struct AccountCustomFieldCreate {
pub json: Option<bool>,
pub name: String,
pub object: String,
pub object_type: String,
pub required: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
AccountCustomFieldCreate : accountCustomFieldCreate is a command that creates a new custom field in the account settings
Fields
json: Option<bool>Set output format to JSON
name: StringThe name of the custom field
object: StringThe object to create the custom field
object_type: StringThe object type to create the custom field [e.g. STATIC_SECRET,DYNAMIC_SECRET,ROTATED_SECRET]
required: Option<bool>Specify whether the custom field is mandatory
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations