pub struct AccountCustomFieldDelete {
pub id: i64,
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
AccountCustomFieldDelete : accountCustomFieldDelete is a command that deletes an account custom field
Fields
id: i64The custom field id
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl AccountCustomFieldDelete
impl AccountCustomFieldDelete
Sourcepub fn new(id: i64) -> AccountCustomFieldDelete
pub fn new(id: i64) -> AccountCustomFieldDelete
accountCustomFieldDelete is a command that deletes an account custom field