pub struct AccountCustomFieldGet {
pub id: i64,
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
AccountCustomFieldGet : accountCustomFieldGet is a command that retrieves an account custom field
Fields
id: i64The custom field id
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl AccountCustomFieldGet
impl AccountCustomFieldGet
Sourcepub fn new(id: i64) -> AccountCustomFieldGet
pub fn new(id: i64) -> AccountCustomFieldGet
accountCustomFieldGet is a command that retrieves an account custom field