pub struct AccountCustomFieldList {
pub json: Option<bool>,
pub object: Option<String>,
pub object_type: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
AccountCustomFieldList : accountCustomFieldList is a command that retrieves the account custom fields
Fields
json: Option<bool>Set output format to JSON
object: Option<String>The object to filter by the custom fields in: body
object_type: Option<String>The object type to filter by the custom fields in: body
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl AccountCustomFieldList
impl AccountCustomFieldList
Sourcepub fn new() -> AccountCustomFieldList
pub fn new() -> AccountCustomFieldList
accountCustomFieldList is a command that retrieves the account custom fields