pub struct AccountCustomFieldUpdate {
pub id: i64,
pub json: Option<bool>,
pub name: Option<String>,
pub required: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
AccountCustomFieldUpdate : accountCustomFieldUpdate is a command to update an account custom field
Fields
id: i64The custom field id
json: Option<bool>Set output format to JSON
name: Option<String>The new name of the custom field
required: Option<bool>Specify whether the custom field is mandatory
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl AccountCustomFieldUpdate
impl AccountCustomFieldUpdate
Sourcepub fn new(id: i64) -> AccountCustomFieldUpdate
pub fn new(id: i64) -> AccountCustomFieldUpdate
accountCustomFieldUpdate is a command to update an account custom field