pub struct AssocRoleAuthMethod {
pub am_name: String,
pub case_sensitive: Option<String>,
pub json: Option<bool>,
pub role_name: String,
pub sub_claims: Option<HashMap<String, String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
AssocRoleAuthMethod : assocRoleAuthMethod is a command that creates an association between role and auth method.
Fields
am_name: StringThe auth method to associate
case_sensitive: Option<String>Treat sub claims as case-sensitive [true/false]
json: Option<bool>Set output format to JSON
role_name: StringThe role to associate
sub_claims: Option<HashMap<String, String>>key/val of sub claims, e.g group=admins,developers
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl AssocRoleAuthMethod
impl AssocRoleAuthMethod
Sourcepub fn new(am_name: String, role_name: String) -> AssocRoleAuthMethod
pub fn new(am_name: String, role_name: String) -> AssocRoleAuthMethod
assocRoleAuthMethod is a command that creates an association between role and auth method.