AssocTargetItem

Struct AssocTargetItem 

pub struct AssocTargetItem {
Show 23 fields pub certificate_path: Option<String>, pub chain_path: Option<String>, pub disable_previous_key_version: Option<bool>, pub external_key_name: Option<String>, pub json: Option<bool>, pub key_operations: Option<Vec<String>>, pub keyring_name: Option<String>, pub kms_algorithm: Option<String>, pub location_id: Option<String>, pub multi_region: Option<String>, pub name: String, pub post_provision_command: Option<String>, pub private_key_path: Option<String>, pub project_id: Option<String>, pub protection_level: Option<String>, pub purpose: Option<String>, pub regions: Option<Vec<String>>, pub sra_association: Option<bool>, pub target_name: String, pub tenant_secret_type: Option<String>, pub token: Option<String>, pub uid_token: Option<String>, pub vault_name: Option<String>,
}
AssocTargetItem : assocTargetItem is a command that creates an association between target and item.

Fields

certificate_path: Option<String>

A path on the target to store the certificate pem file (relevant only for certificate provisioning)

chain_path: Option<String>

A path on the target to store the full chain pem file (relevant only for certificate provisioning)

disable_previous_key_version: Option<bool>

Automatically disable previous key version (required for azure targets)

external_key_name: Option<String>

The external key name to associate with the classic key (Relevant only for Classic Key AWS/Azure/GCP targets)

json: Option<bool>

Set output format to JSON

key_operations: Option<Vec<String>>

A list of allowed operations for the key (required for azure targets)

keyring_name: Option<String>

Keyring name of the GCP KMS (required for gcp targets)

kms_algorithm: Option<String>

Algorithm of the key in GCP KMS (required for gcp targets)

location_id: Option<String>

Location id of the GCP KMS (required for gcp targets)

multi_region: Option<String>

Set to ‘true’ to create a multi-region managed key. (Relevant only for Classic Key AWS targets)

name: String

The item to associate

post_provision_command: Option<String>

A custom command to run on the remote target after successful provisioning (relevant only for certificate provisioning)

private_key_path: Option<String>

A path on the target to store the private key (relevant only for certificate provisioning)

project_id: Option<String>

Project id of the GCP KMS (required for gcp targets)

protection_level: Option<String>

Protection level of the key [software/hardware] (relevant for gcp targets)

purpose: Option<String>

Purpose of the key in GCP KMS (required for gcp targets)

regions: Option<Vec<String>>

The list of regions to create a copy of the key in (relevant for aws targets)

sra_association: Option<bool>

Is the target to associate is for sra, relevant only for linked target association for ldap rotated secret

target_name: String

The target to associate

tenant_secret_type: Option<String>

The tenant secret type [Data/SearchIndex/Analytics] (required for salesforce targets)

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

vault_name: Option<String>

Name of the vault used (required for azure targets)

Implementations

Source

impl AssocTargetItem

pub fn new(name: String, target_name: String) -> AssocTargetItem

assocTargetItem is a command that creates an association between target and item.