Module auth_method_create_aws_iam

Module auth_method_create_aws_iam 

Structs

AuthMethodCreateAwsIam
AuthMethodCreateAwsIam : authMethodCreateAwsIam is a command that creates a new Auth Method that will be able to authenticate using AWS IAM credentials.