AuthMethodCreateAwsIam

Struct AuthMethodCreateAwsIam 

pub struct AuthMethodCreateAwsIam {
Show 24 fields pub access_expires: Option<i64>, pub allowed_client_type: Option<Vec<String>>, pub audit_logs_claims: Option<Vec<String>>, pub bound_arn: Option<Vec<String>>, pub bound_aws_account_id: Vec<String>, pub bound_ips: Option<Vec<String>>, pub bound_resource_id: Option<Vec<String>>, pub bound_role_id: Option<Vec<String>>, pub bound_role_name: Option<Vec<String>>, pub bound_user_id: Option<Vec<String>>, pub bound_user_name: Option<Vec<String>>, pub delete_protection: Option<String>, pub description: Option<String>, pub expiration_event_in: Option<Vec<String>>, pub force_sub_claims: Option<bool>, pub gw_bound_ips: Option<Vec<String>>, pub json: Option<bool>, pub jwt_ttl: Option<i64>, pub name: String, pub product_type: Option<Vec<String>>, pub sts_url: Option<String>, pub token: Option<String>, pub uid_token: Option<String>, pub unique_identifier: Option<String>,
}
AuthMethodCreateAwsIam : authMethodCreateAwsIam is a command that creates a new Auth Method that will be able to authenticate using AWS IAM credentials.

Fields

access_expires: Option<i64>

Access expiration date in Unix timestamp (select 0 for access without expiry date)

allowed_client_type: Option<Vec<String>>

limit the auth method usage for specific client types [cli,ui,gateway-admin,sdk,mobile,extension]

audit_logs_claims: Option<Vec<String>>

Subclaims to include in audit logs, e.g "–audit-logs-claims email –audit-logs-claims username"

bound_arn: Option<Vec<String>>

A list of full arns that the access is restricted to

bound_aws_account_id: Vec<String>

A list of AWS account-IDs that the access is restricted to

bound_ips: Option<Vec<String>>

A CIDR whitelist with the IPs that the access is restricted to

bound_resource_id: Option<Vec<String>>

A list of full resource ids that the access is restricted to

bound_role_id: Option<Vec<String>>

A list of full role ids that the access is restricted to

bound_role_name: Option<Vec<String>>

A list of full role-name that the access is restricted to

bound_user_id: Option<Vec<String>>

A list of full user ids that the access is restricted to

bound_user_name: Option<Vec<String>>

A list of full user-name that the access is restricted to

delete_protection: Option<String>

Protection from accidental deletion of this object [true/false]

description: Option<String>

Auth Method description

expiration_event_in: Option<Vec<String>>

How many days before the expiration of the auth method would you like to be notified.

force_sub_claims: Option<bool>

if true: enforce role-association must include sub claims

gw_bound_ips: Option<Vec<String>>

A CIDR whitelist with the GW IPs that the access is restricted to

json: Option<bool>

Set output format to JSON

jwt_ttl: Option<i64>

Jwt TTL

name: String

Auth Method name

product_type: Option<Vec<String>>

Choose the relevant product type for the auth method [sm, sra, pm, dp, ca]

sts_url: Option<String>

sts URL

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

unique_identifier: Option<String>

A unique identifier (ID) value which is a "sub claim" name that contains details uniquely identifying that resource. This "sub claim" is used to distinguish between different identities.

Implementations

Source

impl AuthMethodCreateAwsIam

pub fn new( bound_aws_account_id: Vec<String>, name: String, ) -> AuthMethodCreateAwsIam

authMethodCreateAwsIam is a command that creates a new Auth Method that will be able to authenticate using AWS IAM credentials.