Module auth_method_create_azure_ad

Module auth_method_create_azure_ad 

Structs

AuthMethodCreateAzureAd
AuthMethodCreateAzureAd : authMethodCreateAzureAD is a command that creates a new auth method that will be able to authenticate using Azure Active Directory credentials.