Module auth_method_create_cert

Module auth_method_create_cert 

Structs

AuthMethodCreateCert
AuthMethodCreateCert : authMethodCreateCert is a command that creates a new auth method that will be able to authenticate using a client certificate