Module auth_method_create_email

Module auth_method_create_email 

Structs

AuthMethodCreateEmail
AuthMethodCreateEmail : authMethodCreateEmail is a command that creates a new auth method that will be able to authenticate using email.