Module auth_method_create_k8s

Module auth_method_create_k8s 

Structs

AuthMethodCreateK8s
AuthMethodCreateK8s : authMethodCreateK8s is a command that creates a new auth method that will be able to authenticate using K8S.