Module auth_method_create_kerberos

Module auth_method_create_kerberos 

Structs

AuthMethodCreateKerberos
AuthMethodCreateKerberos : authMethodCreateKerberos is a command that creates a new auth method that will be able to authenticate using Kerberos