pub struct AuthMethodCreateKerberos {Show 31 fields
pub access_expires: Option<i64>,
pub allowed_client_type: Option<Vec<String>>,
pub audit_logs_claims: Option<Vec<String>>,
pub bind_dn: Option<String>,
pub bind_dn_password: Option<String>,
pub bound_ips: Option<Vec<String>>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub force_sub_claims: Option<bool>,
pub group_attr: Option<String>,
pub group_dn: Option<String>,
pub group_filter: Option<String>,
pub gw_bound_ips: Option<Vec<String>>,
pub json: Option<bool>,
pub jwt_ttl: Option<i64>,
pub keytab_file_data: Option<String>,
pub keytab_file_path: Option<String>,
pub krb5_conf_data: Option<String>,
pub krb5_conf_path: Option<String>,
pub ldap_anonymous_search: Option<bool>,
pub ldap_ca_cert: Option<String>,
pub ldap_url: Option<String>,
pub name: String,
pub product_type: Option<Vec<String>>,
pub subclaims_delimiters: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub unique_identifier: Option<String>,
pub user_attribute: Option<String>,
pub user_dn: Option<String>,
}Expand description
AuthMethodCreateKerberos : authMethodCreateKerberos is a command that creates a new auth method that will be able to authenticate using Kerberos
Fields
access_expires: Option<i64>Access expiration date in Unix timestamp (select 0 for access without expiry date)
allowed_client_type: Option<Vec<String>>limit the auth method usage for specific client types [cli,ui,gateway-admin,sdk,mobile,extension]
audit_logs_claims: Option<Vec<String>>Subclaims to include in audit logs, e.g "–audit-logs-claims email –audit-logs-claims username"
bind_dn: Option<String>bind_dn_password: Option<String>bound_ips: Option<Vec<String>>A CIDR whitelist with the IPs that the access is restricted to
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Auth Method description
expiration_event_in: Option<Vec<String>>How many days before the expiration of the auth method would you like to be notified.
force_sub_claims: Option<bool>if true: enforce role-association must include sub claims
group_attr: Option<String>group_dn: Option<String>group_filter: Option<String>gw_bound_ips: Option<Vec<String>>A CIDR whitelist with the GW IPs that the access is restricted to
json: Option<bool>Set output format to JSON
jwt_ttl: Option<i64>Jwt TTL
keytab_file_data: Option<String>keytab_file_path: Option<String>krb5_conf_data: Option<String>krb5_conf_path: Option<String>ldap_anonymous_search: Option<bool>ldap_ca_cert: Option<String>ldap_url: Option<String>name: StringAuth Method name
product_type: Option<Vec<String>>Choose the relevant product type for the auth method [sm, sra, pm, dp, ca]
subclaims_delimiters: Option<Vec<String>>A list of additional sub claims delimiters (relevant only for SAML, OIDC, OAuth2/JWT)
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
unique_identifier: Option<String>A unique identifier (ID) value which is a "sub claim" name that contains details uniquely identifying that resource. This "sub claim" is used to distinguish between different identities.
user_attribute: Option<String>user_dn: Option<String>Implementations
Sourceimpl AuthMethodCreateKerberos
impl AuthMethodCreateKerberos
Sourcepub fn new(name: String) -> AuthMethodCreateKerberos
pub fn new(name: String) -> AuthMethodCreateKerberos
authMethodCreateKerberos is a command that creates a new auth method that will be able to authenticate using Kerberos