Module auth_method_create_ldap

Module auth_method_create_ldap 

Structs

AuthMethodCreateLdap
AuthMethodCreateLdap : authMethodCreateLdap is a command that creates a new auth method that will be able to authenticate using LDAP.