Module auth_method_create_oauth2

Module auth_method_create_oauth2 

Structs

AuthMethodCreateOauth2
AuthMethodCreateOauth2 : authMethodCreateOauth2 is a command that creates a new auth method that will be able to authenticate using Oauth2.