Module auth_method_create_oci

Module auth_method_create_oci 

Structs

AuthMethodCreateOci
AuthMethodCreateOci : authMethodCreateOCI is a command that creates a new Oracle Auth Method that will be used in the account using OCI principle and groups.