Module auth_method_create_oidc

Module auth_method_create_oidc 

Structs

AuthMethodCreateOidc
AuthMethodCreateOidc : authMethodCreateOIDC is a command that creates a new auth method that will be available to authenticate using OIDC.