pub struct AuthMethodCreateOidc {Show 24 fields
pub access_expires: Option<i64>,
pub allowed_client_type: Option<Vec<String>>,
pub allowed_redirect_uri: Option<Vec<String>>,
pub audience: Option<String>,
pub audit_logs_claims: Option<Vec<String>>,
pub bound_ips: Option<Vec<String>>,
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub force_sub_claims: Option<bool>,
pub gw_bound_ips: Option<Vec<String>>,
pub issuer: Option<String>,
pub json: Option<bool>,
pub jwt_ttl: Option<i64>,
pub name: String,
pub product_type: Option<Vec<String>>,
pub required_scopes: Option<Vec<String>>,
pub required_scopes_prefix: Option<String>,
pub subclaims_delimiters: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub unique_identifier: String,
}Expand description
AuthMethodCreateOidc : authMethodCreateOIDC is a command that creates a new auth method that will be available to authenticate using OIDC.
Fields
access_expires: Option<i64>Access expiration date in Unix timestamp (select 0 for access without expiry date)
allowed_client_type: Option<Vec<String>>limit the auth method usage for specific client types [cli,ui,gateway-admin,sdk,mobile,extension]
allowed_redirect_uri: Option<Vec<String>>Allowed redirect URIs after the authentication
audience: Option<String>Audience claim to be used as part of the authentication flow. In case set, it must match the one configured on the Identity Provider’s Application
audit_logs_claims: Option<Vec<String>>Subclaims to include in audit logs, e.g "–audit-logs-claims email –audit-logs-claims username"
bound_ips: Option<Vec<String>>A CIDR whitelist with the IPs that the access is restricted to
client_id: Option<String>Client ID
client_secret: Option<String>Client Secret
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Auth Method description
expiration_event_in: Option<Vec<String>>How many days before the expiration of the auth method would you like to be notified.
force_sub_claims: Option<bool>if true: enforce role-association must include sub claims
gw_bound_ips: Option<Vec<String>>A CIDR whitelist with the GW IPs that the access is restricted to
issuer: Option<String>Issuer URL
json: Option<bool>Set output format to JSON
jwt_ttl: Option<i64>Jwt TTL
name: StringAuth Method name
product_type: Option<Vec<String>>Choose the relevant product type for the auth method [sm, sra, pm, dp, ca]
required_scopes: Option<Vec<String>>RequiredScopes is a list of required scopes that the oidc method will request from the oidc provider and the user must approve
required_scopes_prefix: Option<String>RequiredScopesPrefix is a a prefix to add to all required-scopes when requesting them from the oidc server (for example, azures’ Application ID URI)
subclaims_delimiters: Option<Vec<String>>A list of additional sub claims delimiters (relevant only for SAML, OIDC, OAuth2/JWT)
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
unique_identifier: StringA unique identifier (ID) value should be configured for OIDC, OAuth2, LDAP and SAML authentication method types and is usually a value such as the email, username, or upn for example. Whenever a user logs in with a token, these authentication types issue a "sub claim" that contains details uniquely identifying that user. This sub claim includes a key containing the ID value that you configured, and is used to distinguish between different users from within the same organization.
Implementations
Sourceimpl AuthMethodCreateOidc
impl AuthMethodCreateOidc
Sourcepub fn new(name: String, unique_identifier: String) -> AuthMethodCreateOidc
pub fn new(name: String, unique_identifier: String) -> AuthMethodCreateOidc
authMethodCreateOIDC is a command that creates a new auth method that will be available to authenticate using OIDC.