Module auth_method_create_saml

Module auth_method_create_saml 

Structs

AuthMethodCreateSaml
AuthMethodCreateSaml : authMethodCreateSAML is a command that creates a new auth method that will be available to authenticate using SAML.