Module auth_method_create_universal_identity

Module auth_method_create_universal_identity 

Structs

AuthMethodCreateUniversalIdentity
AuthMethodCreateUniversalIdentity : authMethodCreateUniversalIdentity is a command that creates a new auth method that will be able to authenticate using Akeyless Universal Identity.