pub struct AuthMethodList {
pub filter: Option<String>,
pub json: Option<bool>,
pub pagination_token: Option<String>,
pub token: Option<String>,
pub type: Option<Vec<String>>,
pub uid_token: Option<String>,
}Expand description
AuthMethodList : authMethodList is a command that returns a list of auth methods
Fields
filter: Option<String>Filter by auth method name or part of it
json: Option<bool>Set output format to JSON
pagination_token: Option<String>Next page reference
token: Option<String>Authentication token (see /auth and /configure)
type: Option<Vec<String>>The Auth method types list of the requested method. In case it is empty, all types of auth methods will be returned. options: [api_key, azure_ad, oauth2/jwt, saml2, ldap, aws_iam, oidc, universal_identity, gcp, k8s, cert]
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl AuthMethodList
impl AuthMethodList
Sourcepub fn new() -> AuthMethodList
pub fn new() -> AuthMethodList
authMethodList is a command that returns a list of auth methods