pub struct AuthMethodRoleAssociation {
pub allowed_ops: Option<Vec<String>>,
pub assoc_id: Option<String>,
pub auth_method_sub_claims: Option<HashMap<String, Vec<String>>>,
pub is_sub_claims_case_sensitive: Option<bool>,
pub is_subclaims_with_operator: Option<bool>,
pub role_id: Option<i64>,
pub role_name: Option<String>,
pub rules: Option<Box<Rules>>,
}Expand description
AuthMethodRoleAssociation : AuthMethodRoleAssociation includes details of an association between an auth method and a role.
Fields
allowed_ops: Option<Vec<String>>assoc_id: Option<String>auth_method_sub_claims: Option<HashMap<String, Vec<String>>>is_sub_claims_case_sensitive: Option<bool>is_subclaims_with_operator: Option<bool>role_id: Option<i64>role_name: Option<String>rules: Option<Box<Rules>>Implementations
Sourceimpl AuthMethodRoleAssociation
impl AuthMethodRoleAssociation
Sourcepub fn new() -> AuthMethodRoleAssociation
pub fn new() -> AuthMethodRoleAssociation
AuthMethodRoleAssociation includes details of an association between an auth method and a role.