Module auth_method_update_aws_iam

Module auth_method_update_aws_iam 

Structs

AuthMethodUpdateAwsIam
AuthMethodUpdateAwsIam : authMethodUpdateAwsIam is a command that Updates a new Auth Method that will be able to authenticate using AWS IAM credentials.