Module auth_method_update_azure_ad

Module auth_method_update_azure_ad 

Structs

AuthMethodUpdateAzureAd
AuthMethodUpdateAzureAd : authMethodUpdateAzureAD is a command that updates a new auth method that will be able to authenticate using Azure Active Directory credentials.