Module auth_method_update_cert

Module auth_method_update_cert 

Structs

AuthMethodUpdateCert
AuthMethodUpdateCert : authMethodUpdateCert is a command that updates a new auth method that will be able to authenticate using a client certificate