Module auth_method_update_k8s

Module auth_method_update_k8s 

Structs

AuthMethodUpdateK8s
AuthMethodUpdateK8s : authMethodUpdateK8s is a command that updates a new auth method that will be able to authenticate using K8S.