Module auth_method_update_kerberos

Module auth_method_update_kerberos 

Structs

AuthMethodUpdateKerberos
AuthMethodUpdateKerberos : authMethodUpdateKerberos is a command that updates an auth method that will be able to authenticate using Kerberos