Module auth_method_update_ldap

Module auth_method_update_ldap 

Structs

AuthMethodUpdateLdap
AuthMethodUpdateLdap : authMethodUpdateLdap is a command that updates a new auth method that will be able to authenticate using LDAP.