Module auth_method_update_oauth2

Module auth_method_update_oauth2 

Structs

AuthMethodUpdateOauth2
AuthMethodUpdateOauth2 : authMethodUpdateOauth2 is a command that updates a new auth method that will be able to authenticate using Oauth2.