AuthMethodUpdateOauth2

Struct AuthMethodUpdateOauth2 

pub struct AuthMethodUpdateOauth2 {
Show 26 fields pub access_expires: Option<i64>, pub allowed_client_type: Option<Vec<String>>, pub audience: Option<String>, pub audit_logs_claims: Option<Vec<String>>, pub bound_client_ids: Option<Vec<String>>, pub bound_ips: Option<Vec<String>>, pub cert: Option<String>, pub cert_file_data: Option<String>, pub delete_protection: Option<String>, pub description: Option<String>, pub expiration_event_in: Option<Vec<String>>, pub force_sub_claims: Option<bool>, pub gateway_url: Option<String>, pub gw_bound_ips: Option<Vec<String>>, pub issuer: Option<String>, pub json: Option<bool>, pub jwks_json_data: Option<String>, pub jwks_uri: Option<String>, pub jwt_ttl: Option<i64>, pub name: String, pub new_name: Option<String>, pub product_type: Option<Vec<String>>, pub subclaims_delimiters: Option<Vec<String>>, pub token: Option<String>, pub uid_token: Option<String>, pub unique_identifier: String,
}
AuthMethodUpdateOauth2 : authMethodUpdateOauth2 is a command that updates a new auth method that will be able to authenticate using Oauth2.

Fields

access_expires: Option<i64>

Access expiration date in Unix timestamp (select 0 for access without expiry date)

allowed_client_type: Option<Vec<String>>

limit the auth method usage for specific client types [cli,ui,gateway-admin,sdk,mobile,extension]

audience: Option<String>

The audience in the JWT

audit_logs_claims: Option<Vec<String>>

Subclaims to include in audit logs, e.g "–audit-logs-claims email –audit-logs-claims username"

bound_client_ids: Option<Vec<String>>

The clients ids that the access is restricted to

bound_ips: Option<Vec<String>>

A CIDR whitelist with the IPs that the access is restricted to

cert: Option<String>

CertificateFile Path to a file that contain the certificate in a PEM format.

cert_file_data: Option<String>

CertificateFileData PEM Certificate in a Base64 format.

delete_protection: Option<String>

Protection from accidental deletion of this object [true/false]

description: Option<String>

Auth Method description

expiration_event_in: Option<Vec<String>>

How many days before the expiration of the auth method would you like to be notified.

force_sub_claims: Option<bool>

if true: enforce role-association must include sub claims

gateway_url: Option<String>

Akeyless Gateway URL (Configuration Management port). Relevant only when the jwks-uri is accessible only from the gateway.

gw_bound_ips: Option<Vec<String>>

A CIDR whitelist with the GW IPs that the access is restricted to

issuer: Option<String>

Issuer URL

json: Option<bool>

Set output format to JSON

jwks_json_data: Option<String>

The JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server. base64 encoded string

jwks_uri: Option<String>

The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.

jwt_ttl: Option<i64>

Jwt TTL

name: String

Auth Method name

new_name: Option<String>

Auth Method new name

product_type: Option<Vec<String>>

Choose the relevant product type for the auth method [sm, sra, pm, dp, ca]

subclaims_delimiters: Option<Vec<String>>

A list of additional sub claims delimiters (relevant only for SAML, OIDC, OAuth2/JWT)

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

unique_identifier: String

A unique identifier (ID) value should be configured for OAuth2, LDAP and SAML authentication method types and is usually a value such as the email, username, or upn for example. Whenever a user logs in with a token, these authentication types issue a "sub claim" that contains details uniquely identifying that user. This sub claim includes a key containing the ID value that you configured, and is used to distinguish between different users from within the same organization.

Implementations

Source

impl AuthMethodUpdateOauth2

pub fn new(name: String, unique_identifier: String) -> AuthMethodUpdateOauth2

authMethodUpdateOauth2 is a command that updates a new auth method that will be able to authenticate using Oauth2.