Module auth_method_update_oci

Module auth_method_update_oci 

Structs

AuthMethodUpdateOci
AuthMethodUpdateOci : authMethodUpdateOCI is a command that updates an auth method that will be used in the account using OCI principle and groups.