Module auth_method_update_oidc

Module auth_method_update_oidc 

Structs

AuthMethodUpdateOidc
AuthMethodUpdateOidc : authMethodUpdateOIDC is a command that updates a new auth method that will be available to authenticate using OIDC.