Module auth_method_update_saml

Module auth_method_update_saml 

Structs

AuthMethodUpdateSaml
AuthMethodUpdateSaml : authMethodUpdateSAML is a command that updates a new auth method that will be available to authenticate using SAML.