Module auth_method_update_universal_identity

Module auth_method_update_universal_identity 

Structs

AuthMethodUpdateUniversalIdentity
AuthMethodUpdateUniversalIdentity : authMethodUpdateUniversalIdentity is a command that updates a new auth method that will be able to authenticate using Akeyless Universal Identity.