pub struct AwsiamAccessRules {
pub account_id: Option<Vec<String>>,
pub arn: Option<Vec<String>>,
pub resource_id: Option<Vec<String>>,
pub role_id: Option<Vec<String>>,
pub role_name: Option<Vec<String>>,
pub sts_endpoint: Option<String>,
pub unique_identifier: Option<String>,
pub user_id: Option<Vec<String>>,
pub user_name: Option<Vec<String>>,
}Fields
account_id: Option<Vec<String>>The list of account ids that the login is restricted to.
arn: Option<Vec<String>>The list of ARNs that the login is restricted to.
resource_id: Option<Vec<String>>The list of resource ids that the login is restricted to.
role_id: Option<Vec<String>>The list of role ids that the login is restricted to.
role_name: Option<Vec<String>>The list of role names that the login is restricted to.
sts_endpoint: Option<String>The sts URL.
unique_identifier: Option<String>A unique identifier to distinguish different users
user_id: Option<Vec<String>>The list of user ids that the login is restricted to.
user_name: Option<Vec<String>>The list of user names that the login is restricted to.
Implementations
Sourceimpl AwsiamAccessRules
impl AwsiamAccessRules
pub fn new() -> AwsiamAccessRules