AzureAdAccessRules

Struct AzureAdAccessRules 

pub struct AzureAdAccessRules {
Show 14 fields pub ad_endpoint: Option<String>, pub azure_cloud: Option<String>, pub bound_group_ids: Option<Vec<String>>, pub bound_resource_groups: Option<Vec<String>>, pub bound_resource_ids: Option<Vec<String>>, pub bound_resource_names: Option<Vec<String>>, pub bound_resource_providers: Option<Vec<String>>, pub bound_resource_types: Option<Vec<String>>, pub bound_service_principal_ids: Option<Vec<String>>, pub bound_subscription_ids: Option<Vec<String>>, pub bound_tenant_id: Option<String>, pub issuer: Option<String>, pub jwks_uri: Option<String>, pub unique_identifier: Option<String>,
}
AzureAdAccessRules : AzureADAccessRules contains access rules specific to Azure Active Directory authentication.

Fields

ad_endpoint: Option<String>

The audience in the JWT.

azure_cloud: Option<String>

Azure cloud environment [AzureCloud/AzureUSGovernment/AzureChinaCloud]. For create/update, cloud is inferred from jwks_uri.

bound_group_ids: Option<Vec<String>>

The list of group ids that login is restricted to.

bound_resource_groups: Option<Vec<String>>

The list of resource groups that login is restricted to.

bound_resource_ids: Option<Vec<String>>

The list of full resource ids that the login is restricted to.

bound_resource_names: Option<Vec<String>>

The list of resource names that the login is restricted to (e.g, a virtual machine name, scale set name, etc).

bound_resource_providers: Option<Vec<String>>

The list of resource providers that login is restricted to (e.g, Microsoft.Compute, Microsoft.ManagedIdentity, etc).

bound_resource_types: Option<Vec<String>>

The list of resource types that login is restricted to (e.g, virtualMachines, userAssignedIdentities, etc).

bound_service_principal_ids: Option<Vec<String>>

The list of service principal IDs that login is restricted to.

bound_subscription_ids: Option<Vec<String>>

The list of subscription IDs that login is restricted to.

bound_tenant_id: Option<String>

The tenants id for the Azure Active Directory organization.

issuer: Option<String>

Issuer URL

jwks_uri: Option<String>

The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.

unique_identifier: Option<String>

A unique identifier to distinguish different users

Implementations

Source

impl AzureAdAccessRules

pub fn new() -> AzureAdAccessRules

AzureADAccessRules contains access rules specific to Azure Active Directory authentication.