Configure

Struct Configure 

pub struct Configure {
Show 25 fields pub access_id: Option<String>, pub access_key: Option<String>, pub access_type: Option<String>, pub account_id: Option<String>, pub admin_email: Option<String>, pub admin_password: Option<String>, pub azure_ad_object_id: Option<String>, pub azure_cloud: Option<String>, pub cert_data: Option<String>, pub cert_issuer_name: Option<String>, pub cert_username: Option<String>, pub default_location_prefix: Option<String>, pub disable_pafxfast: Option<String>, pub gateway_spn: Option<String>, pub gcp_audience: Option<String>, pub json: Option<bool>, pub k8s_auth_config_name: Option<String>, pub kerberos_token: Option<String>, pub kerberos_username: Option<String>, pub key_data: Option<String>, pub keytab_data: Option<String>, pub krb5_conf_data: Option<String>, pub legacy_signing_alg_name: Option<bool>, pub oci_auth_type: Option<String>, pub oci_group_ocid: Option<Vec<String>>,
}

Fields

access_id: Option<String>

Access ID

access_key: Option<String>

Access Key

access_type: Option<String>

Access Type (access_key/password/azure_ad/saml/oidc/aws_iam/gcp/k8s/cert)

account_id: Option<String>

Account id (relevant only for access-type=password where the email address is associated with more than one account)

admin_email: Option<String>

Email (relevant only for access-type=password)

admin_password: Option<String>

Password (relevant only for access-type=password)

azure_ad_object_id: Option<String>

Azure Active Directory ObjectId (relevant only for access-type=azure_ad)

azure_cloud: Option<String>

Azure cloud environment to use. Values: AzureCloud (default), AzureUSGovernment, AzureChinaCloud.

cert_data: Option<String>

Certificate data encoded in base64. Used if file was not provided. (relevant only for access-type=cert in Curl Context)

cert_issuer_name: Option<String>

Certificate Issuer Name

cert_username: Option<String>

The username to sign in the SSH certificate (use a comma-separated list for more than one username)

default_location_prefix: Option<String>

Default path prefix for name of items, targets and auth methods

disable_pafxfast: Option<String>

Disable the FAST negotiation in the Kerberos authentication method

gateway_spn: Option<String>

The service principal name of the gateway as registered in LDAP (i.e., HTTP/gateway)

gcp_audience: Option<String>

GCP JWT audience

json: Option<bool>

Set output format to JSON

k8s_auth_config_name: Option<String>

The K8S Auth config name (relevant only for access-type=k8s)

kerberos_token: Option<String>

KerberosToken represents a Kerberos token generated for the gateway SPN (Service Principal Name).

kerberos_username: Option<String>

TThe username for the entry within the keytab to authenticate via Kerberos

key_data: Option<String>

Private key data encoded in base64. Used if file was not provided.(relevant only for access-type=cert in Curl Context)

keytab_data: Option<String>

Base64-encoded content of a valid keytab file, containing the service account’s entry.

krb5_conf_data: Option<String>

Base64-encoded content of a valid krb5.conf file, specifying the settings and parameters required for Kerberos authentication.

legacy_signing_alg_name: Option<bool>

Set this option to output legacy (‘ssh-rsa-cert-v01@openssh.com’) signing algorithm name in the certificate.

oci_auth_type: Option<String>

The type of the OCI configuration to use [instance/apikey/resource] (relevant only for access-type=oci)

oci_group_ocid: Option<Vec<String>>

A list of Oracle Cloud IDs groups (relevant only for access-type=oci)

Implementations