pub struct CreateArtifactoryTarget {
pub artifactory_admin_name: String,
pub artifactory_admin_pwd: String,
pub base_url: String,
pub comment: Option<String>,
pub description: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
CreateArtifactoryTarget : createArtifactoryTarget is a command that creates a new target. [Deprecated: Use target-create-artifactory command]
Fields
artifactory_admin_name: StringArtifactory Admin Name
artifactory_admin_pwd: StringArtifactory Admin password
base_url: StringBase URL
comment: Option<String>Deprecated - use description
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations