Module create_auth_method_awsiam

Module create_auth_method_awsiam 

Structs

CreateAuthMethodAwsiam
CreateAuthMethodAwsiam : createAuthMethodAWSIAM is a command that creates a new Auth Method that will be able to authenticate using AWS IAM credentials. [Deprecated: Use auth-method-create-aws-iam command]