Module create_auth_method_azure_ad

Module create_auth_method_azure_ad 

Structs

CreateAuthMethodAzureAd
CreateAuthMethodAzureAd : createAuthMethodAzureAD is a command that creates a new auth method that will be able to authenticate using Azure Active Directory credentials. [Deprecated: Use auth-method-create-azure-ad command]