CreateAuthMethodAzureAd

Struct CreateAuthMethodAzureAd 

pub struct CreateAuthMethodAzureAd {
Show 28 fields pub access_expires: Option<i64>, pub allowed_client_type: Option<Vec<String>>, pub audience: Option<String>, pub audit_logs_claims: Option<Vec<String>>, pub bound_group_id: Option<Vec<String>>, pub bound_ips: Option<Vec<String>>, pub bound_providers: Option<Vec<String>>, pub bound_resource_id: Option<Vec<String>>, pub bound_resource_names: Option<Vec<String>>, pub bound_resource_types: Option<Vec<String>>, pub bound_rg_id: Option<Vec<String>>, pub bound_spid: Option<Vec<String>>, pub bound_sub_id: Option<Vec<String>>, pub bound_tenant_id: String, pub delete_protection: Option<String>, pub description: Option<String>, pub expiration_event_in: Option<Vec<String>>, pub force_sub_claims: Option<bool>, pub gw_bound_ips: Option<Vec<String>>, pub issuer: Option<String>, pub json: Option<bool>, pub jwks_uri: Option<String>, pub jwt_ttl: Option<i64>, pub name: String, pub product_type: Option<Vec<String>>, pub token: Option<String>, pub uid_token: Option<String>, pub unique_identifier: Option<String>,
}
CreateAuthMethodAzureAd : createAuthMethodAzureAD is a command that creates a new auth method that will be able to authenticate using Azure Active Directory credentials. [Deprecated: Use auth-method-create-azure-ad command]

Fields

access_expires: Option<i64>

Access expiration date in Unix timestamp (select 0 for access without expiry date)

allowed_client_type: Option<Vec<String>>

limit the auth method usage for specific client types [cli,ui,gateway-admin,sdk,mobile,extension]

audience: Option<String>

Deprecated (Deprecated) The audience in the JWT

audit_logs_claims: Option<Vec<String>>

Subclaims to include in audit logs, e.g "–audit-logs-claims email –audit-logs-claims username"

bound_group_id: Option<Vec<String>>

A list of group ids that the access is restricted to

bound_ips: Option<Vec<String>>

A CIDR whitelist with the IPs that the access is restricted to

bound_providers: Option<Vec<String>>

A list of resource providers that the access is restricted to (e.g, Microsoft.Compute, Microsoft.ManagedIdentity, etc)

bound_resource_id: Option<Vec<String>>

A list of full resource ids that the access is restricted to

bound_resource_names: Option<Vec<String>>

A list of resource names that the access is restricted to (e.g, a virtual machine name, scale set name, etc).

bound_resource_types: Option<Vec<String>>

A list of resource types that the access is restricted to (e.g, virtualMachines, userAssignedIdentities, etc)

bound_rg_id: Option<Vec<String>>

A list of resource groups that the access is restricted to

bound_spid: Option<Vec<String>>

A list of service principal IDs that the access is restricted to

bound_sub_id: Option<Vec<String>>

A list of subscription ids that the access is restricted to

bound_tenant_id: String

The Azure tenant id that the access is restricted to

delete_protection: Option<String>

Protection from accidental deletion of this object [true/false]

description: Option<String>

Auth Method description

expiration_event_in: Option<Vec<String>>

How many days before the expiration of the auth method would you like to be notified.

force_sub_claims: Option<bool>

if true: enforce role-association must include sub claims

gw_bound_ips: Option<Vec<String>>

A CIDR whitelist with the GW IPs that the access is restricted to

issuer: Option<String>

Issuer URL

json: Option<bool>

Set output format to JSON

jwks_uri: Option<String>

The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.

jwt_ttl: Option<i64>

Jwt TTL

name: String

Auth Method name

product_type: Option<Vec<String>>

Choose the relevant product type for the auth method [sm, sra, pm, dp, ca]

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

unique_identifier: Option<String>

A unique identifier (ID) value which is a "sub claim" name that contains details uniquely identifying that resource. This "sub claim" is used to distinguish between different identities.

Implementations

Source

impl CreateAuthMethodAzureAd

pub fn new(bound_tenant_id: String, name: String) -> CreateAuthMethodAzureAd

createAuthMethodAzureAD is a command that creates a new auth method that will be able to authenticate using Azure Active Directory credentials. [Deprecated: Use auth-method-create-azure-ad command]