pub struct CreateAuthMethodCert {Show 26 fields
pub access_expires: Option<i64>,
pub allowed_client_type: Option<Vec<String>>,
pub allowed_cors: Option<String>,
pub audit_logs_claims: Option<Vec<String>>,
pub bound_common_names: Option<Vec<String>>,
pub bound_dns_sans: Option<Vec<String>>,
pub bound_email_sans: Option<Vec<String>>,
pub bound_extensions: Option<Vec<String>>,
pub bound_ips: Option<Vec<String>>,
pub bound_organizational_units: Option<Vec<String>>,
pub bound_uri_sans: Option<Vec<String>>,
pub certificate_data: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub force_sub_claims: Option<bool>,
pub gw_bound_ips: Option<Vec<String>>,
pub json: Option<bool>,
pub jwt_ttl: Option<i64>,
pub name: String,
pub product_type: Option<Vec<String>>,
pub require_crl_dp: Option<bool>,
pub revoked_cert_ids: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub unique_identifier: String,
}Expand description
CreateAuthMethodCert : createAuthMethodCert is a command that creates a new auth method that will be able to authenticate using a client certificate. [Deprecated: Use auth-method-create-cert command]
Fields
access_expires: Option<i64>Access expiration date in Unix timestamp (select 0 for access without expiry date)
allowed_client_type: Option<Vec<String>>limit the auth method usage for specific client types [cli,ui,gateway-admin,sdk,mobile,extension]
allowed_cors: Option<String>Comma separated list of allowed CORS domains to be validated as part of the authentication flow.
audit_logs_claims: Option<Vec<String>>Subclaims to include in audit logs, e.g "–audit-logs-claims email –audit-logs-claims username"
bound_common_names: Option<Vec<String>>A list of names. At least one must exist in the Common Name. Supports globbing.
bound_dns_sans: Option<Vec<String>>A list of DNS names. At least one must exist in the SANs. Supports globbing.
bound_email_sans: Option<Vec<String>>A list of Email Addresses. At least one must exist in the SANs. Supports globbing.
bound_extensions: Option<Vec<String>>A list of extensions formatted as "oid:value". Expects the extension value to be some type of ASN1 encoded string. All values much match. Supports globbing on "value".
bound_ips: Option<Vec<String>>A CIDR whitelist with the IPs that the access is restricted to
bound_organizational_units: Option<Vec<String>>A list of Organizational Units names. At least one must exist in the OU field.
bound_uri_sans: Option<Vec<String>>A list of URIs. At least one must exist in the SANs. Supports globbing.
certificate_data: Option<String>The certificate data in base64, if no file was provided
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Auth Method description
expiration_event_in: Option<Vec<String>>How many days before the expiration of the auth method would you like to be notified.
force_sub_claims: Option<bool>if true: enforce role-association must include sub claims
gw_bound_ips: Option<Vec<String>>A CIDR whitelist with the GW IPs that the access is restricted to
json: Option<bool>Set output format to JSON
jwt_ttl: Option<i64>Jwt TTL
name: StringAuth Method name
product_type: Option<Vec<String>>Choose the relevant product type for the auth method [sm, sra, pm, dp, ca]
require_crl_dp: Option<bool>Require certificate CRL distribution points (CDP) and enforce CRL validation during authentication.
revoked_cert_ids: Option<Vec<String>>A list of revoked cert ids
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
unique_identifier: StringA unique identifier (ID) value should be configured, such as common_name or organizational_unit Whenever a user logs in with a token, these authentication types issue a "sub claim" that contains details uniquely identifying that user. This sub claim includes a key containing the ID value that you configured, and is used to distinguish between different users from within the same organization.
Implementations
Sourceimpl CreateAuthMethodCert
impl CreateAuthMethodCert
Sourcepub fn new(name: String, unique_identifier: String) -> CreateAuthMethodCert
pub fn new(name: String, unique_identifier: String) -> CreateAuthMethodCert
createAuthMethodCert is a command that creates a new auth method that will be able to authenticate using a client certificate. [Deprecated: Use auth-method-create-cert command]