Module create_auth_method_email

Module create_auth_method_email 

Structs

CreateAuthMethodEmail
CreateAuthMethodEmail : createAuthMethodEmail is a command that creates a new auth method that will be able to authenticate using email. [Deprecated: Use auth-method-create-email command]