Module create_auth_method_gcp

Module create_auth_method_gcp 

Structs

CreateAuthMethodGcp
CreateAuthMethodGcp : createAuthMethodGCP is a command that creates a new auth method that will be able to authenticate using GCP IAM Service Account credentials or GCE instance credentials. [Deprecated: Use auth-method-create-gcp command]