Module create_auth_method_k8_s

Module create_auth_method_k8_s 

Structs

CreateAuthMethodK8S
CreateAuthMethodK8S : createAuthMethodK8S is a command that creates a new auth method that will be able to authenticate using K8S. [Deprecated: Use auth-method-create-k8s command]