Module create_auth_method_ldap

Module create_auth_method_ldap 

Structs

CreateAuthMethodLdap
CreateAuthMethodLdap : createAuthMethodLDAP is a command that creates a new auth method that will be able to authenticate using LDAP. [Deprecated: Use auth-method-create-ldap command]