Module create_auth_method_o_auth2

Module create_auth_method_o_auth2 

Structs

CreateAuthMethodOAuth2
CreateAuthMethodOAuth2 : createAuthMethodOAuth2 is a command that creates a new auth method that will be able to authenticate using Oauth2. [Deprecated: Use auth-method-create-oauth2 command]