Module create_auth_method_oci

Module create_auth_method_oci 

Structs

CreateAuthMethodOci
CreateAuthMethodOci : createAuthMethodOCI is a command that Creates a new Oracle Auth Method that will be used in the account using OCI principle and groups. [Deprecated: Use auth-method-create-oci command]