Module create_auth_method_oidc

Module create_auth_method_oidc 

Structs

CreateAuthMethodOidc
CreateAuthMethodOidc : createAuthMethodOIDC is a command that creates a new auth method that will be available to authenticate using OIDC. [Deprecated: Use auth-method-create-oidc command]