Module create_auth_method_saml

Module create_auth_method_saml 

Structs

CreateAuthMethodSaml
CreateAuthMethodSaml : createAuthMethodSAML is a command that creates a new auth method that will be available to authenticate using SAML. [Deprecated: Use auth-method-create-saml command]