Module create_auth_method_universal_identity

Module create_auth_method_universal_identity 

Structs

CreateAuthMethodUniversalIdentity
CreateAuthMethodUniversalIdentity : createAuthMethodUniversalIdentity is a command that creates a new auth method that will be able to authenticate using Akeyless Universal Identity. [Deprecated: Use auth-method-create-universal-identity command]