pub struct CreateAwsTarget {Show 15 fields
pub access_key: String,
pub access_key_id: String,
pub comment: Option<String>,
pub description: Option<String>,
pub generate_external_id: Option<bool>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub region: Option<String>,
pub role_arn: Option<String>,
pub session_token: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub use_gw_cloud_identity: Option<bool>,
}Expand description
CreateAwsTarget : createAWSTarget is a command that creates a new target. [Deprecated: Use target-create-aws command]
Fields
access_key: StringAWS secret access key
access_key_id: StringAWS access key ID
comment: Option<String>Deprecated - use description
description: Option<String>Description of the object
generate_external_id: Option<bool>A unique auto-generated value used in your AWS account when configuring your AWS IAM role to securely delegate access to Akeyless. Relevant only when using GW cloud ID
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
region: Option<String>AWS region
role_arn: Option<String>AWS IAM role identifier that Gateway will assume in your AWS account, relevant only when using external ID
session_token: Option<String>Required only for temporary security credentials retrieved using STS
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
use_gw_cloud_identity: Option<bool>Use the GW’s Cloud IAM
Implementations