pub struct CreateCertificate {Show 14 fields
pub certificate_data: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub format: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub key: Option<String>,
pub key_data: Option<String>,
pub metadata: Option<String>,
pub name: String,
pub tags: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
certificate_data: Option<String>Content of the certificate in a Base64 format.
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
expiration_event_in: Option<Vec<String>>How many days before the expiration of the certificate would you like to be notified.
format: Option<String>CertificateFormat of the certificate and private key, possible values: cer,crt,pem,pfx,p12. Required when passing inline certificate content with –certificate-data or –key-data, otherwise format is derived from the file extension.
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key to use to encrypt the certificate’s key (if empty, the account default protectionKey key will be used)
key_data: Option<String>Content of the certificate’s private key in a Base64 format.
metadata: Option<String>Deprecated - use description
name: StringCertificate name
Add tags attached to this object
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl CreateCertificate
impl CreateCertificate
pub fn new(name: String) -> CreateCertificate