pub struct CreateClassicKey {Show 29 fields
pub alg: String,
pub auto_rotate: Option<String>,
pub cert_file_data: Option<String>,
pub certificate_common_name: Option<String>,
pub certificate_country: Option<String>,
pub certificate_digest_algo: Option<String>,
pub certificate_format: Option<String>,
pub certificate_locality: Option<String>,
pub certificate_organization: Option<String>,
pub certificate_province: Option<String>,
pub certificate_ttl: Option<i64>,
pub conf_file_data: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub generate_self_signed_certificate: Option<bool>,
pub gpg_alg: Option<String>,
pub hash_algorithm: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub key_data: Option<String>,
pub metadata: Option<String>,
pub name: String,
pub protection_key_name: Option<String>,
pub rotation_event_in: Option<Vec<String>>,
pub rotation_interval: Option<String>,
pub tags: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
CreateClassicKey : CreateClassicKey is a command that creates classic key
Fields
alg: StringClassic Key type; options: [AES128GCM, AES256GCM, AES128SIV, AES256SIV, RSA1024, RSA2048, RSA3072, RSA4096, EC256, EC384, GPG]
auto_rotate: Option<String>Whether to automatically rotate every rotation_interval days, or disable existing automatic rotation [true/false]
cert_file_data: Option<String>Certificate in a PEM format.
certificate_common_name: Option<String>Common name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_country: Option<String>Country name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_digest_algo: Option<String>Digest algorithm to be used for the certificate key signing.
certificate_format: Option<String>certificate_locality: Option<String>Locality for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_organization: Option<String>Organization name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_province: Option<String>Province name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_ttl: Option<i64>TTL in days for the generated certificate. Required only for generate-self-signed-certificate.
conf_file_data: Option<String>The csr config data in base64 encoding
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
expiration_event_in: Option<Vec<String>>How many days before the expiration of the certificate would you like to be notified.
generate_self_signed_certificate: Option<bool>Whether to generate a self signed certificate with the key. If set, –certificate-ttl must be provided.
gpg_alg: Option<String>gpg alg: Relevant only if GPG key type selected; options: [RSA1024, RSA2048, RSA3072, RSA4096, Ed25519]
hash_algorithm: Option<String>Specifies the hash algorithm used for the encryption key’s operations, available options: [SHA256, SHA384, SHA512]
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
key_data: Option<String>Base64-encoded classic key value
metadata: Option<String>Deprecated - use description
name: StringClassicKey name
protection_key_name: Option<String>The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
rotation_event_in: Option<Vec<String>>How many days before the rotation of the item would you like to be notified
rotation_interval: Option<String>The number of days to wait between every automatic rotation (1-365)
Add tags attached to this object
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl CreateClassicKey
impl CreateClassicKey
Sourcepub fn new(alg: String, name: String) -> CreateClassicKey
pub fn new(alg: String, name: String) -> CreateClassicKey
CreateClassicKey is a command that creates classic key