pub struct CreateDockerhubTarget {
pub comment: Option<String>,
pub description: Option<String>,
pub dockerhub_password: Option<String>,
pub dockerhub_username: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
CreateDockerhubTarget : createDockerhubTarget is a command that creates a new target. [Deprecated: Use target-create-dockerhub command]
Fields
comment: Option<String>Deprecated - use description
description: Option<String>Description of the object
dockerhub_password: Option<String>Password for docker repository
dockerhub_username: Option<String>Username for docker repository
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl CreateDockerhubTarget
impl CreateDockerhubTarget
Sourcepub fn new(name: String) -> CreateDockerhubTarget
pub fn new(name: String) -> CreateDockerhubTarget
createDockerhubTarget is a command that creates a new target. [Deprecated: Use target-create-dockerhub command]