pub struct CreateEsm {
pub azure_kv_name: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub gcp_project_id: Option<String>,
pub json: Option<bool>,
pub k8s_namespace: Option<String>,
pub name: String,
pub tags: Option<Vec<String>>,
pub target_to_associate: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
CreateEsm : CreateESM is a command that creates an External Secrets Manager. [Deprecated: Use command create-usc]
Fields
azure_kv_name: Option<String>Azure Key Vault name (Relevant only for Azure targets)
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the External Secrets Manager
gcp_project_id: Option<String>GCP Project ID (Relevant only for GCP targets)
json: Option<bool>Set output format to JSON
k8s_namespace: Option<String>K8s namespace (Relevant to Kubernetes targets)
name: StringExternal Secrets Manager name
List of the tags attached to this External Secrets Manager
target_to_associate: StringTarget External Secrets Manager to connect
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations