pub struct CreateEventForwarder {Show 22 fields
pub admin_name: Option<String>,
pub admin_pwd: Option<String>,
pub app_private_key_base64: Option<String>,
pub auth_type: Option<String>,
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub comment: Option<String>,
pub description: Option<String>,
pub email_to: Option<String>,
pub event_source_locations: Vec<String>,
pub event_source_type: Option<String>,
pub event_types: Option<Vec<String>>,
pub every: Option<String>,
pub forwarder_type: String,
pub host: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub name: String,
pub runner_type: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_email: Option<String>,
}Expand description
CreateEventForwarder : createEventForwarder is a command that creates a new event forwarder [Deprecated - please use event-forwarder-create-* command]
Fields
admin_name: Option<String>Workstation Admin Name
admin_pwd: Option<String>Workstation Admin password
app_private_key_base64: Option<String>The RSA Private Key PEM formatted in base64 to use when connecting to ServiceNow with jwt authentication
auth_type: Option<String>The authentication type to use when connecting to ServiceNow (user-pass / jwt)
client_id: Option<String>The client ID to use when connecting to ServiceNow with jwt authentication
client_secret: Option<String>The client secret to use when connecting to ServiceNow with jwt authentication
comment: Option<String>Deprecated - use description
description: Option<String>Description of the object
email_to: Option<String>A comma seperated list of email addresses to send event to (relevant only for "email" Event Forwarder)
event_source_locations: Vec<String>Event sources
event_source_type: Option<String>Event Source type [item, target, auth_method, gateway]
event_types: Option<Vec<String>>List of event types to notify about [request-access, certificate-pending-expiration, certificate-expired, certificate-provisioning-success, certificate-provisioning-failure, auth-method-pending-expiration, auth-method-expired, rotated-secret-success, rotated-secret-failure, dynamic-secret-failure, multi-auth-failure, uid-rotation-failure, apply-justification, email-auth-method-approved, usage, rotation-usage, gateway-inactive, static-secret-updated]
every: Option<String>Rate of periodic runner repetition in hours
forwarder_type: Stringhost: Option<String>Workstation Host
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the EventForwarder secret value (if empty, the account default protectionKey key will be used)
name: StringEventForwarder name
runner_type: Stringtoken: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_email: Option<String>The user email to use when connecting to ServiceNow with jwt authentication
Implementations