pub struct CreateGlobalSignTarget {Show 16 fields
pub comment: Option<String>,
pub contact_email: String,
pub contact_first_name: String,
pub contact_last_name: String,
pub contact_phone: String,
pub description: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub password: String,
pub profile_id: String,
pub timeout: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub username: String,
}Expand description
CreateGlobalSignTarget : createGlobalSignTarget is a command that creates a new target. [Deprecated: Use target-create-globalsign command]
Fields
comment: Option<String>Deprecated - use description
contact_email: StringEmail of the GlobalSign GCC account contact
contact_first_name: StringFirst name of the GlobalSign GCC account contact
contact_last_name: StringLast name of the GlobalSign GCC account contact
contact_phone: StringTelephone of the GlobalSign GCC account contact
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
password: StringPassword of the GlobalSign GCC account
profile_id: StringProfile ID of the GlobalSign GCC account
timeout: Option<String>Timeout waiting for certificate validation in Duration format (1h - 1 Hour, 20m - 20 Minutes, 33m3s - 33 Minutes and 3 Seconds), maximum 1h.
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
username: StringUsername of the GlobalSign GCC account
Implementations
Sourceimpl CreateGlobalSignTarget
impl CreateGlobalSignTarget
Sourcepub fn new(
contact_email: String,
contact_first_name: String,
contact_last_name: String,
contact_phone: String,
name: String,
password: String,
profile_id: String,
username: String,
) -> CreateGlobalSignTarget
pub fn new( contact_email: String, contact_first_name: String, contact_last_name: String, contact_phone: String, name: String, password: String, profile_id: String, username: String, ) -> CreateGlobalSignTarget
createGlobalSignTarget is a command that creates a new target. [Deprecated: Use target-create-globalsign command]