pub struct CreateHashiVaultTarget {
pub description: Option<String>,
pub hashi_url: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub namespace: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub vault_token: Option<String>,
}Expand description
CreateHashiVaultTarget : createHashiVaultTarget is a command that creates a new hashi-vault target. [Deprecated: Use target-create-hashi-vault command]
Fields
description: Option<String>Description of the object
hashi_url: Option<String>HashiCorp Vault API URL, e.g. https://vault-mgr01:8200
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
namespace: Option<Vec<String>>Comma-separated list of vault namespaces
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
vault_token: Option<String>Vault access token with sufficient permissions
Implementations
Sourceimpl CreateHashiVaultTarget
impl CreateHashiVaultTarget
Sourcepub fn new(name: String) -> CreateHashiVaultTarget
pub fn new(name: String) -> CreateHashiVaultTarget
createHashiVaultTarget is a command that creates a new hashi-vault target. [Deprecated: Use target-create-hashi-vault command]