pub struct CreateKey {Show 21 fields
pub alg: String,
pub certificate_common_name: Option<String>,
pub certificate_country: Option<String>,
pub certificate_digest_algo: Option<String>,
pub certificate_locality: Option<String>,
pub certificate_organization: Option<String>,
pub certificate_province: Option<String>,
pub certificate_ttl: Option<i64>,
pub conf_file_data: Option<String>,
pub customer_frg_id: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub generate_self_signed_certificate: Option<bool>,
pub hash_algorithm: Option<String>,
pub json: Option<bool>,
pub metadata: Option<String>,
pub name: String,
pub split_level: Option<i64>,
pub tag: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
CreateKey : createKey is a command that creates a new key. [Deprecated: Use command create-dfc-key]
Fields
alg: StringKey type; options: [AES128GCM, AES256GCM, AES128SIV, AES256SIV, AES128CBC, AES256CBC, RSA1024, RSA2048, RSA3072, RSA4096]
certificate_common_name: Option<String>Common name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_country: Option<String>Country name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_digest_algo: Option<String>Digest algorithm to be used for the certificate key signing.
certificate_locality: Option<String>Locality for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_organization: Option<String>Organization name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_province: Option<String>Province name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_ttl: Option<i64>TTL in days for the generated certificate. Required only for generate-self-signed-certificate.
conf_file_data: Option<String>The csr config data in base64 encoding
customer_frg_id: Option<String>The customer fragment ID that will be used to create the key (if empty, the key will be created independently of a customer fragment)
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
generate_self_signed_certificate: Option<bool>Whether to generate a self signed certificate with the key. If set, –certificate-ttl must be provided.
hash_algorithm: Option<String>Specifies the hash algorithm used for the encryption key’s operations, available options: [SHA256, SHA384, SHA512]
json: Option<bool>Set output format to JSON
metadata: Option<String>Deprecated - use description
name: StringKey name
split_level: Option<i64>The number of fragments that the item will be split into (not includes customer fragment)
tag: Option<Vec<String>>List of the tags attached to this key
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication