Module create_linked_target

Module create_linked_target 

Structs

CreateLinkedTarget
CreateLinkedTarget : createLinkedTarget is a command that creates a new Linked Target which can inherit credentials from existing Targets. [Deprecated: Use target-create-linked command]