pub struct CreateLinkedTarget {
pub description: Option<String>,
pub hosts: Option<String>,
pub json: Option<bool>,
pub name: String,
pub parent_target_name: Option<String>,
pub token: Option<String>,
pub type: Option<String>,
pub uid_token: Option<String>,
}Expand description
CreateLinkedTarget : createLinkedTarget is a command that creates a new Linked Target which can inherit credentials from existing Targets. [Deprecated: Use target-create-linked command]
Fields
description: Option<String>Description of the object
hosts: Option<String>A comma seperated list of server hosts and server descriptions joined by semicolon ‘;’ (i.e. ‘server-dev.com;My Dev server,server-prod.com;My Prod server description’)
json: Option<bool>Set output format to JSON
name: StringTarget name
parent_target_name: Option<String>The parent Target name
token: Option<String>Authentication token (see /auth and /configure)
type: Option<String>Specifies the hosts type, relevant only when working without parent target
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl CreateLinkedTarget
impl CreateLinkedTarget
Sourcepub fn new(name: String) -> CreateLinkedTarget
pub fn new(name: String) -> CreateLinkedTarget
createLinkedTarget is a command that creates a new Linked Target which can inherit credentials from existing Targets. [Deprecated: Use target-create-linked command]