pub struct CreatePasskey {
pub accessibility: Option<String>,
pub alg: String,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub json: Option<bool>,
pub name: String,
pub origin_url: Option<Vec<String>>,
pub protection_key_name: Option<String>,
pub tags: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub username: Option<String>,
}Expand description
CreatePasskey : CreatePasskey is a command that creates a new passkey
Fields
accessibility: Option<String>for personal password manager
alg: StringPasskey type; options: [EC256, EC384, EC512]
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
name: StringClassicKey name
origin_url: Option<Vec<String>>Originating websites for this passkey
protection_key_name: Option<String>The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
Add tags attached to this object
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
username: Option<String>For Password Management use
Implementations
Sourceimpl CreatePasskey
impl CreatePasskey
Sourcepub fn new(alg: String, name: String) -> CreatePasskey
pub fn new(alg: String, name: String) -> CreatePasskey
CreatePasskey is a command that creates a new passkey