CreateRotatedSecret

Struct CreateRotatedSecret 

pub struct CreateRotatedSecret {
Show 55 fields pub provider_type: Option<String>, pub api_id: Option<String>, pub api_key: Option<String>, pub application_id: Option<String>, pub authentication_credentials: Option<String>, pub auto_rotate: Option<String>, pub aws_region: Option<String>, pub custom_payload: Option<String>, pub delete_protection: Option<String>, pub description: Option<String>, pub gcp_key: Option<String>, pub gcp_service_account_email: Option<String>, pub gcp_service_account_key_id: Option<String>, pub grace_rotation: Option<String>, pub host_provider: Option<String>, pub json: Option<bool>, pub key: Option<String>, pub metadata: Option<String>, pub name: String, pub password_length: Option<String>, pub rotate_after_disconnect: Option<String>, pub rotated_password: Option<String>, pub rotated_username: Option<String>, pub rotation_hour: Option<i32>, pub rotation_interval: Option<String>, pub rotator_creds_type: Option<String>, pub rotator_custom_cmd: Option<String>, pub rotator_type: String, pub same_password: Option<String>, pub secure_access_allow_external_user: Option<bool>, pub secure_access_aws_account_id: Option<String>, pub secure_access_aws_native_cli: Option<bool>, pub secure_access_bastion_issuer: Option<String>, pub secure_access_certificate_issuer: Option<String>, pub secure_access_db_name: Option<String>, pub secure_access_db_schema: Option<String>, pub secure_access_disable_concurrent_connections: Option<bool>, pub secure_access_enable: Option<String>, pub secure_access_host: Option<Vec<String>>, pub secure_access_rdp_domain: Option<String>, pub secure_access_rdp_user: Option<String>, pub secure_access_url: Option<String>, pub secure_access_web: Option<bool>, pub secure_access_web_browsing: Option<bool>, pub secure_access_web_proxy: Option<bool>, pub ssh_password: Option<String>, pub ssh_username: Option<String>, pub storage_account_key_name: Option<String>, pub tags: Option<Vec<String>>, pub target: Option<Vec<String>>, pub target_name: String, pub token: Option<String>, pub uid_token: Option<String>, pub user_attribute: Option<String>, pub user_dn: Option<String>,
}
CreateRotatedSecret : createRotatedSecret is a command that creates a rotated secret [Deprecated: Use rotated-secret-create commands]

Fields

provider_type: Option<String>api_id: Option<String>

API ID to rotate (relevant only for rotator-type=api-key)

api_key: Option<String>

API key to rotate (relevant only for rotator-type=api-key)

application_id: Option<String>

ApplicationId (used in azure)

authentication_credentials: Option<String>

The credentials to connect with use-user-creds/use-target-creds

auto_rotate: Option<String>

Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]

aws_region: Option<String>

Aws Region (relevant only for aws)

custom_payload: Option<String>

Secret payload to be sent with rotation request (relevant only for rotator-type=custom)

delete_protection: Option<String>

Protection from accidental deletion of this object [true/false]

description: Option<String>

Description of the object

gcp_key: Option<String>

Base64-encoded service account private key text

gcp_service_account_email: Option<String>

The email of the gcp service account to rotate

gcp_service_account_key_id: Option<String>

The key id of the gcp service account to rotate

grace_rotation: Option<String>

Create a new access key without deleting the old key from AWS for backup (relevant only for AWS) [true/false]

host_provider: Option<String>

Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret

json: Option<bool>

Set output format to JSON

key: Option<String>

The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)

metadata: Option<String>

Deprecated - use description

name: String

Secret name

password_length: Option<String>

The length of the password to be generated

rotate_after_disconnect: Option<String>

Rotate the value of the secret after SRA session ends [true/false]

rotated_password: Option<String>

rotated-username password (relevant only for rotator-type=password)

rotated_username: Option<String>

username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=password)

rotation_hour: Option<i32>

The Hour of the rotation in UTC. Default rotation-hour is 14:00

rotation_interval: Option<String>

The number of days to wait between every automatic key rotation (1-365)

rotator_creds_type: Option<String>rotator_custom_cmd: Option<String>

Custom rotation command (relevant only for ssh target)

rotator_type: String

Rotator Type

same_password: Option<String>

Rotate same password for each host from the Linked Target (relevant only for Linked Target)

secure_access_allow_external_user: Option<bool>

Allow providing external user for a domain users (relevant only for rdp)

secure_access_aws_account_id: Option<String>

The AWS account id (relevant only for aws)

secure_access_aws_native_cli: Option<bool>

The AWS native cli

secure_access_bastion_issuer: Option<String>

Deprecated. use secure-access-certificate-issuer

secure_access_certificate_issuer: Option<String>

Path to the SSH Certificate Issuer for your Akeyless Secure Access

secure_access_db_name: Option<String>

The DB name (relevant only for DB Dynamic-Secret)

secure_access_db_schema: Option<String>

The db schema (relevant only for mssql or postgresql)

secure_access_disable_concurrent_connections: Option<bool>

Enable this flag to prevent simultaneous use of the same secret

secure_access_enable: Option<String>

Enable/Disable secure remote access [true/false]

secure_access_host: Option<Vec<String>>

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)

secure_access_rdp_domain: Option<String>

Required when the Dynamic Secret is used for a domain user (relevant only for RDP Dynamic-Secret)

secure_access_rdp_user: Option<String>

Override the RDP Domain username (relevant only for rdp)

secure_access_url: Option<String>

Destination URL to inject secrets

secure_access_web: Option<bool>

Enable Web Secure Remote Access

secure_access_web_browsing: Option<bool>

Secure browser viaAkeyless’s Secure Remote Access (SRA) (relevant only for aws or azure)

secure_access_web_proxy: Option<bool>

Web-Proxy via Akeyless’s Secure Remote Access (SRA) (relevant only for aws or azure)

ssh_password: Option<String>

Deprecated: use RotatedPassword

ssh_username: Option<String>

Deprecated: use RotatedUser

storage_account_key_name: Option<String>

The name of the storage account key to rotate [key1/key2/kerb1/kerb2] (relevat to azure-storage-account)

tags: Option<Vec<String>>

Add tags attached to this object

target: Option<Vec<String>>

A list of linked targets to be associated, Relevant only for Secure Remote Access for ssh cert issuer, ldap rotated secret and ldap dynamic secret, To specify multiple targets use argument multiple times

target_name: String

Target name

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

user_attribute: Option<String>

LDAP User Attribute, Default value "cn"

user_dn: Option<String>

LDAP User Base DN

Implementations

Source

impl CreateRotatedSecret

pub fn new( name: String, rotator_type: String, target_name: String, ) -> CreateRotatedSecret

createRotatedSecret is a command that creates a rotated secret [Deprecated: Use rotated-secret-create commands]