pub struct CreateSecret {Show 32 fields
pub accessibility: Option<String>,
pub change_event: Option<String>,
pub custom_field: Option<HashMap<String, String>>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub format: Option<String>,
pub inject_url: Option<Vec<String>>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub max_versions: Option<String>,
pub metadata: Option<String>,
pub multiline_value: Option<bool>,
pub name: String,
pub password: Option<String>,
pub protection_key: Option<String>,
pub secure_access_bastion_issuer: Option<String>,
pub secure_access_certificate_issuer: Option<String>,
pub secure_access_enable: Option<String>,
pub secure_access_gateway: Option<String>,
pub secure_access_host: Option<Vec<String>>,
pub secure_access_rdp_user: Option<String>,
pub secure_access_ssh_creds: Option<String>,
pub secure_access_ssh_user: Option<String>,
pub secure_access_url: Option<String>,
pub secure_access_web_browsing: Option<bool>,
pub secure_access_web_proxy: Option<bool>,
pub tags: Option<Vec<String>>,
pub token: Option<String>,
pub type: Option<String>,
pub uid_token: Option<String>,
pub username: Option<String>,
pub value: String,
}Fields
accessibility: Option<String>for personal password manager
change_event: Option<String>Trigger an event when a secret value changed [true/false] (Relevant only for Static Secret)
custom_field: Option<HashMap<String, String>>For Password Management use, additional fields
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
format: Option<String>Secret format [text/json/key-value] (relevant only for type ‘generic’)
inject_url: Option<Vec<String>>For Password Management use, reflect the website context
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
metadata: Option<String>Deprecated - use description
multiline_value: Option<bool>The provided value is a multiline value (separated by ‘\n’)
name: StringSecret name
password: Option<String>For Password Management use, additional fields
protection_key: Option<String>The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
secure_access_bastion_issuer: Option<String>Deprecated. use secure-access-certificate-issuer
secure_access_certificate_issuer: Option<String>Path to the SSH Certificate Issuer for your Akeyless Secure Access
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_gateway: Option<String>secure_access_host: Option<Vec<String>>Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)
secure_access_rdp_user: Option<String>Remote Desktop Username
secure_access_ssh_creds: Option<String>Static-Secret values contains SSH Credentials, either Private Key or Password [password/private-key]
secure_access_ssh_user: Option<String>Override the SSH username as indicated in SSH Certificate Issuer
secure_access_url: Option<String>Destination URL to inject secrets
secure_access_web_browsing: Option<bool>Secure browser via Akeyless’s Secure Remote Access (SRA)
secure_access_web_proxy: Option<bool>Web-Proxy via Akeyless’s Secure Remote Access (SRA)
Add tags attached to this object
token: Option<String>Authentication token (see /auth and /configure)
type: Option<String>The secret sub type [generic/password]
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
username: Option<String>For Password Management use
value: StringThe secret value (relevant only for type ‘generic’)
Implementations
Sourceimpl CreateSecret
impl CreateSecret
pub fn new(name: String, value: String) -> CreateSecret