CreateSshCertIssuer

Struct CreateSshCertIssuer 

pub struct CreateSshCertIssuer {
Show 30 fields pub provider_type: Option<String>, pub allowed_users: String, pub delete_protection: Option<String>, pub description: Option<String>, pub extensions: Option<HashMap<String, String>>, pub external_username: Option<String>, pub fixed_user_claim_keyname: Option<String>, pub host_provider: Option<String>, pub item_custom_fields: Option<HashMap<String, String>>, pub json: Option<bool>, pub metadata: Option<String>, pub name: String, pub principals: Option<String>, pub secure_access_api: Option<String>, pub secure_access_bastion_api: Option<String>, pub secure_access_bastion_ssh: Option<String>, pub secure_access_enable: Option<String>, pub secure_access_enforce_hosts_restriction: Option<bool>, pub secure_access_gateway: Option<String>, pub secure_access_host: Option<Vec<String>>, pub secure_access_ssh: Option<String>, pub secure_access_ssh_creds_user: Option<String>, pub secure_access_use_internal_bastion: Option<bool>, pub secure_access_use_internal_ssh_access: Option<bool>, pub signer_key_name: String, pub tag: Option<Vec<String>>, pub target: Option<Vec<String>>, pub token: Option<String>, pub ttl: i64, pub uid_token: Option<String>,
}

Fields

provider_type: Option<String>allowed_users: String

Users allowed to fetch the certificate, e.g root,ubuntu

delete_protection: Option<String>

Protection from accidental deletion of this object [true/false]

description: Option<String>

Description of the object

extensions: Option<HashMap<String, String>>

Signed certificates with extensions, e.g permit-port-forwarding=\"\"

external_username: Option<String>

Externally provided username [true/false]

fixed_user_claim_keyname: Option<String>

For externally provided users, denotes the key-name of IdP claim to extract the username from (relevant only for external-username=true)

host_provider: Option<String>

Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret

item_custom_fields: Option<HashMap<String, String>>

Additional custom fields to associate with the item

json: Option<bool>

Set output format to JSON

metadata: Option<String>

Deprecated - use description

name: String

SSH certificate issuer name

principals: Option<String>

Signed certificates with principal, e.g example_role1,example_role2

secure_access_api: Option<String>

Secure Access SSH control API endpoint. E.g. https://my.sra-server:9900

secure_access_bastion_api: Option<String>

Deprecated. use secure-access-api

secure_access_bastion_ssh: Option<String>

Deprecated. use secure-access-ssh

secure_access_enable: Option<String>

Enable/Disable secure remote access [true/false]

secure_access_enforce_hosts_restriction: Option<bool>

Enable this flag to enforce connections only to the hosts listed in –secure-access-host

secure_access_gateway: Option<String>secure_access_host: Option<Vec<String>>

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)

secure_access_ssh: Option<String>

Bastion’s SSH server. E.g. my.sra-server:22

secure_access_ssh_creds_user: Option<String>

SSH username to connect to target server, must be in ‘Allowed Users’ list

secure_access_use_internal_bastion: Option<bool>

Deprecated. Use secure-access-use-internal-ssh-access

secure_access_use_internal_ssh_access: Option<bool>

Use internal SSH Access

signer_key_name: String

A key to sign the certificate with

tag: Option<Vec<String>>

List of the tags attached to this key

target: Option<Vec<String>>

A list of linked targets to be associated, Relevant only for Secure Remote Access for ssh cert issuer, ldap rotated secret and ldap dynamic secret, To specify multiple targets use argument multiple times

token: Option<String>

Authentication token (see /auth and /configure)

ttl: i64

The requested Time To Live for the certificate, in seconds

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

Implementations

Source

impl CreateSshCertIssuer

pub fn new( allowed_users: String, name: String, signer_key_name: String, ttl: i64, ) -> CreateSshCertIssuer