CreateTokenizer

Struct CreateTokenizer 

pub struct CreateTokenizer {
Show 17 fields pub alphabet: Option<String>, pub decoding_template: Option<String>, pub delete_protection: Option<String>, pub description: Option<String>, pub encoding_template: Option<String>, pub encryption_key_name: Option<String>, pub item_custom_fields: Option<HashMap<String, String>>, pub json: Option<bool>, pub metadata: Option<String>, pub name: String, pub pattern: Option<String>, pub tag: Option<Vec<String>>, pub template_type: String, pub token: Option<String>, pub tokenizer_type: String, pub tweak_type: Option<String>, pub uid_token: Option<String>,
}
CreateTokenizer : createTokenizer is a command that creates a tokenizer item

Fields

alphabet: Option<String>

Alphabet to use in regexp vaultless tokenization

decoding_template: Option<String>

The Decoding output template to use in regexp vaultless tokenization

delete_protection: Option<String>

Protection from accidental deletion of this object [true/false]

description: Option<String>

Description of the object

encoding_template: Option<String>

The Encoding output template to use in regexp vaultless tokenization

encryption_key_name: Option<String>

AES key name to use in vaultless tokenization

item_custom_fields: Option<HashMap<String, String>>

Additional custom fields to associate with the item

json: Option<bool>

Set output format to JSON

metadata: Option<String>

Deprecated - use description

name: String

Tokenizer name

pattern: Option<String>

Pattern to use in regexp vaultless tokenization

tag: Option<Vec<String>>

List of the tags attached to this key

template_type: String

Which template type this tokenizer is used for [SSN,CreditCard,USPhoneNumber,Email,Regexp]

token: Option<String>

Authentication token (see /auth and /configure)

tokenizer_type: String

Tokenizer type

tweak_type: Option<String>

The tweak type to use in vaultless tokenization [Supplied, Generated, Internal, Masking]

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

Implementations

Source

impl CreateTokenizer

pub fn new( name: String, template_type: String, tokenizer_type: String, ) -> CreateTokenizer

createTokenizer is a command that creates a tokenizer item