pub struct CreateUsc {Show 20 fields
pub azure_kv_name: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub environment_names: Option<String>,
pub gcp_project_id: Option<String>,
pub gcp_sm_regions: Option<String>,
pub github_scope: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub k8s_namespace: Option<String>,
pub name: String,
pub organization_name: Option<String>,
pub repository_access: Option<String>,
pub repository_names: Option<String>,
pub tags: Option<Vec<String>>,
pub target_to_associate: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub usc_prefix: Option<String>,
pub use_prefix_as_filter: Option<String>,
}Expand description
CreateUsc : CreateUSC is a command that creates a Universal Secrets Connector
Fields
azure_kv_name: Option<String>Azure Key Vault name (Relevant only for Azure targets)
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the Universal Secrets Connector
environment_names: Option<String>The environments in repo-name/environment-name format, comma-separated (only relevant for: github-scope=repository-environment)
gcp_project_id: Option<String>GCP Project ID (Relevant only for GCP targets)
gcp_sm_regions: Option<String>GCP Secret Manager regions to query for regional secrets (comma-separated, e.g., us-east1,us-west1). Max 12 regions. Required when listing with object-type=regional-secrets.
github_scope: Option<String>The scope where secrets will be created, available options: [repository, organization, repository-environment]
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
k8s_namespace: Option<String>K8s namespace (Relevant to Kubernetes targets)
name: StringUniversal Secrets Connector name
organization_name: Option<String>The organization name to create the secret in (only relevant for: github-scope=organization)
repository_access: Option<String>repository_names: Option<String>The repository names, comma-separated (only relevant for: github-scope=repository)
List of the tags attached to this Universal Secrets Connector
target_to_associate: StringTarget Universal Secrets Connector to connect
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
usc_prefix: Option<String>Prefix for all secrets created in AWS Secrets Manager
use_prefix_as_filter: Option<String>Whether to filter the USC secret list using the specified usc-prefix [true/false]