CreateWindowsTarget

Struct CreateWindowsTarget 

pub struct CreateWindowsTarget {
Show 16 fields pub certificate: Option<String>, pub connection_type: Option<String>, pub description: Option<String>, pub domain: Option<String>, pub hostname: String, pub json: Option<bool>, pub key: Option<String>, pub max_versions: Option<String>, pub name: String, pub parent_target_name: Option<String>, pub password: String, pub port: Option<String>, pub token: Option<String>, pub uid_token: Option<String>, pub use_tls: Option<String>, pub username: String,
}
CreateWindowsTarget : createWindowsTarget is a command that creates a new windows target. [Deprecated: Use target-create-windows command]

Fields

certificate: Option<String>

SSL CA certificate in base64 encoding generated from a trusted Certificate Authority (CA)

connection_type: Option<String>

Type of connection to Windows Server [credentials/parent-target]

description: Option<String>

Description of the object

domain: Option<String>

User domain name

hostname: String

Server hostname

json: Option<bool>

Set output format to JSON

key: Option<String>

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)

max_versions: Option<String>

Set the maximum number of versions, limited by the account settings defaults.

name: String

Target name

parent_target_name: Option<String>

Name of the parent target, relevant only when connection-type is parent-target

password: String

Privileged user password

port: Option<String>

Server WinRM port

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

use_tls: Option<String>

Enable/Disable TLS for WinRM over HTTPS [true/false]

username: String

Privileged username

Implementations

Source

impl CreateWindowsTarget

pub fn new( hostname: String, name: String, password: String, username: String, ) -> CreateWindowsTarget

createWindowsTarget is a command that creates a new windows target. [Deprecated: Use target-create-windows command]