Module data_protection_section

Module data_protection_section 

Structs

DataProtectionSection
DataProtectionSection : We need the fields to be pointers as we use the same struct for partial updates as well