pub struct DataProtectionSection {
pub enable_classic_key_protection: Option<bool>,
}Expand description
DataProtectionSection : We need the fields to be pointers as we use the same struct for partial updates as well
Fields
enable_classic_key_protection: Option<bool>Implementations
Sourceimpl DataProtectionSection
impl DataProtectionSection
Sourcepub fn new() -> DataProtectionSection
pub fn new() -> DataProtectionSection
We need the fields to be pointers as we use the same struct for partial updates as well