pub struct DecryptFile {
pub cyphertext_header: Option<String>,
pub display_id: Option<String>,
pub in: String,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub key_name: String,
pub out: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: Option<i32>,
}Fields
cyphertext_header: Option<String>display_id: Option<String>The display id of the key to use in the decryption process
in: StringPath to the file to be decrypted. If not provided, the content will be taken from stdin
item_id: Option<i64>The item id of the key to use in the decryption process
json: Option<bool>Set output format to JSON
key_name: StringThe name of the key to use in the decryption process
out: Option<String>Path to the output file. If not provided, the output will be sent to stdout
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: Option<i32>key version (relevant only for classic key)
Implementations
Sourceimpl DecryptFile
impl DecryptFile
pub fn new(in: String, key_name: String) -> DecryptFile