pub struct DecryptGpg {
pub ciphertext: String,
pub display_id: Option<String>,
pub input_format: Option<String>,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub key_name: String,
pub output_format: Option<String>,
pub passphrase: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
ciphertext: StringCiphertext to be decrypted
display_id: Option<String>The display id of the key to use in the decryption process
input_format: Option<String>Select default assumed format for the ciphertext. Currently supported options: [base64,raw]
item_id: Option<i64>The item id of the key to use in the decryption process
json: Option<bool>Set output format to JSON
key_name: StringThe name of the key to use in the decryption process
output_format: Option<String>If specified, the output will be formatted accordingly. options: [base64]
passphrase: Option<String>Passphrase that was used to generate the key
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl DecryptGpg
impl DecryptGpg
pub fn new(ciphertext: String, key_name: String) -> DecryptGpg