pub struct DecryptPkcs1 {
pub ciphertext: String,
pub display_id: Option<String>,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub key_name: String,
pub output_format: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: Option<i32>,
}Fields
ciphertext: StringCiphertext to be decrypted in base64 encoded format
display_id: Option<String>The display id of the key to use in the decryption process
item_id: Option<i64>The item id of the key to use in the decryption process
json: Option<bool>Set output format to JSON
key_name: StringThe name of the key to use in the decryption process
output_format: Option<String>If specified, the output will be formatted accordingly. options: [base64]
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: Option<i32>key version (relevant only for classic key)
Implementations
Sourceimpl DecryptPkcs1
impl DecryptPkcs1
pub fn new(ciphertext: String, key_name: String) -> DecryptPkcs1