pub struct DeleteAuthMethod {
pub json: Option<bool>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
DeleteAuthMethod : deleteAuthMethod is a command that deletes the auth method. [Deprecated: Use auth-method-delete command]
Fields
json: Option<bool>Set output format to JSON
name: StringAuth Method name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl DeleteAuthMethod
impl DeleteAuthMethod
Sourcepub fn new(name: String) -> DeleteAuthMethod
pub fn new(name: String) -> DeleteAuthMethod
deleteAuthMethod is a command that deletes the auth method. [Deprecated: Use auth-method-delete command]