pub struct DeleteAuthMethods {
pub json: Option<bool>,
pub path: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
DeleteAuthMethods : deleteAuthMethods is a command that deletes multiple auth methods from a given path.
Fields
json: Option<bool>Set output format to JSON
path: StringPath to delete the auth methods from
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl DeleteAuthMethods
impl DeleteAuthMethods
Sourcepub fn new(path: String) -> DeleteAuthMethods
pub fn new(path: String) -> DeleteAuthMethods
deleteAuthMethods is a command that deletes multiple auth methods from a given path.