pub struct DeleteEventForwarder {
pub json: Option<bool>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
DeleteEventForwarder : deleteEventForwarder is a command that creates a new event forwarder [Deprecated - please use event-forwarder-delete command]
Fields
json: Option<bool>Set output format to JSON
name: StringEventForwarder name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl DeleteEventForwarder
impl DeleteEventForwarder
Sourcepub fn new(name: String) -> DeleteEventForwarder
pub fn new(name: String) -> DeleteEventForwarder
deleteEventForwarder is a command that creates a new event forwarder [Deprecated - please use event-forwarder-delete command]