pub struct DeleteRoleAssociation {
pub assoc_id: String,
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
DeleteRoleAssociation : deleteRoleAssociation is a command that deletes an association between role and auth method.
Fields
assoc_id: StringThe association id to be deleted
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl DeleteRoleAssociation
impl DeleteRoleAssociation
Sourcepub fn new(assoc_id: String) -> DeleteRoleAssociation
pub fn new(assoc_id: String) -> DeleteRoleAssociation
deleteRoleAssociation is a command that deletes an association between role and auth method.