pub struct DeleteTargetAssociation {
pub assoc_id: Option<String>,
pub json: Option<bool>,
pub name: String,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
DeleteTargetAssociation : deleteTargetAssociation is a command that deletes an association between target and item.
Fields
assoc_id: Option<String>The association id to be deleted
json: Option<bool>Set output format to JSON
name: StringItem name
target_name: Option<String>The target to associate
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl DeleteTargetAssociation
impl DeleteTargetAssociation
Sourcepub fn new(name: String) -> DeleteTargetAssociation
pub fn new(name: String) -> DeleteTargetAssociation
deleteTargetAssociation is a command that deletes an association between target and item.