pub struct DescribeItem {Show 13 fields
pub accessibility: Option<String>,
pub bastion_details: Option<bool>,
pub der_certificate_format: Option<bool>,
pub display_id: Option<String>,
pub gateway_details: Option<bool>,
pub item_custom_fields_details: Option<bool>,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub name: String,
pub services_details: Option<bool>,
pub show_versions: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
accessibility: Option<String>for personal password manager
bastion_details: Option<bool>Indicate if the item should return with ztb cluster details (url, etc)
der_certificate_format: Option<bool>The certificate will be displayed in DER format
display_id: Option<String>The display id of the item
gateway_details: Option<bool>Indicate if the item should return with clusters details (url, etc)
item_custom_fields_details: Option<bool>Include all item custom fields details
item_id: Option<i64>Item id of the item
json: Option<bool>Set output format to JSON
name: StringItem name
services_details: Option<bool>Include all associated services details
show_versions: Option<bool>Include all item versions in reply
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl DescribeItem
impl DescribeItem
pub fn new(name: String) -> DescribeItem