pub struct Detokenize {
pub ciphertext: String,
pub json: Option<bool>,
pub token: Option<String>,
pub tokenizer_name: String,
pub tweak: Option<String>,
pub uid_token: Option<String>,
}Expand description
Detokenize : detokenize is a command that decrypts text with a tokenizer
Fields
ciphertext: StringData to be decrypted
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
tokenizer_name: StringThe name of the tokenizer to use in the decryption process
tweak: Option<String>Base64 encoded tweak for vaultless encryption
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl Detokenize
impl Detokenize
Sourcepub fn new(ciphertext: String, tokenizer_name: String) -> Detokenize
pub fn new(ciphertext: String, tokenizer_name: String) -> Detokenize
detokenize is a command that decrypts text with a tokenizer