pub struct DynamicSecretCreateArtifactory {Show 17 fields
pub artifactory_admin_name: Option<String>,
pub artifactory_admin_pwd: Option<String>,
pub artifactory_token_audience: String,
pub artifactory_token_scope: String,
pub base_url: Option<String>,
pub custom_username_template: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub producer_encryption_key_name: Option<String>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretCreateArtifactory : dynamicSecretCreateArtifactory is a command that creates artifactory dynamic secret
Fields
artifactory_admin_name: Option<String>Artifactory Admin Name
artifactory_admin_pwd: Option<String>Artifactory Admin password
artifactory_token_audience: StringToken Audience
artifactory_token_scope: StringToken Scope
base_url: Option<String>Base URL
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
producer_encryption_key_name: Option<String>Dynamic producer encryption key
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
Implementations