pub struct DynamicSecretCreateAws {Show 36 fields
pub access_mode: Option<String>,
pub admin_rotation_interval_days: Option<i64>,
pub aws_access_key_id: Option<String>,
pub aws_access_secret_key: Option<String>,
pub aws_external_id: Option<String>,
pub aws_role_arns: Option<String>,
pub aws_user_console_access: Option<bool>,
pub aws_user_groups: Option<String>,
pub aws_user_policies: Option<String>,
pub aws_user_programmatic_access: Option<bool>,
pub custom_username_template: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub enable_admin_rotation: Option<bool>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub password_length: Option<String>,
pub producer_encryption_key_name: Option<String>,
pub region: Option<String>,
pub secure_access_aws_account_id: Option<String>,
pub secure_access_aws_native_cli: Option<bool>,
pub secure_access_bastion_issuer: Option<String>,
pub secure_access_certificate_issuer: Option<String>,
pub secure_access_delay: Option<i64>,
pub secure_access_enable: Option<String>,
pub secure_access_web: Option<bool>,
pub secure_access_web_browsing: Option<bool>,
pub secure_access_web_proxy: Option<bool>,
pub session_tags: Option<String>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub transitive_tag_keys: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretCreateAws : dynamicSecretCreateAws is a command that creates aws dynamic secret
Fields
access_mode: Option<String>admin_rotation_interval_days: Option<i64>Admin credentials rotation interval (days)
aws_access_key_id: Option<String>Access Key ID
aws_access_secret_key: Option<String>Secret Access Key
aws_external_id: Option<String>The AWS External ID associated with the AWS role (relevant only for assume_role mode)
aws_role_arns: Option<String>AWS Role ARNs to be used in the Assume Role operation (relevant only for assume_role mode)
aws_user_console_access: Option<bool>AWS User console access
aws_user_groups: Option<String>AWS User groups
aws_user_policies: Option<String>AWS User policies
aws_user_programmatic_access: Option<bool>Enable AWS User programmatic access
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
enable_admin_rotation: Option<bool>Automatic admin credentials rotation
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
password_length: Option<String>The length of the password to be generated
producer_encryption_key_name: Option<String>Dynamic producer encryption key
region: Option<String>Region
secure_access_aws_account_id: Option<String>The AWS account id
secure_access_aws_native_cli: Option<bool>The AWS native cli
secure_access_bastion_issuer: Option<String>Deprecated. use secure-access-certificate-issuer
secure_access_certificate_issuer: Option<String>Path to the SSH Certificate Issuer for your Akeyless Secure Access
secure_access_delay: Option<i64>The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_web: Option<bool>Enable Web Secure Remote Access
secure_access_web_browsing: Option<bool>Secure browser via Akeyless’s Secure Remote Access (SRA)
secure_access_web_proxy: Option<bool>Web-Proxy via Akeyless’s Secure Remote Access (SRA)
String of Key value session tags comma separated, relevant only for Assumed Role
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
transitive_tag_keys: Option<String>String of transitive tag keys space separated, relevant only for Assumed Role
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
Implementations
Sourceimpl DynamicSecretCreateAws
impl DynamicSecretCreateAws
Sourcepub fn new(name: String) -> DynamicSecretCreateAws
pub fn new(name: String) -> DynamicSecretCreateAws
dynamicSecretCreateAws is a command that creates aws dynamic secret