pub struct DynamicSecretCreateChef {Show 18 fields
pub chef_orgs: Option<String>,
pub chef_server_key: Option<String>,
pub chef_server_url: Option<String>,
pub chef_server_username: Option<String>,
pub custom_username_template: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub password_length: Option<String>,
pub producer_encryption_key_name: Option<String>,
pub skip_ssl: Option<bool>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretCreateChef : dynamicSecretCreateChef is a command that creates chef dynamic secret
Fields
chef_orgs: Option<String>Organizations
chef_server_key: Option<String>Server key
chef_server_url: Option<String>Server URL
chef_server_username: Option<String>Server username
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
password_length: Option<String>The length of the password to be generated
producer_encryption_key_name: Option<String>Dynamic producer encryption key
skip_ssl: Option<bool>Skip SSL
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
Implementations
Sourceimpl DynamicSecretCreateChef
impl DynamicSecretCreateChef
Sourcepub fn new(name: String) -> DynamicSecretCreateChef
pub fn new(name: String) -> DynamicSecretCreateChef
dynamicSecretCreateChef is a command that creates chef dynamic secret