pub struct DynamicSecretCreateDockerhub {Show 14 fields
pub delete_protection: Option<String>,
pub description: Option<String>,
pub dockerhub_password: Option<String>,
pub dockerhub_token_scopes: Option<String>,
pub dockerhub_username: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub producer_encryption_key_name: Option<String>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretCreateDockerhub : dynamicSecretCreateDockerhub is a command that creates a DOCKERHUB dynamic secret
Fields
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
dockerhub_password: Option<String>DockerhubPassword is either the user’s password access token to manage the repository
dockerhub_token_scopes: Option<String>Access token scopes list (comma-separated) to give the dynamic secret valid options are in "repo:admin", "repo:write", "repo:read", "repo:public_read"
dockerhub_username: Option<String>DockerhubUsername is the name of the user in dockerhub
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
producer_encryption_key_name: Option<String>Dynamic producer encryption key
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
Implementations
Sourceimpl DynamicSecretCreateDockerhub
impl DynamicSecretCreateDockerhub
Sourcepub fn new(name: String) -> DynamicSecretCreateDockerhub
pub fn new(name: String) -> DynamicSecretCreateDockerhub
dynamicSecretCreateDockerhub is a command that creates a DOCKERHUB dynamic secret