pub struct DynamicSecretCreateGcp {Show 28 fields
pub access_type: Option<String>,
pub custom_username_template: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub fixed_user_claim_keyname: Option<String>,
pub gcp_cred_type: Option<String>,
pub gcp_key: Option<String>,
pub gcp_key_algo: Option<String>,
pub gcp_project_id: Option<String>,
pub gcp_sa_email: Option<String>,
pub gcp_token_scopes: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub producer_encryption_key_name: Option<String>,
pub role_binding: Option<String>,
pub role_names: Option<String>,
pub secure_access_delay: Option<i64>,
pub secure_access_enable: Option<String>,
pub secure_access_url: Option<String>,
pub secure_access_web_browsing: Option<bool>,
pub secure_access_web_proxy: Option<bool>,
pub service_account_type: Option<String>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretCreateGcp : dynamicSecretCreateGcp is a command that creates a GCP dynamic secret
Fields
access_type: Option<String>custom_username_template: Option<String>Customize how temporary usernames are generated using go template
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
fixed_user_claim_keyname: Option<String>For externally provided users, denotes the key-name of IdP claim to extract the username from (Relevant only when –access-type=external)
gcp_cred_type: Option<String>gcp_key: Option<String>Base64-encoded service account private key text
gcp_key_algo: Option<String>Service account key algorithm, e.g. KEY_ALG_RSA_1024 (Relevant only when –access-type=sa and –gcp-cred-type=key)
gcp_project_id: Option<String>GCP Project ID override for dynamic secret operations
gcp_sa_email: Option<String>The email of the fixed service account to generate keys or tokens for (Relevant only when –access-type=sa and –service-account-type=fixed)
gcp_token_scopes: Option<String>Access token scopes list, e.g. scope1,scope2 (Relevant only when –access-type=sa; required when –gcp-cred-type=token)
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
producer_encryption_key_name: Option<String>Dynamic producer encryption key
role_binding: Option<String>Role binding definitions in JSON format (Relevant only when –access-type=sa and –service-account-type=dynamic)
role_names: Option<String>Comma-separated list of GCP roles to assign to the user (Relevant only when –access-type=external)
secure_access_delay: Option<i64>The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_url: Option<String>Destination URL to inject secrets
secure_access_web_browsing: Option<bool>Secure browser via Akeyless’s Secure Remote Access (SRA)
secure_access_web_proxy: Option<bool>Web-Proxy via Akeyless’s Secure Remote Access (SRA)
service_account_type: Option<String>The type of the GCP service account. Options [fixed, dynamic] (Relevant only when –access-type=sa)
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
Implementations
Sourceimpl DynamicSecretCreateGcp
impl DynamicSecretCreateGcp
Sourcepub fn new(name: String) -> DynamicSecretCreateGcp
pub fn new(name: String) -> DynamicSecretCreateGcp
dynamicSecretCreateGcp is a command that creates a GCP dynamic secret