pub struct DynamicSecretCreateGithub {Show 18 fields
pub delete_protection: Option<String>,
pub description: Option<String>,
pub github_app_id: Option<i64>,
pub github_app_private_key: Option<String>,
pub github_base_url: Option<String>,
pub installation_id: Option<i64>,
pub installation_organization: Option<String>,
pub installation_repository: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub token_permissions: Option<Vec<String>>,
pub token_repositories: Option<Vec<String>>,
pub token_ttl: Option<String>,
pub uid_token: Option<String>,
}Expand description
DynamicSecretCreateGithub : dynamicSecretCreateGithub is a command that creates github dynamic secret
Fields
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
github_app_id: Option<i64>Github app id
github_app_private_key: Option<String>App private key
github_base_url: Option<String>Base URL
installation_id: Option<i64>GitHub application installation id
installation_organization: Option<String>Optional, mutually exclusive with installation id, GitHub organization name
installation_repository: Option<String>Optional, mutually exclusive with installation id, GitHub repository ‘
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
token_permissions: Option<Vec<String>>Optional - installation token’s allowed permissions
token_repositories: Option<Vec<String>>Optional - installation token’s allowed repositories
token_ttl: Option<String>Token TTL
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl DynamicSecretCreateGithub
impl DynamicSecretCreateGithub
Sourcepub fn new(name: String) -> DynamicSecretCreateGithub
pub fn new(name: String) -> DynamicSecretCreateGithub
dynamicSecretCreateGithub is a command that creates github dynamic secret