DynamicSecretCreateLdap

Struct DynamicSecretCreateLdap 

pub struct DynamicSecretCreateLdap {
Show 33 fields pub provider_type: Option<String>, pub bind_dn: Option<String>, pub bind_dn_password: Option<String>, pub custom_username_template: Option<String>, pub delete_protection: Option<String>, pub description: Option<String>, pub external_username: Option<String>, pub fixed_user_claim_keyname: Option<String>, pub group_dn: Option<String>, pub host_provider: Option<String>, pub item_custom_fields: Option<HashMap<String, String>>, pub json: Option<bool>, pub ldap_ca_cert: Option<String>, pub ldap_url: Option<String>, pub name: String, pub password_length: Option<String>, pub producer_encryption_key_name: Option<String>, pub secure_access_bastion_issuer: Option<String>, pub secure_access_certificate_issuer: Option<String>, pub secure_access_delay: Option<i64>, pub secure_access_enable: Option<String>, pub secure_access_host: Option<Vec<String>>, pub secure_access_rd_gateway_server: Option<String>, pub secure_access_rdp_domain: Option<String>, pub tags: Option<Vec<String>>, pub target: Option<Vec<String>>, pub target_name: Option<String>, pub token: Option<String>, pub token_expiration: Option<String>, pub uid_token: Option<String>, pub user_attribute: Option<String>, pub user_dn: Option<String>, pub user_ttl: Option<String>,
}
DynamicSecretCreateLdap : dynamicSecretCreateLdap is a command that creates ldap dynamic secret

Fields

provider_type: Option<String>bind_dn: Option<String>

Bind DN

bind_dn_password: Option<String>

Bind DN Password

custom_username_template: Option<String>

Customize how temporary usernames are generated using go template

delete_protection: Option<String>

Protection from accidental deletion of this object [true/false]

description: Option<String>

Description of the object

external_username: Option<String>

Externally provided username [true/false]

fixed_user_claim_keyname: Option<String>

For externally provided users, denotes the key-name of IdP claim to extract the username from (relevant only for external-username=true)

group_dn: Option<String>

Group DN which the temporary user should be added

host_provider: Option<String>

Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret

item_custom_fields: Option<HashMap<String, String>>

Additional custom fields to associate with the item

json: Option<bool>

Set output format to JSON

ldap_ca_cert: Option<String>

CA Certificate File Content

ldap_url: Option<String>

LDAP Server URL

name: String

Dynamic secret name

password_length: Option<String>

The length of the password to be generated

producer_encryption_key_name: Option<String>

Dynamic producer encryption key

secure_access_bastion_issuer: Option<String>

Deprecated. use secure-access-certificate-issuer

secure_access_certificate_issuer: Option<String>

Path to the SSH Certificate Issuer for your Akeyless Secure Access

secure_access_delay: Option<i64>

The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds

secure_access_enable: Option<String>

Enable/Disable secure remote access [true/false]

secure_access_host: Option<Vec<String>>

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)

secure_access_rd_gateway_server: Option<String>

RD Gateway server

secure_access_rdp_domain: Option<String>

Required when the Dynamic Secret is used for a domain user

tags: Option<Vec<String>>

Add tags attached to this object

target: Option<Vec<String>>

A list of linked targets to be associated, Relevant only for Secure Remote Access for ssh cert issuer, ldap rotated secret and ldap dynamic secret, To specify multiple targets use argument multiple times

target_name: Option<String>

Target name

token: Option<String>

Authentication token (see /auth and /configure)

token_expiration: Option<String>

Token expiration

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

user_attribute: Option<String>

User Attribute

user_dn: Option<String>

User DN

user_ttl: Option<String>

User TTL

Implementations

Source

impl DynamicSecretCreateLdap

pub fn new(name: String) -> DynamicSecretCreateLdap

dynamicSecretCreateLdap is a command that creates ldap dynamic secret