pub struct DynamicSecretCreateOpenAi {Show 13 fields
pub custom_username_template: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub producer_encryption_key_name: Option<String>,
pub project_id: Option<String>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretCreateOpenAi : dynamicSecretCreateOpenAI is a command that creates OpenAI dynamic secret
Fields
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
producer_encryption_key_name: Option<String>Dynamic producer encryption key
project_id: Option<String>Project ID
Add tags attached to this object
target_name: Option<String>Name of existing target to use in producer creation
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
Implementations
Sourceimpl DynamicSecretCreateOpenAi
impl DynamicSecretCreateOpenAi
Sourcepub fn new(name: String) -> DynamicSecretCreateOpenAi
pub fn new(name: String) -> DynamicSecretCreateOpenAi
dynamicSecretCreateOpenAI is a command that creates OpenAI dynamic secret