pub struct DynamicSecretCreateRedis {Show 20 fields
pub acl_rules: Option<String>,
pub custom_username_template: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub host: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub password: Option<String>,
pub password_length: Option<String>,
pub port: Option<String>,
pub producer_encryption_key_name: Option<String>,
pub ssl: Option<bool>,
pub ssl_certificate: Option<String>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
pub username: Option<String>,
}Expand description
DynamicSecretCreateRedis : dynamicSecretCreateRedis is a command that creates Redis dynamic secret
Fields
acl_rules: Option<String>A JSON array list of redis ACL rules to attach to the created user. For available rules see the ACL CAT command https://redis.io/commands/acl-cat By default the user will have permissions to read all keys ‘["~*", "+@read"]’
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
host: Option<String>Redis Host
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
password: Option<String>Redis Password
password_length: Option<String>The length of the password to be generated
port: Option<String>Redis Port
producer_encryption_key_name: Option<String>Dynamic producer encryption key
ssl: Option<bool>Enable/Disable SSL [true/false]
ssl_certificate: Option<String>SSL CA certificate in base64 encoding generated from a trusted Certificate Authority (CA)
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
username: Option<String>Redis Username
Implementations
Sourceimpl DynamicSecretCreateRedis
impl DynamicSecretCreateRedis
Sourcepub fn new(name: String) -> DynamicSecretCreateRedis
pub fn new(name: String) -> DynamicSecretCreateRedis
dynamicSecretCreateRedis is a command that creates Redis dynamic secret