pub struct DynamicSecretList {
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
DynamicSecretList : dynamicSecretList is a command that returns a list of dynamic secrets
Fields
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl DynamicSecretList
impl DynamicSecretList
Sourcepub fn new() -> DynamicSecretList
pub fn new() -> DynamicSecretList
dynamicSecretList is a command that returns a list of dynamic secrets