pub struct DynamicSecretUpdateK8s {Show 36 fields
pub custom_username_template: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub k8s_allowed_namespaces: Option<String>,
pub k8s_cluster_ca_cert: Option<String>,
pub k8s_cluster_endpoint: Option<String>,
pub k8s_cluster_name: Option<String>,
pub k8s_cluster_token: Option<String>,
pub k8s_namespace: Option<String>,
pub k8s_predefined_role_name: Option<String>,
pub k8s_predefined_role_type: Option<String>,
pub k8s_rolebinding_yaml_data: Option<String>,
pub k8s_rolebinding_yaml_def: Option<String>,
pub k8s_service_account: Option<String>,
pub k8s_service_account_type: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub producer_encryption_key_name: Option<String>,
pub secure_access_allow_port_forwading: Option<bool>,
pub secure_access_bastion_issuer: Option<String>,
pub secure_access_certificate_issuer: Option<String>,
pub secure_access_cluster_endpoint: Option<String>,
pub secure_access_dashboard_url: Option<String>,
pub secure_access_delay: Option<i64>,
pub secure_access_enable: Option<String>,
pub secure_access_web: Option<bool>,
pub secure_access_web_browsing: Option<bool>,
pub secure_access_web_proxy: Option<bool>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub use_gw_service_account: Option<bool>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretUpdateK8s : dynamicSecretUpdateK8s is a command that updates k8s dynamic secret
Fields
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
k8s_allowed_namespaces: Option<String>Comma-separated list of allowed K8S namespaces for the generated ServiceAccount (relevant only for k8s-service-account-type=dynamic)
k8s_cluster_ca_cert: Option<String>K8S cluster CA certificate
k8s_cluster_endpoint: Option<String>K8S cluster URL endpoint
k8s_cluster_name: Option<String>K8S cluster name
k8s_cluster_token: Option<String>K8S cluster Bearer token
k8s_namespace: Option<String>K8S Namespace where the ServiceAccount exists.
k8s_predefined_role_name: Option<String>The pre-existing Role or ClusterRole name to bind the generated ServiceAccount to (relevant only for k8s-service-account-type=dynamic)
k8s_predefined_role_type: Option<String>Specifies the type of the pre-existing K8S role [Role, ClusterRole] (relevant only for k8s-service-account-type=dynamic)
k8s_rolebinding_yaml_data: Option<String>Content of the yaml in a Base64 format.
k8s_rolebinding_yaml_def: Option<String>Path to yaml file that contains definitions of K8S role and role binding (relevant only for k8s-service-account-type=dynamic)
k8s_service_account: Option<String>K8S ServiceAccount to extract token from.
k8s_service_account_type: Option<String>K8S ServiceAccount type [fixed, dynamic].
name: StringDynamic secret name
new_name: Option<String>Dynamic secret name
producer_encryption_key_name: Option<String>Dynamic producer encryption key
secure_access_allow_port_forwading: Option<bool>Enable Port forwarding while using CLI access
secure_access_bastion_issuer: Option<String>Deprecated. use secure-access-certificate-issuer
secure_access_certificate_issuer: Option<String>Path to the SSH Certificate Issuer for your Akeyless Secure Access
secure_access_cluster_endpoint: Option<String>The K8s cluster endpoint URL
secure_access_dashboard_url: Option<String>The K8s dashboard url
secure_access_delay: Option<i64>The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_web: Option<bool>Enable Web Secure Remote Access
secure_access_web_browsing: Option<bool>Secure browser via Akeyless’s Secure Remote Access (SRA)
secure_access_web_proxy: Option<bool>Web-Proxy via Akeyless’s Secure Remote Access (SRA)
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
use_gw_service_account: Option<bool>Use the GW’s service account
user_ttl: Option<String>User TTL
Implementations
Sourceimpl DynamicSecretUpdateK8s
impl DynamicSecretUpdateK8s
Sourcepub fn new(name: String) -> DynamicSecretUpdateK8s
pub fn new(name: String) -> DynamicSecretUpdateK8s
dynamicSecretUpdateK8s is a command that updates k8s dynamic secret