pub struct DynamicSecretUpdateMsSql {Show 30 fields
pub custom_username_template: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub mssql_allowed_db_names: Option<String>,
pub mssql_create_statements: Option<String>,
pub mssql_dbname: Option<String>,
pub mssql_host: Option<String>,
pub mssql_password: Option<String>,
pub mssql_port: Option<String>,
pub mssql_revocation_statements: Option<String>,
pub mssql_username: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub password_length: Option<String>,
pub producer_encryption_key_name: Option<String>,
pub secure_access_bastion_issuer: Option<String>,
pub secure_access_certificate_issuer: Option<String>,
pub secure_access_db_name: Option<String>,
pub secure_access_db_schema: Option<String>,
pub secure_access_delay: Option<i64>,
pub secure_access_enable: Option<String>,
pub secure_access_host: Option<Vec<String>>,
pub secure_access_web: Option<bool>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretUpdateMsSql : dynamicSecretUpdateMsSql is a command that updates mssql dynamic secret
Fields
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
mssql_allowed_db_names: Option<String>CSV of allowed DB names for runtime selection when getting the secret value. Empty => use target DB only; "*" => any DB allowed; One or more names => user must choose from this list
mssql_create_statements: Option<String>MSSQL Creation statements
mssql_dbname: Option<String>MSSQL Name
mssql_host: Option<String>MSSQL Host
mssql_password: Option<String>MSSQL Password
mssql_port: Option<String>MSSQL Port
mssql_revocation_statements: Option<String>MSSQL Revocation statements
mssql_username: Option<String>MSSQL Username
name: StringDynamic secret name
new_name: Option<String>Dynamic secret name
password_length: Option<String>The length of the password to be generated
producer_encryption_key_name: Option<String>Dynamic producer encryption key
secure_access_bastion_issuer: Option<String>Deprecated. use secure-access-certificate-issuer
secure_access_certificate_issuer: Option<String>Path to the SSH Certificate Issuer for your Akeyless Secure Access
secure_access_db_name: Option<String>The DB name (relevant only for DB Dynamic-Secret)
secure_access_db_schema: Option<String>The DB schema
secure_access_delay: Option<i64>The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_host: Option<Vec<String>>Target DB servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts)
secure_access_web: Option<bool>Enable Web Secure Remote Access
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
Implementations
Sourceimpl DynamicSecretUpdateMsSql
impl DynamicSecretUpdateMsSql
Sourcepub fn new(name: String) -> DynamicSecretUpdateMsSql
pub fn new(name: String) -> DynamicSecretUpdateMsSql
dynamicSecretUpdateMsSql is a command that updates mssql dynamic secret