pub struct DynamicSecretUpdateMySql {Show 32 fields
pub custom_username_template: Option<String>,
pub db_server_certificates: Option<String>,
pub db_server_name: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub mysql_dbname: Option<String>,
pub mysql_host: Option<String>,
pub mysql_password: Option<String>,
pub mysql_port: Option<String>,
pub mysql_revocation_statements: Option<String>,
pub mysql_screation_statements: Option<String>,
pub mysql_username: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub password_length: Option<String>,
pub producer_encryption_key_name: Option<String>,
pub secure_access_bastion_issuer: Option<String>,
pub secure_access_certificate_issuer: Option<String>,
pub secure_access_db_name: Option<String>,
pub secure_access_delay: Option<i64>,
pub secure_access_enable: Option<String>,
pub secure_access_host: Option<Vec<String>>,
pub secure_access_web: Option<bool>,
pub ssl: Option<bool>,
pub ssl_certificate: Option<String>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretUpdateMySql : dynamicSecretUpdateMySql is a command that updates mysql dynamic secret
Fields
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
db_server_certificates: Option<String>(Optional) DB server certificates
db_server_name: Option<String>(Optional) Server name for certificate verification
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
mysql_dbname: Option<String>MySQL DB Name
mysql_host: Option<String>MySQL Host
mysql_password: Option<String>MySQL Password
mysql_port: Option<String>MySQL Port
mysql_revocation_statements: Option<String>MySQL Revocation statements
mysql_screation_statements: Option<String>MySQL Creation statements
mysql_username: Option<String>MySQL Username
name: StringDynamic secret name
new_name: Option<String>Dynamic secret name
password_length: Option<String>The length of the password to be generated
producer_encryption_key_name: Option<String>Dynamic producer encryption key
secure_access_bastion_issuer: Option<String>Deprecated. use secure-access-certificate-issuer
secure_access_certificate_issuer: Option<String>Path to the SSH Certificate Issuer for your Akeyless Secure Access
secure_access_db_name: Option<String>The DB name (relevant only for DB Dynamic-Secret)
secure_access_delay: Option<i64>The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_host: Option<Vec<String>>Target DB servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts)
secure_access_web: Option<bool>Enable Web Secure Remote Access
ssl: Option<bool>Enable/Disable SSL [true/false]
ssl_certificate: Option<String>SSL connection certificate
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
Implementations
Sourceimpl DynamicSecretUpdateMySql
impl DynamicSecretUpdateMySql
Sourcepub fn new(name: String) -> DynamicSecretUpdateMySql
pub fn new(name: String) -> DynamicSecretUpdateMySql
dynamicSecretUpdateMySql is a command that updates mysql dynamic secret