DynamicSecretUpdateRdp

Struct DynamicSecretUpdateRdp 

pub struct DynamicSecretUpdateRdp {
Show 32 fields pub allow_user_extend_session: Option<i64>, pub custom_username_template: Option<String>, pub delete_protection: Option<String>, pub description: Option<String>, pub fixed_user_claim_keyname: Option<String>, pub fixed_user_only: Option<String>, pub item_custom_fields: Option<HashMap<String, String>>, pub json: Option<bool>, pub name: String, pub new_name: Option<String>, pub password_length: Option<String>, pub producer_encryption_key_name: Option<String>, pub rdp_admin_name: Option<String>, pub rdp_admin_pwd: Option<String>, pub rdp_host_name: Option<String>, pub rdp_host_port: Option<String>, pub rdp_user_groups: Option<String>, pub secure_access_allow_external_user: Option<bool>, pub secure_access_bastion_issuer: Option<String>, pub secure_access_certificate_issuer: Option<String>, pub secure_access_delay: Option<i64>, pub secure_access_enable: Option<String>, pub secure_access_host: Option<Vec<String>>, pub secure_access_rd_gateway_server: Option<String>, pub secure_access_rdp_domain: Option<String>, pub secure_access_rdp_user: Option<String>, pub tags: Option<Vec<String>>, pub target_name: Option<String>, pub token: Option<String>, pub uid_token: Option<String>, pub user_ttl: Option<String>, pub warn_user_before_expiration: Option<i64>,
}
DynamicSecretUpdateRdp : dynamicSecretUpdateRdp is a command that updates rdp dynamic secret

Fields

allow_user_extend_session: Option<i64>

AllowUserExtendSession

custom_username_template: Option<String>

Customize how temporary usernames are generated using go template

delete_protection: Option<String>

Protection from accidental deletion of this object [true/false]

description: Option<String>

Description of the object

fixed_user_claim_keyname: Option<String>

For externally provided users, denotes the key-name of IdP claim to extract the username from (relevant only for fixed-user-only=true)

fixed_user_only: Option<String>

Allow access using externally (IdP) provided username [true/false]

item_custom_fields: Option<HashMap<String, String>>

Additional custom fields to associate with the item

json: Option<bool>

Set output format to JSON

name: String

Dynamic secret name

new_name: Option<String>

Dynamic secret name

password_length: Option<String>

The length of the password to be generated

producer_encryption_key_name: Option<String>

Dynamic producer encryption key

rdp_admin_name: Option<String>

RDP Admin Name

rdp_admin_pwd: Option<String>

RDP Admin password

rdp_host_name: Option<String>

Hostname

rdp_host_port: Option<String>

Port

rdp_user_groups: Option<String>

Groups

secure_access_allow_external_user: Option<bool>

Allow providing external user for a domain users

secure_access_bastion_issuer: Option<String>

Deprecated. use secure-access-certificate-issuer

secure_access_certificate_issuer: Option<String>

Path to the SSH Certificate Issuer for your Akeyless Secure Access

secure_access_delay: Option<i64>

The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds

secure_access_enable: Option<String>

Enable/Disable secure remote access [true/false]

secure_access_host: Option<Vec<String>>

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)

secure_access_rd_gateway_server: Option<String>

RD Gateway server

secure_access_rdp_domain: Option<String>

Required when the Dynamic Secret is used for a domain user

secure_access_rdp_user: Option<String>

Override the RDP Domain username

tags: Option<Vec<String>>

Add tags attached to this object

target_name: Option<String>

Target name

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

user_ttl: Option<String>

User TTL

warn_user_before_expiration: Option<i64>

WarnBeforeUserExpiration

Implementations

Source

impl DynamicSecretUpdateRdp

pub fn new(name: String) -> DynamicSecretUpdateRdp

dynamicSecretUpdateRdp is a command that updates rdp dynamic secret