pub struct DynamicSecretUpdateRedshift {Show 23 fields
pub creation_statements: Option<String>,
pub custom_username_template: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub new_name: Option<String>,
pub password_length: Option<String>,
pub producer_encryption_key: Option<String>,
pub redshift_db_name: Option<String>,
pub redshift_host: Option<String>,
pub redshift_password: Option<String>,
pub redshift_port: Option<String>,
pub redshift_username: Option<String>,
pub secure_access_enable: Option<String>,
pub secure_access_host: Option<Vec<String>>,
pub ssl: Option<bool>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretUpdateRedshift : dynamicSecretUpdateRedshift is a command that updates redshift dynamic secret
Fields
creation_statements: Option<String>Redshift Creation statements
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
new_name: Option<String>Dynamic secret name
password_length: Option<String>The length of the password to be generated
producer_encryption_key: Option<String>Dynamic producer encryption key
redshift_db_name: Option<String>Redshift DB Name
redshift_host: Option<String>Redshift Host
redshift_password: Option<String>Redshift Password
redshift_port: Option<String>Redshift Port
redshift_username: Option<String>Redshift Username
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_host: Option<Vec<String>>Target DB servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts)
ssl: Option<bool>Enable/Disable SSL [true/false]
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
Implementations
Sourceimpl DynamicSecretUpdateRedshift
impl DynamicSecretUpdateRedshift
Sourcepub fn new(name: String) -> DynamicSecretUpdateRedshift
pub fn new(name: String) -> DynamicSecretUpdateRedshift
dynamicSecretUpdateRedshift is a command that updates redshift dynamic secret