pub struct DynamicSecretUpdateSnowflake {Show 23 fields
pub account: Option<String>,
pub account_password: Option<String>,
pub account_username: Option<String>,
pub auth_mode: Option<String>,
pub custom_username_template: Option<String>,
pub db_name: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub key_algo: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub password_length: Option<String>,
pub private_key: Option<String>,
pub private_key_passphrase: Option<String>,
pub role: Option<String>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
pub warehouse: Option<String>,
}Expand description
DynamicSecretUpdateSnowflake : GatewayUpdateProducerSnowflakeCmd is a command that updates a Snowflake dynamic secret
Fields
account: Option<String>Account name
account_password: Option<String>Database Password
account_username: Option<String>Database Username
auth_mode: Option<String>The authentication mode for the temporary user [password/key]
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
db_name: Option<String>Database name
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
key_algo: Option<String>name: StringDynamic secret name
new_name: Option<String>Dynamic secret name
password_length: Option<String>The length of the password to be generated
private_key: Option<String>RSA Private key (base64 encoded)
private_key_passphrase: Option<String>The Private key passphrase
role: Option<String>User role
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
warehouse: Option<String>Warehouse name
Implementations
Sourceimpl DynamicSecretUpdateSnowflake
impl DynamicSecretUpdateSnowflake
Sourcepub fn new(name: String) -> DynamicSecretUpdateSnowflake
pub fn new(name: String) -> DynamicSecretUpdateSnowflake
GatewayUpdateProducerSnowflakeCmd is a command that updates a Snowflake dynamic secret