Encrypt

Struct Encrypt 

pub struct Encrypt {
    pub display_id: Option<String>,
    pub encryption_context: Option<HashMap<String, String>>,
    pub input_format: Option<String>,
    pub item_id: Option<i64>,
    pub json: Option<bool>,
    pub key_name: String,
    pub plaintext: Option<String>,
    pub token: Option<String>,
    pub uid_token: Option<String>,
    pub version: Option<i32>,
}

Fields

display_id: Option<String>

The display id of the key to use in the encryption process

encryption_context: Option<HashMap<String, String>>

name-value pair that specifies the encryption context to be used for authenticated encryption. If used here, the same value must be supplied to the decrypt command or decryption will fail

input_format: Option<String>

Select default assumed format for any plaintext input. Currently supported options: [base64]

item_id: Option<i64>

The item id of the key to use in the encryption process

json: Option<bool>

Set output format to JSON

key_name: String

The name of the key to use in the encryption process

plaintext: Option<String>

Data to be encrypted

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

version: Option<i32>

key version (relevant only for classic key)

Implementations

Source

impl Encrypt

pub fn new(key_name: String) -> Encrypt