pub struct EncryptFile {
pub display_id: Option<String>,
pub in: String,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub key_name: String,
pub out: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
display_id: Option<String>The display id of the key to use in the encryption process
in: StringPath to the file to be encrypted. If not provided, the content will be taken from stdin
item_id: Option<i64>The item id of the key to use in the encryption process
json: Option<bool>Set output format to JSON
key_name: StringThe name of the key to use in the encryption process
out: Option<String>Path to the output file. If not provided, the output will be sent to stdout
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl EncryptFile
impl EncryptFile
pub fn new(in: String, key_name: String) -> EncryptFile