pub struct EncryptGpg {
pub display_id: Option<String>,
pub input_format: Option<String>,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub key_name: String,
pub plaintext: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
display_id: Option<String>The display id of the key to use in the encryption process
input_format: Option<String>If specified, the plaintext input is assumed to be formatted accordingly. Current supported options: [base64]
item_id: Option<i64>The item id of the key to use in the encryption process
json: Option<bool>Set output format to JSON
key_name: StringThe name of the key to use in the encryption process
plaintext: StringData to be encrypted
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl EncryptGpg
impl EncryptGpg
pub fn new(key_name: String, plaintext: String) -> EncryptGpg