pub struct EncryptWithClassicKey {
pub display_id: String,
pub ignore_cache: Option<String>,
pub json: Option<bool>,
pub plaintext: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: i32,
}Fields
display_id: StringThe name of the key to use in the encryption process
ignore_cache: Option<String>Retrieve the Secret value without checking the Gateway’s cache [true/false]. This flag is only relevant when using the RestAPI
json: Option<bool>Set output format to JSON
plaintext: StringData to be encrypted
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: i32classic key version
Implementations