pub struct EsmCreate {
pub binary_value: Option<bool>,
pub description: Option<String>,
pub esm_name: String,
pub json: Option<bool>,
pub secret_name: String,
pub tags: Option<HashMap<String, String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub value: String,
}Expand description
EsmCreate : esmCreate is a command that creates a new secret in an External Secrets Manager
Fields
binary_value: Option<bool>Use this option if the external secret value is a base64 encoded binary
description: Option<String>Description of the external secret
esm_name: StringName of the External Secrets Manager item
json: Option<bool>Set output format to JSON
secret_name: StringName for the new external secret
Tags for the external secret
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
value: StringValue of the external secret item, either text or base64 encoded binary
Implementations