pub struct EsmGet {
pub esm_name: String,
pub json: Option<bool>,
pub secret_id: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
EsmGet : esmGet is a command that gets the value and interal details of a secret from an External Secrets Manager
Fields
esm_name: StringName of the External Secrets Manager item
json: Option<bool>Set output format to JSON
secret_id: StringThe secret id (or name, for AWS, Azure or K8s targets) to get from the External Secrets Manager
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations