EventForwarderCreateServiceNow

Struct EventForwarderCreateServiceNow 

pub struct EventForwarderCreateServiceNow {
Show 21 fields pub admin_name: Option<String>, pub admin_pwd: Option<String>, pub app_private_key_base64: Option<String>, pub auth_methods_event_source_locations: Option<Vec<String>>, pub auth_type: Option<String>, pub client_id: Option<String>, pub client_secret: Option<String>, pub description: Option<String>, pub event_types: Option<Vec<String>>, pub every: Option<String>, pub gateways_event_source_locations: Vec<String>, pub host: Option<String>, pub items_event_source_locations: Option<Vec<String>>, pub json: Option<bool>, pub key: Option<String>, pub name: String, pub runner_type: String, pub targets_event_source_locations: Option<Vec<String>>, pub token: Option<String>, pub uid_token: Option<String>, pub user_email: Option<String>,
}
EventForwarderCreateServiceNow : eventForwarderCreateServiceNow is a command that creates service-now event forwarder

Fields

admin_name: Option<String>

Workstation Admin Name

admin_pwd: Option<String>

Workstation Admin Password

app_private_key_base64: Option<String>

The RSA Private Key to use when connecting with jwt authentication

auth_methods_event_source_locations: Option<Vec<String>>

Auth Method Event sources

auth_type: Option<String>

The authentication type to use [user-pass/jwt]

client_id: Option<String>

The client ID to use when connecting with jwt authentication

client_secret: Option<String>

The client secret to use when connecting with jwt authentication

description: Option<String>

Description of the object

event_types: Option<Vec<String>>

List of event types to notify about [request-access, certificate-pending-expiration, certificate-expired, certificate-provisioning-success, certificate-provisioning-failure, auth-method-pending-expiration, auth-method-expired, next-automatic-rotation, rotated-secret-success, rotated-secret-failure, dynamic-secret-failure, multi-auth-failure, uid-rotation-failure, apply-justification, email-auth-method-approved, usage, rotation-usage, gateway-inactive, static-secret-updated, rate-limiting, usage-report, secret-sync]

every: Option<String>

Rate of periodic runner repetition in hours

gateways_event_source_locations: Vec<String>

Event sources

host: Option<String>

Workstation Host

items_event_source_locations: Option<Vec<String>>

Items Event sources

json: Option<bool>

Set output format to JSON

key: Option<String>

The name of a key that used to encrypt the EventForwarder secret value (if empty, the account default protectionKey key will be used)

name: String

EventForwarder name

runner_type: Stringtargets_event_source_locations: Option<Vec<String>>

Targets Event sources

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

user_email: Option<String>

The user email to identify with when connecting with jwt authentication

Implementations

Source

impl EventForwarderCreateServiceNow

pub fn new( gateways_event_source_locations: Vec<String>, name: String, runner_type: String, ) -> EventForwarderCreateServiceNow

eventForwarderCreateServiceNow is a command that creates service-now event forwarder