pub struct EventForwarderCreateSlack {Show 14 fields
pub auth_methods_event_source_locations: Option<Vec<String>>,
pub description: Option<String>,
pub event_types: Option<Vec<String>>,
pub every: Option<String>,
pub gateways_event_source_locations: Vec<String>,
pub items_event_source_locations: Option<Vec<String>>,
pub json: Option<bool>,
pub key: Option<String>,
pub name: String,
pub runner_type: String,
pub targets_event_source_locations: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub url: String,
}Expand description
EventForwarderCreateSlack : eventForwarderCreateSlack is a command that creates slack event forwarder
Fields
auth_methods_event_source_locations: Option<Vec<String>>Auth Method Event sources
description: Option<String>Description of the object
event_types: Option<Vec<String>>List of event types to notify about [request-access, certificate-pending-expiration, certificate-expired, certificate-provisioning-success, certificate-provisioning-failure, auth-method-pending-expiration, auth-method-expired, next-automatic-rotation, rotated-secret-success, rotated-secret-failure, dynamic-secret-failure, multi-auth-failure, uid-rotation-failure, apply-justification, email-auth-method-approved, usage, rotation-usage, gateway-inactive, static-secret-updated, rate-limiting, usage-report, secret-sync]
every: Option<String>Rate of periodic runner repetition in hours
gateways_event_source_locations: Vec<String>Event sources
items_event_source_locations: Option<Vec<String>>Items Event sources
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the EventForwarder secret value (if empty, the account default protectionKey key will be used)
name: StringEventForwarder name
runner_type: Stringtargets_event_source_locations: Option<Vec<String>>Targets Event sources
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
url: StringSlack Webhook URL
Implementations