pub struct EventForwarderUpdateServiceNow {Show 22 fields
pub admin_name: Option<String>,
pub admin_pwd: Option<String>,
pub app_private_key_base64: Option<String>,
pub auth_methods_event_source_locations: Option<Vec<String>>,
pub auth_type: Option<String>,
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub description: Option<String>,
pub enable: Option<String>,
pub event_types: Option<Vec<String>>,
pub gateways_event_source_locations: Vec<String>,
pub host: Option<String>,
pub items_event_source_locations: Option<Vec<String>>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub targets_event_source_locations: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_email: Option<String>,
}Expand description
EventForwarderUpdateServiceNow : eventForwarderUpdateServiceNow is a command that updates service now event forwarder
Fields
admin_name: Option<String>Workstation Admin Name
admin_pwd: Option<String>Workstation Admin Password
app_private_key_base64: Option<String>The RSA Private Key to use when connecting with jwt authentication
auth_methods_event_source_locations: Option<Vec<String>>Auth Method Event sources
auth_type: Option<String>The authentication type to use [user-pass/jwt]
client_id: Option<String>The client ID to use when connecting with jwt authentication
client_secret: Option<String>The client secret to use when connecting with jwt authentication
description: Option<String>Description of the object
enable: Option<String>Enable/Disable Event Forwarder [true/false]
event_types: Option<Vec<String>>List of event types to notify about [request-access, certificate-pending-expiration, certificate-expired, certificate-provisioning-success, certificate-provisioning-failure, auth-method-pending-expiration, auth-method-expired, next-automatic-rotation, rotated-secret-success, rotated-secret-failure, dynamic-secret-failure, multi-auth-failure, uid-rotation-failure, apply-justification, email-auth-method-approved, usage, rotation-usage, gateway-inactive, static-secret-updated, rate-limiting, usage-report, secret-sync]
gateways_event_source_locations: Vec<String>Event sources
host: Option<String>Workstation Host
items_event_source_locations: Option<Vec<String>>Items Event sources
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the EventForwarder secret value (if empty, the account default protectionKey key will be used)
name: StringEventForwarder name
new_name: Option<String>New EventForwarder name
targets_event_source_locations: Option<Vec<String>>Targets Event sources
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_email: Option<String>The user email to identify with when connecting with jwt authentication
Implementations