pub struct EventForwarderUpdateTeams {Show 15 fields
pub auth_methods_event_source_locations: Option<Vec<String>>,
pub description: Option<String>,
pub enable: Option<String>,
pub event_types: Option<Vec<String>>,
pub gateways_event_source_locations: Vec<String>,
pub items_event_source_locations: Option<Vec<String>>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub targets_event_source_locations: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub url: String,
}Expand description
EventForwarderUpdateTeams : eventForwarderUpdateTeams is a command that updates teams event forwarder
Fields
auth_methods_event_source_locations: Option<Vec<String>>Auth Method Event sources
description: Option<String>Description of the object
enable: Option<String>Enable/Disable Event Forwarder [true/false]
event_types: Option<Vec<String>>List of event types to notify about [request-access, certificate-pending-expiration, certificate-expired, certificate-provisioning-success, certificate-provisioning-failure, auth-method-pending-expiration, auth-method-expired, next-automatic-rotation, rotated-secret-success, rotated-secret-failure, dynamic-secret-failure, multi-auth-failure, uid-rotation-failure, apply-justification, email-auth-method-approved, usage, rotation-usage, gateway-inactive, static-secret-updated, rate-limiting, usage-report, secret-sync]
gateways_event_source_locations: Vec<String>Event sources
items_event_source_locations: Option<Vec<String>>Items Event sources
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the EventForwarder secret value (if empty, the account default protectionKey key will be used)
name: StringEventForwarder name
new_name: Option<String>New EventForwarder name
targets_event_source_locations: Option<Vec<String>>Targets Event sources
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
url: StringTeams Webhook URL
Implementations