pub struct ExportClassicKey {
pub accessibility: Option<String>,
pub export_public_key: Option<bool>,
pub ignore_cache: Option<String>,
pub json: Option<bool>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: Option<i32>,
pub wrapping_key_name: Option<String>,
}Expand description
ExportClassicKey : ExportClassicKey is a command that returns the classic key material
Fields
accessibility: Option<String>for personal password manager
export_public_key: Option<bool>Use this option to output only public key
ignore_cache: Option<String>Retrieve the Secret value without checking the Gateway’s cache [true/false]. This flag is only relevant when using the RestAPI
json: Option<bool>Set output format to JSON
name: StringClassicKey name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: Option<i32>Classic key version
wrapping_key_name: Option<String>Classic key name to wrap the key material with
Implementations
Sourceimpl ExportClassicKey
impl ExportClassicKey
Sourcepub fn new(name: String) -> ExportClassicKey
pub fn new(name: String) -> ExportClassicKey
ExportClassicKey is a command that returns the classic key material