pub struct FolderUpdate {
pub accessibility: Option<String>,
pub add_tag: Option<Vec<String>>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub json: Option<bool>,
pub name: String,
pub rm_tag: Option<Vec<String>>,
pub token: Option<String>,
pub type: Option<String>,
pub uid_token: Option<String>,
}Expand description
FolderUpdate : folderUpdate is a command that updates folder
Fields
accessibility: Option<String>for personal password manager
add_tag: Option<Vec<String>>List of the new tags that will be attached to this folder
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
name: StringFolder name
rm_tag: Option<Vec<String>>List of the existent tags that will be removed from this folder
token: Option<String>Authentication token (see /auth and /configure)
type: Option<String>uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl FolderUpdate
impl FolderUpdate
Sourcepub fn new(name: String) -> FolderUpdate
pub fn new(name: String) -> FolderUpdate
folderUpdate is a command that updates folder