pub struct GatewayGetLogForwarding {
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayGetLogForwarding : gatewayGetLogForwarding is a command to get log forwarding configuration
Fields
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayGetLogForwarding
impl GatewayGetLogForwarding
Sourcepub fn new() -> GatewayGetLogForwarding
pub fn new() -> GatewayGetLogForwarding
gatewayGetLogForwarding is a command to get log forwarding configuration