pub struct GatewayGetRemoteAccess {
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayGetRemoteAccess : gatewayGetRemoteAccess is a command that returns remote access config
Fields
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayGetRemoteAccess
impl GatewayGetRemoteAccess
Sourcepub fn new() -> GatewayGetRemoteAccess
pub fn new() -> GatewayGetRemoteAccess
gatewayGetRemoteAccess is a command that returns remote access config