pub struct GatewayGetTmpUsers {
pub json: Option<bool>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayGetTmpUsers : gatewayGetTmpUsers is a command that returns gateway configuration [Deprecated: Use dynamic-secret-tmp-creds-get command]
Fields
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayGetTmpUsers
impl GatewayGetTmpUsers
Sourcepub fn new(name: String) -> GatewayGetTmpUsers
pub fn new(name: String) -> GatewayGetTmpUsers
gatewayGetTmpUsers is a command that returns gateway configuration [Deprecated: Use dynamic-secret-tmp-creds-get command]