pub struct GatewayRevokeTmpUsers {
pub host: Option<String>,
pub json: Option<bool>,
pub name: String,
pub revoke_all: Option<bool>,
pub soft_delete: Option<bool>,
pub tmp_creds_id: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayRevokeTmpUsers : gatewayRevokeTmpUsers is a command that revoke producer tmp user [Deprecated: Use dynamic-secret-tmp-creds-delete command]
Fields
host: Option<String>Host
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
revoke_all: Option<bool>Revoke All Temp Creds
soft_delete: Option<bool>Soft Delete
tmp_creds_id: Option<String>Tmp Creds ID
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayRevokeTmpUsers
impl GatewayRevokeTmpUsers
Sourcepub fn new(name: String) -> GatewayRevokeTmpUsers
pub fn new(name: String) -> GatewayRevokeTmpUsers
gatewayRevokeTmpUsers is a command that revoke producer tmp user [Deprecated: Use dynamic-secret-tmp-creds-delete command]