pub struct GatewayUpdateAllowedAccess {
pub sub_claims_case_insensitive: Option<bool>,
pub access_id: String,
pub case_sensitive: Option<String>,
pub description: Option<String>,
pub json: Option<bool>,
pub name: String,
pub new_name: Option<String>,
pub permissions: Option<String>,
pub sub_claims: Option<HashMap<String, String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayUpdateAllowedAccess : gatewayUpdateAllowedAccess is a command that update allowed access in Gator
Fields
sub_claims_case_insensitive: Option<bool>access_id: StringAccess ID The access id to be attached to this allowed access. Auth method with this access id should already exist.
case_sensitive: Option<String>Treat sub claims as case-sensitive [true/false]
description: Option<String>Allowed access description
json: Option<bool>Set output format to JSON
name: StringAllowed access name
new_name: Option<String>New allowed access name
permissions: Option<String>Permissions Comma-seperated list of permissions for this allowed access. Available permissions: [defaults,targets,classic_keys,automatic_migration,ldap_auth,dynamic_secret,k8s_auth,log_forwarding,zero_knowledge_encryption,rotated_secret,caching,event_forwarding,admin,kmip,general,rotate_secret_value]
sub_claims: Option<HashMap<String, String>>Sub claims key/val of sub claims, e.g group=admins,developers
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayUpdateAllowedAccess
impl GatewayUpdateAllowedAccess
Sourcepub fn new(access_id: String, name: String) -> GatewayUpdateAllowedAccess
pub fn new(access_id: String, name: String) -> GatewayUpdateAllowedAccess
gatewayUpdateAllowedAccess is a command that update allowed access in Gator