pub struct GatewayUpdateCache {
pub backup_interval: Option<String>,
pub enable_cache: Option<String>,
pub enable_proactive: Option<String>,
pub json: Option<bool>,
pub minimum_fetch_interval: Option<String>,
pub stale_timeout: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayUpdateCache : gatewayUpdateCache is a command that updates cache settings
Fields
backup_interval: Option<String>Secure backup interval in minutes. To ensure service continuity in case of power cycle and network outage secrets will be backed up periodically per backup interval
enable_cache: Option<String>Enable cache [true/false]
enable_proactive: Option<String>Enable proactive caching [true/false]
json: Option<bool>Set output format to JSON
minimum_fetch_interval: Option<String>When using Cache or/and Proactive Cache, additional secrets will be fetched upon requesting a secret, based on the requestor’s access policy. Define minimum fetching interval to avoid over fetching in a given time frame
stale_timeout: Option<String>Stale timeout in minutes, cache entries which are not accessed within timeout will be removed from cache
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayUpdateCache
impl GatewayUpdateCache
Sourcepub fn new() -> GatewayUpdateCache
pub fn new() -> GatewayUpdateCache
gatewayUpdateCache is a command that updates cache settings