GatewayUpdateItem

Struct GatewayUpdateItem 

pub struct GatewayUpdateItem {
Show 30 fields pub add_tag: Option<Vec<String>>, pub api_id: Option<String>, pub api_key: Option<String>, pub app_id: Option<String>, pub auto_rotate: Option<String>, pub custom_payload: Option<String>, pub delete_protection: Option<String>, pub description: Option<String>, pub gcp_key: Option<String>, pub gcp_service_account_email: Option<String>, pub gcp_service_account_key_id: Option<String>, pub grace_rotation: Option<String>, pub json: Option<bool>, pub keep_prev_version: Option<String>, pub key: Option<String>, pub name: String, pub new_metadata: Option<String>, pub new_name: Option<String>, pub new_version: Option<bool>, pub password_length: Option<String>, pub rm_tag: Option<Vec<String>>, pub rotated_password: Option<String>, pub rotated_username: Option<String>, pub rotation_event_in: Option<Vec<String>>, pub rotation_hour: Option<i32>, pub rotation_interval: Option<String>, pub rotator_creds_type: Option<String>, pub token: Option<String>, pub type: String, pub uid_token: Option<String>,
}
GatewayUpdateItem : gatewayUpdateItem is a command that updates classic key

Fields

add_tag: Option<Vec<String>>

List of the new tags that will be attached to this item

api_id: Option<String>

API ID to rotate (relevant only for rotator-type=api-key)

api_key: Option<String>

API key to rotate (relevant only for rotator-type=api-key)

app_id: Option<String>

ApplicationId (used in azure)

auto_rotate: Option<String>

Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]

custom_payload: Option<String>

Secret payload to be sent with rotation request (relevant only for rotator-type=custom)

delete_protection: Option<String>

Protection from accidental deletion of this object [true/false]

description: Option<String>

Description of the object

gcp_key: Option<String>

Base64-encoded service account private key text

gcp_service_account_email: Option<String>

The email of the gcp service account to rotate

gcp_service_account_key_id: Option<String>

The key id of the gcp service account to rotate

grace_rotation: Option<String>

Create a new access key without deleting the old key from AWS for backup (relevant only for AWS) [true/false]

json: Option<bool>

Set output format to JSON

keep_prev_version: Option<String>

Whether to keep previous version [true/false]. (relevant only for –type=rotated-secret). If not set, use default according to account settings

key: Option<String>

The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)

name: String

Item name

new_metadata: Option<String>

Deprecated - use description

new_name: Option<String>

New item name

new_version: Option<bool>

Deprecated

password_length: Option<String>

The length of the password to be generated

rm_tag: Option<Vec<String>>

List of the existent tags that will be removed from this item

rotated_password: Option<String>

rotated-username password (relevant only for rotator-type=password)

rotated_username: Option<String>

username to be rotated, if selected \"use-self-creds\" at rotator-creds-type, this username will try to rotate it’s own password, if \"use-target-creds\" is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=password)

rotation_event_in: Option<Vec<String>>

How many days before the rotation of the item would you like to be notified

rotation_hour: Option<i32>

The Rotation Hour

rotation_interval: Option<String>

The number of days to wait between every automatic key rotation (1-365)

rotator_creds_type: Option<String>

The rotation credentials type

token: Option<String>

Authentication token (see /auth and /configure)

type: String

Item type

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

Implementations

Source

impl GatewayUpdateItem

pub fn new(name: String, type: String) -> GatewayUpdateItem

gatewayUpdateItem is a command that updates classic key