pub struct GatewayUpdateLdapAuthConfig {Show 15 fields
pub access_id: Option<String>,
pub bind_dn: Option<String>,
pub bind_dn_password: Option<String>,
pub group_attr: Option<String>,
pub group_dn: Option<String>,
pub group_filter: Option<String>,
pub json: Option<bool>,
pub ldap_ca_cert: Option<String>,
pub ldap_enable: Option<String>,
pub ldap_url: Option<String>,
pub signing_key_data: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_attribute: Option<String>,
pub user_dn: Option<String>,
}Expand description
GatewayUpdateLdapAuthConfig : gatewayUpdateLdapAuth is a command that updates ldap auth config
Fields
access_id: Option<String>The access ID of the Ldap auth method
bind_dn: Option<String>Bind DN
bind_dn_password: Option<String>Bind DN Password
group_attr: Option<String>Group Attr
group_dn: Option<String>Group Dn
group_filter: Option<String>Group Filter
json: Option<bool>Set output format to JSON
ldap_ca_cert: Option<String>LDAP CA Certificate (base64 encoded)
ldap_enable: Option<String>Enable Ldap [true/false]
ldap_url: Option<String>LDAP Server URL, e.g. ldap://planetexpress.com:389
signing_key_data: Option<String>The private key (base64 encoded), associated with the public key defined in the Ldap auth
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_attribute: Option<String>User Attribute
user_dn: Option<String>User DN
Implementations
Sourceimpl GatewayUpdateLdapAuthConfig
impl GatewayUpdateLdapAuthConfig
Sourcepub fn new() -> GatewayUpdateLdapAuthConfig
pub fn new() -> GatewayUpdateLdapAuthConfig
gatewayUpdateLdapAuth is a command that updates ldap auth config