pub struct GatewayUpdateLogForwardingSplunk {Show 14 fields
pub enable: Option<String>,
pub enable_batch: Option<String>,
pub enable_tls: Option<bool>,
pub index: Option<String>,
pub json: Option<bool>,
pub output_format: Option<String>,
pub pull_interval: Option<String>,
pub source: Option<String>,
pub source_type: Option<String>,
pub splunk_token: Option<String>,
pub splunk_url: Option<String>,
pub tls_certificate: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayUpdateLogForwardingSplunk : gatewayUpdateLogForwardingSplunk is a command that updates log forwarding config (splunk target)
Fields
enable: Option<String>Enable Log Forwarding [true/false]
enable_batch: Option<String>Enable batch forwarding [true/false]
enable_tls: Option<bool>Enable tls
index: Option<String>Splunk index
json: Option<bool>Set output format to JSON
output_format: Option<String>Logs format [text/json]
pull_interval: Option<String>Pull interval in seconds
source: Option<String>Splunk source
source_type: Option<String>Splunk source type
splunk_token: Option<String>Splunk token
splunk_url: Option<String>Splunk server URL
tls_certificate: Option<String>Splunk tls certificate
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayUpdateLogForwardingSplunk
impl GatewayUpdateLogForwardingSplunk
Sourcepub fn new() -> GatewayUpdateLogForwardingSplunk
pub fn new() -> GatewayUpdateLogForwardingSplunk
gatewayUpdateLogForwardingSplunk is a command that updates log forwarding config (splunk target)