pub struct GatewayUpdateLogForwardingStdout {
pub enable: Option<String>,
pub json: Option<bool>,
pub output_format: Option<String>,
pub pull_interval: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayUpdateLogForwardingStdout : gatewayUpdateLogForwardingStdout is a command that updates log forwarding config (stdout target)
Fields
enable: Option<String>Enable Log Forwarding [true/false]
json: Option<bool>Set output format to JSON
output_format: Option<String>Logs format [text/json]
pull_interval: Option<String>Pull interval in seconds
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayUpdateLogForwardingStdout
impl GatewayUpdateLogForwardingStdout
Sourcepub fn new() -> GatewayUpdateLogForwardingStdout
pub fn new() -> GatewayUpdateLogForwardingStdout
gatewayUpdateLogForwardingStdout is a command that updates log forwarding config (stdout target)