pub struct GatewayUpdateLogForwardingSumologic {
pub enable: Option<String>,
pub endpoint: Option<String>,
pub host: Option<String>,
pub json: Option<bool>,
pub output_format: Option<String>,
pub pull_interval: Option<String>,
pub sumologic_tags: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayUpdateLogForwardingSumologic : gatewayUpdateLogForwardingSumologic is a command that updates log forwarding config (sumologic target)
Fields
enable: Option<String>Enable Log Forwarding [true/false]
endpoint: Option<String>Sumologic endpoint URL
host: Option<String>Sumologic host
json: Option<bool>Set output format to JSON
output_format: Option<String>Logs format [text/json]
pull_interval: Option<String>Pull interval in seconds
A comma-separated list of Sumologic tags
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayUpdateLogForwardingSumologic
impl GatewayUpdateLogForwardingSumologic
Sourcepub fn new() -> GatewayUpdateLogForwardingSumologic
pub fn new() -> GatewayUpdateLogForwardingSumologic
gatewayUpdateLogForwardingSumologic is a command that updates log forwarding config (sumologic target)