pub struct GatewayUpdateLogForwardingSyslog {
pub enable: Option<String>,
pub enable_tls: Option<bool>,
pub formatter: Option<String>,
pub host: Option<String>,
pub json: Option<bool>,
pub network: Option<String>,
pub output_format: Option<String>,
pub pull_interval: Option<String>,
pub target_tag: Option<String>,
pub tls_certificate: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayUpdateLogForwardingSyslog : gatewayUpdateLogForwardingSyslog is a command that updates log forwarding config (syslog target)
Fields
enable: Option<String>Enable Log Forwarding [true/false]
enable_tls: Option<bool>Enable tls relevant only for network type TCP
formatter: Option<String>Syslog formatter [text/cef]
host: Option<String>Syslog host
json: Option<bool>Set output format to JSON
network: Option<String>Syslog network [tcp/udp]
output_format: Option<String>Logs format [text/json]
pull_interval: Option<String>Pull interval in seconds
target_tag: Option<String>Syslog target tag
tls_certificate: Option<String>Syslog tls certificate
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayUpdateLogForwardingSyslog
impl GatewayUpdateLogForwardingSyslog
Sourcepub fn new() -> GatewayUpdateLogForwardingSyslog
pub fn new() -> GatewayUpdateLogForwardingSyslog
gatewayUpdateLogForwardingSyslog is a command that updates log forwarding config (syslog target)