GatewayUpdateRemoteAccess

Struct GatewayUpdateRemoteAccess 

pub struct GatewayUpdateRemoteAccess {
    pub allowed_ssh_url: Option<String>,
    pub allowed_urls: Option<String>,
    pub default_session_ttl_minutes: Option<String>,
    pub hide_session_recording: Option<String>,
    pub json: Option<bool>,
    pub kexalgs: Option<String>,
    pub keyboard_layout: Option<String>,
    pub legacy_ssh_algorithm: Option<String>,
    pub rdp_target_configuration: Option<String>,
    pub ssh_target_configuration: Option<String>,
    pub token: Option<String>,
    pub uid_token: Option<String>,
}
GatewayUpdateRemoteAccess : gatewayUpdateRemoteAccess is a command that update remote access config

Fields

allowed_ssh_url: Option<String>

Specify a valid SSH-URL to tunnel to SSH session

allowed_urls: Option<String>

List of valid URLs to redirect from the Portal back to the remote access server (in a comma-delimited list)

default_session_ttl_minutes: Option<String>

Default session TTL in minutes

hide_session_recording: Option<String>

Specifies whether to show/hide if the session is currently recorded [true/false]

json: Option<bool>

Set output format to JSON

kexalgs: Option<String>

Decide which algorithm will be used as part of the SSH initial hand-shake process

keyboard_layout: Option<String>

Enable support for additional keyboard layouts

legacy_ssh_algorithm: Option<String>

Signs SSH certificates using legacy ssh-rsa-cert-01@openssh.com signing algorithm [true/false]

rdp_target_configuration: Option<String>

Specify the usernameSubClaim that exists inside the IDP JWT, e.g. email

ssh_target_configuration: Option<String>

Specify the usernameSubClaim that exists inside the IDP JWT, e.g. email

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

Implementations

Source

impl GatewayUpdateRemoteAccess

pub fn new() -> GatewayUpdateRemoteAccess

gatewayUpdateRemoteAccess is a command that update remote access config