pub struct GatewayUpdateRemoteAccessDesktopApp {
pub desktop_app_secure_web_access_url: Option<String>,
pub desktop_app_secure_web_proxy: Option<String>,
pub desktop_app_ssh_cert_issuer: Option<String>,
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GatewayUpdateRemoteAccessDesktopApp : gatewayUpdateRemoteAccessDesktopApp is a command that update remote access desktop app config
Fields
desktop_app_secure_web_access_url: Option<String>desktop_app_secure_web_proxy: Option<String>desktop_app_ssh_cert_issuer: Option<String>json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GatewayUpdateRemoteAccessDesktopApp
impl GatewayUpdateRemoteAccessDesktopApp
Sourcepub fn new() -> GatewayUpdateRemoteAccessDesktopApp
pub fn new() -> GatewayUpdateRemoteAccessDesktopApp
gatewayUpdateRemoteAccessDesktopApp is a command that update remote access desktop app config