pub struct GenerateCa {Show 13 fields
pub alg: Option<String>,
pub allowed_domains: String,
pub delete_protection: Option<String>,
pub extended_key_usage: Option<String>,
pub json: Option<bool>,
pub key_type: Option<String>,
pub max_path_len: Option<i64>,
pub pki_chain_name: String,
pub protection_key_name: Option<String>,
pub split_level: Option<i64>,
pub token: Option<String>,
pub ttl: String,
pub uid_token: Option<String>,
}Expand description
GenerateCa : GenerateCA is a command that creates a new PKI CA and Intermediate issuers
Fields
alg: Option<String>allowed_domains: StringA list of the allowed domains that clients can request to be included in the certificate (in a comma-delimited list)
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
extended_key_usage: Option<String>A comma sepereted list of extended key usage for the intermediate (serverauth / clientauth / codesigning)
json: Option<bool>Set output format to JSON
key_type: Option<String>max_path_len: Option<i64>The maximum number of intermediate certificates that can appear in a certification path
pki_chain_name: StringPKI chain name
protection_key_name: Option<String>The name of a key that used to encrypt the secrets values (if empty, the account default protectionKey key will be used)
split_level: Option<i64>The number of fragments that the item will be split into
token: Option<String>Authentication token (see /auth and /configure)
ttl: StringThe maximum requested Time To Live for issued certificate by default in seconds, supported formats are s,m,h,d
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GenerateCa
impl GenerateCa