pub struct GetAuthMethod {
pub json: Option<bool>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GetAuthMethod : getAuthMethod is a command that returns information about the auth method. [Deprecated: Use auth-method-get command]
Fields
json: Option<bool>Set output format to JSON
name: StringAuth Method name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GetAuthMethod
impl GetAuthMethod
Sourcepub fn new(name: String) -> GetAuthMethod
pub fn new(name: String) -> GetAuthMethod
getAuthMethod is a command that returns information about the auth method. [Deprecated: Use auth-method-get command]