pub struct GetCertChallenge {
pub access_id: Option<String>,
pub cert_data: Option<String>,
pub json: Option<bool>,
}Expand description
GetCertChallenge : GetCertChallenge is a command that gets a challenge for certificate authentication
Fields
access_id: Option<String>Access ID
cert_data: Option<String>Certificate data encoded in base64. Used if file was not provided.
json: Option<bool>Set output format to JSON
Implementations
Sourceimpl GetCertChallenge
impl GetCertChallenge
Sourcepub fn new() -> GetCertChallenge
pub fn new() -> GetCertChallenge
GetCertChallenge is a command that gets a challenge for certificate authentication