pub struct GetEventForwarder {
pub json: Option<bool>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GetEventForwarder : getEventForwarder is a command that creates a new event forwarder [Deprecated - please use event-forwarder-get command]
Fields
json: Option<bool>Set output format to JSON
name: StringEventForwarder name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GetEventForwarder
impl GetEventForwarder
Sourcepub fn new(name: String) -> GetEventForwarder
pub fn new(name: String) -> GetEventForwarder
getEventForwarder is a command that creates a new event forwarder [Deprecated - please use event-forwarder-get command]