pub struct GetLastUserEventStatus {
pub event_source: Option<String>,
pub event_type: String,
pub item_name: String,
pub item_type: String,
pub json: Option<bool>,
pub time_back: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
event_source: Option<String>event_type: Stringitem_name: StringEvent item name
item_type: StringEvent item type can be either "target" or type of item eg "static_secret"/"dynamic_secret" To get type of some item run akeyless describe-item -n {ITEM_NAME} --jq-expression .item_type
json: Option<bool>Set output format to JSON
time_back: Option<String>The time back to search the event, for example if the value is "5m" we will return the last user event issued in the last 5 minutes. By default, we will search without any time boundary.
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations