pub struct GetSecretValue {
pub accessibility: Option<String>,
pub ignore_cache: Option<String>,
pub json: Option<bool>,
pub names: Vec<String>,
pub pretty_print: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: Option<i32>,
}Fields
accessibility: Option<String>for personal password manager
ignore_cache: Option<String>Retrieve the Secret value without checking the Gateway’s cache [true/false]. This flag is only relevant when using the RestAPI
json: Option<bool>Set output format to JSON
names: Vec<String>Secret name
pretty_print: Option<bool>Print the secret value with json-pretty-print (not relevent to SDK)
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: Option<i32>Secret version, if negative value N is provided the last N versions will return (maximum 20)
Implementations
Sourceimpl GetSecretValue
impl GetSecretValue
pub fn new(names: Vec<String>) -> GetSecretValue