pub struct GetSshCertificate {
pub cert_issuer_name: String,
pub cert_username: String,
pub json: Option<bool>,
pub legacy_signing_alg_name: Option<bool>,
pub public_key_data: Option<String>,
pub token: Option<String>,
pub ttl: Option<i64>,
pub uid_token: Option<String>,
}Fields
cert_issuer_name: StringThe name of the SSH certificate issuer
cert_username: StringThe username to sign in the SSH certificate
json: Option<bool>Set output format to JSON
legacy_signing_alg_name: Option<bool>Set this option to output legacy (‘ssh-rsa-cert-v01@openssh.com’) signing algorithm name in the certificate.
public_key_data: Option<String>SSH public key file contents. If this option is used, the certificate will be printed to stdout
token: Option<String>Authentication token (see /auth and /configure)
ttl: Option<i64>Updated certificate lifetime in seconds (must be less than the Certificate Issuer default TTL)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GetSshCertificate
impl GetSshCertificate
pub fn new(cert_issuer_name: String, cert_username: String) -> GetSshCertificate