pub struct GwUpdateRemoteAccessSessionLogsAzureAnalytics {
pub enable: Option<String>,
pub enable_batch: Option<String>,
pub json: Option<bool>,
pub output_format: Option<String>,
pub pull_interval: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub workspace_id: Option<String>,
pub workspace_key: Option<String>,
}Expand description
GwUpdateRemoteAccessSessionLogsAzureAnalytics : gwUpdateRemoteAccessSessionLogsAzureAnalytics is a command that updates session log forwarding config (azure-analytics target)
Fields
enable: Option<String>Enable Log Forwarding [true/false]
enable_batch: Option<String>Enable batch forwarding [true/false]
json: Option<bool>Set output format to JSON
output_format: Option<String>Logs format [text/json]
pull_interval: Option<String>Pull interval in seconds
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
workspace_id: Option<String>Azure workspace id
workspace_key: Option<String>Azure workspace key
Implementations
Sourceimpl GwUpdateRemoteAccessSessionLogsAzureAnalytics
impl GwUpdateRemoteAccessSessionLogsAzureAnalytics
Sourcepub fn new() -> GwUpdateRemoteAccessSessionLogsAzureAnalytics
pub fn new() -> GwUpdateRemoteAccessSessionLogsAzureAnalytics
gwUpdateRemoteAccessSessionLogsAzureAnalytics is a command that updates session log forwarding config (azure-analytics target)