pub struct GwUpdateRemoteAccessSessionLogsDatadog {
pub api_key: Option<String>,
pub enable: Option<String>,
pub host: Option<String>,
pub json: Option<bool>,
pub log_service: Option<String>,
pub log_source: Option<String>,
pub log_tags: Option<String>,
pub output_format: Option<String>,
pub pull_interval: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
GwUpdateRemoteAccessSessionLogsDatadog : gwUpdateRemoteAccessSessionLogsDatadog is a command that updates session log forwarding config (datadog target)
Fields
api_key: Option<String>Datadog api key
enable: Option<String>Enable Log Forwarding [true/false]
host: Option<String>Datadog host
json: Option<bool>Set output format to JSON
log_service: Option<String>Datadog log service
log_source: Option<String>Datadog log source
A comma-separated list of Datadog log tags formatted as "key:value" strings
output_format: Option<String>Logs format [text/json]
pull_interval: Option<String>Pull interval in seconds
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl GwUpdateRemoteAccessSessionLogsDatadog
impl GwUpdateRemoteAccessSessionLogsDatadog
Sourcepub fn new() -> GwUpdateRemoteAccessSessionLogsDatadog
pub fn new() -> GwUpdateRemoteAccessSessionLogsDatadog
gwUpdateRemoteAccessSessionLogsDatadog is a command that updates session log forwarding config (datadog target)