pub struct Hmac {
pub display_id: Option<String>,
pub hash_function: Option<String>,
pub input_format: Option<String>,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub key_name: String,
pub plaintext: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
display_id: Option<String>The display id of the key to use in the encryption process
hash_function: Option<String>Hash function [sha-256,sha-512]
input_format: Option<String>Select default assumed format for any plaintext input. Currently supported options: [base64]
item_id: Option<i64>The item id of the key to use in the encryption process
json: Option<bool>Set output format to JSON
key_name: StringThe name of the key to use in the encryption process
plaintext: Option<String>Data to perform hmac on
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations