K8SAuth

Struct K8SAuth 

pub struct K8SAuth {
Show 18 fields pub am_token_expiration: Option<i64>, pub auth_method_access_id: Option<String>, pub auth_method_prv_key_pem: Option<String>, pub cluster_api_type: Option<String>, pub disable_iss_validation: Option<bool>, pub id: Option<String>, pub k8s_auth_type: Option<String>, pub k8s_ca_cert: Option<String>, pub k8s_client_cert_data: Option<String>, pub k8s_client_key_data: Option<String>, pub k8s_host: Option<String>, pub k8s_issuer: Option<String>, pub k8s_pub_keys_pem: Option<Vec<String>>, pub k8s_token_reviewer_jwt: Option<String>, pub name: Option<String>, pub rancher_api_key: Option<String>, pub rancher_cluster_id: Option<String>, pub use_local_ca_jwt: Option<bool>,
}

Fields

am_token_expiration: Option<i64>

AuthMethodTokenExpiration is time in seconds of expiration of the Akeyless Kube Auth Method token

auth_method_access_id: Option<String>

AuthMethodAccessId of the Kubernetes auth method

auth_method_prv_key_pem: Option<String>

AuthMethodSigningKey is the private key (in base64 of the PEM format) associated with the public key defined in the Kubernetes auth method, that used to sign the internal token for the Akeyless Kubernetes Auth Method

cluster_api_type: Option<String>

ClusterApiType defines types of API access to cluster

disable_iss_validation: Option<bool>

DisableISSValidation is optional parameter to disable ISS validation

id: Option<String>k8s_auth_type: Option<String>k8s_ca_cert: Option<String>

K8SCACert is the CA Cert to use to call into the kubernetes API

k8s_client_cert_data: Option<String>

K8sClientCertData is the client certificate for k8s client certificate authentication

k8s_client_key_data: Option<String>

K8sClientKeyData is the client key for k8s client certificate authentication

k8s_host: Option<String>

K8SHost is the url string for the kubernetes API

k8s_issuer: Option<String>

K8SIssuer is the claim that specifies who issued the Kubernetes token

k8s_pub_keys_pem: Option<Vec<String>>

K8SPublicKeysPEM is the list of public key in PEM format

k8s_token_reviewer_jwt: Option<String>

K8STokenReviewerJWT is the bearer for clusterApiTypeK8s, used during TokenReview API call

name: Option<String>rancher_api_key: Option<String>

RancherApiKey the bear token for clusterApiTypeRancher

rancher_cluster_id: Option<String>

RancherClusterId cluster id as define in rancher (in case of clusterApiTypeRancher)

use_local_ca_jwt: Option<bool>

UseLocalCAJwt is an optional parameter to set defaulting to using the local service account when running in a Kubernetes pod

Implementations