Module kmip_delete_server

Module kmip_delete_server 

Structs

KmipDeleteServer
KmipDeleteServer : kmipDeleteServer is a command that the kmip server (allowed only if it has no clients nor associated items)