pub struct KmipDeleteServer {
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
KmipDeleteServer : kmipDeleteServer is a command that the kmip server (allowed only if it has no clients nor associated items)
Fields
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl KmipDeleteServer
impl KmipDeleteServer
Sourcepub fn new() -> KmipDeleteServer
pub fn new() -> KmipDeleteServer
kmipDeleteServer is a command that the kmip server (allowed only if it has no clients nor associated items)