pub struct KmipSetServerState {
pub json: Option<bool>,
pub state: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
KmipSetServerState : kmipSetServerState is a command that sets the environment state to active/inactive.
Fields
json: Option<bool>Set output format to JSON
state: Stringtoken: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl KmipSetServerState
impl KmipSetServerState
Sourcepub fn new(state: String) -> KmipSetServerState
pub fn new(state: String) -> KmipSetServerState
kmipSetServerState is a command that sets the environment state to active/inactive.