pub struct ListSharedItems {
pub accessibility: Option<String>,
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
ListSharedItems : listSharedItems is a command to list all the items been shared
Fields
accessibility: Option<String>for personal password manager
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourcepub fn new() -> ListSharedItems
pub fn new() -> ListSharedItems
listSharedItems is a command to list all the items been shared