pub struct ListTargets {
pub filter: Option<String>,
pub json: Option<bool>,
pub pagination_token: Option<String>,
pub token: Option<String>,
pub type: Option<Vec<String>>,
pub uid_token: Option<String>,
}Expand description
ListTargets : listTargets is a command that returns a list of targets. [Deprecated: Use target-list command]
Fields
filter: Option<String>Filter by auth method name or part of it
json: Option<bool>Set output format to JSON
pagination_token: Option<String>Next page reference
token: Option<String>Authentication token (see /auth and /configure)
type: Option<Vec<String>>The target types list . In case it is empty, all types of targets will be returned. options: [hanadb cassandra aws ssh gke eks mysql mongodb snowflake mssql redshift artifactory azure rabbitmq k8s venafi gcp oracle dockerhub ldap github chef web salesforce postgres]
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl ListTargets
impl ListTargets
Sourcepub fn new() -> ListTargets
pub fn new() -> ListTargets
listTargets is a command that returns a list of targets. [Deprecated: Use target-list command]