pub struct Name {
pub country: Option<Vec<String>>,
pub extra_names: Option<Vec<AttributeTypeAndValue>>,
pub locality: Option<Vec<String>>,
pub names: Option<Vec<AttributeTypeAndValue>>,
pub serial_number: Option<String>,
pub street_address: Option<Vec<String>>,
}Expand description
Name : Name represents an X.509 distinguished name. This only includes the common elements of a DN. Note that Name is only an approximation of the X.509 structure. If an accurate representation is needed, asn1.Unmarshal the raw subject or issuer as an [RDNSequence].
Fields
country: Option<Vec<String>>extra_names: Option<Vec<AttributeTypeAndValue>>ExtraNames contains attributes to be copied, raw, into any marshaled distinguished names. Values override any attributes with the same OID. The ExtraNames field is not populated when parsing, see Names.
locality: Option<Vec<String>>names: Option<Vec<AttributeTypeAndValue>>Names contains all parsed attributes. When parsing distinguished names, this can be used to extract non-standard attributes that are not parsed by this package. When marshaling to RDNSequences, the Names field is ignored, see ExtraNames.
serial_number: Option<String>street_address: Option<Vec<String>>Implementations