OAuth2AccessRules

Struct OAuth2AccessRules 

pub struct OAuth2AccessRules {
    pub audience: Option<String>,
    pub authorized_gw_cluster_name: Option<String>,
    pub bound_claims: Option<Vec<OAuth2CustomClaim>>,
    pub bound_clients_id: Option<Vec<String>>,
    pub certificate: Option<String>,
    pub issuer: Option<String>,
    pub jwks_json_data: Option<String>,
    pub jwks_uri: Option<String>,
    pub unique_identifier: Option<String>,
}
OAuth2AccessRules : OAuth2AccessRules contains access rules specific to OAuth2 authentication method.

Fields

audience: Option<String>

The audience in the JWT.

authorized_gw_cluster_name: Option<String>

The gateway cluster name that is authorized to access JWKeySetURL

bound_claims: Option<Vec<OAuth2CustomClaim>>

The claims that login is restricted to.

bound_clients_id: Option<Vec<String>>

The clients ids that login is restricted to.

certificate: Option<String>

Certificate to use when calling jwks_uri from the gateway. in PEM format

issuer: Option<String>

Issuer URL

jwks_json_data: Option<String>

The JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server. base64 encoded string

jwks_uri: Option<String>

The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.

unique_identifier: Option<String>

A unique identifier to distinguish different users

Implementations

Source

impl OAuth2AccessRules

pub fn new() -> OAuth2AccessRules

OAuth2AccessRules contains access rules specific to OAuth2 authentication method.