pub struct OidcAccessRules {
pub allowed_redirect_uris: Option<Vec<String>>,
pub audience: Option<String>,
pub bound_claims: Option<Vec<OidcCustomClaim>>,
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub is_internal: Option<bool>,
pub issuer: Option<String>,
pub required_scopes: Option<Vec<String>>,
pub required_scopes_prefix: Option<String>,
pub unique_identifier: Option<String>,
}Expand description
OidcAccessRules : OIDCAccessRules contains access rules specific to Open Id Connect authentication method.
Fields
allowed_redirect_uris: Option<Vec<String>>Allowed redirect URIs after the authentication
audience: Option<String>Audience claim to be used as part of the authentication flow. In case set, it must match the one configured on the Identity Provider’s Application
bound_claims: Option<Vec<OidcCustomClaim>>The claims that login is restricted to.
client_id: Option<String>Client ID
client_secret: Option<String>Client Secret
is_internal: Option<bool>IsInternal indicates whether this is an internal Auth Method where the client has no control over it, or it was created by the client e.g - Sign In with Google will create an OIDC Auth Method with IsInternal=true
issuer: Option<String>Issuer URL
required_scopes: Option<Vec<String>>A list of required scopes to request from the oidc provider, and to check on the token
required_scopes_prefix: Option<String>A prefix to add to the required scopes (for example, azures’ Application ID URI)
unique_identifier: Option<String>A unique identifier to distinguish different users
Implementations
Sourceimpl OidcAccessRules
impl OidcAccessRules
Sourcepub fn new() -> OidcAccessRules
pub fn new() -> OidcAccessRules
OIDCAccessRules contains access rules specific to Open Id Connect authentication method.