pub struct PolicyCreateKeys {
pub allowed_algorithms: Option<Vec<String>>,
pub allowed_key_names: Option<Vec<String>>,
pub allowed_key_types: Option<Vec<String>>,
pub json: Option<bool>,
pub max_rotation_interval_days: Option<i32>,
pub object_types: Option<Vec<String>>,
pub path: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
allowed_algorithms: Option<Vec<String>>Specify allowed key algorithms (e.g., [RSA2048,AES128GCM])
allowed_key_names: Option<Vec<String>>Specify allowed protection key names. To enforce using the account’s default protection key, use ‘default-account-key’
allowed_key_types: Option<Vec<String>>Specify allowed key protection types (dfc, classic-key)
json: Option<bool>Set output format to JSON
max_rotation_interval_days: Option<i32>Set the maximum rotation interval for automatic key rotation.
object_types: Option<Vec<String>>The object types this policy will apply to (items, targets). If not provided, defaults to [items, targets].
path: StringThe path the policy refers to
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl PolicyCreateKeys
impl PolicyCreateKeys
pub fn new(path: String) -> PolicyCreateKeys