pub struct PolicyUpdateKeys {
pub allowed_algorithms: Option<Vec<String>>,
pub allowed_key_names: Option<Vec<String>>,
pub allowed_key_types: Option<Vec<String>>,
pub id: String,
pub json: Option<bool>,
pub max_rotation_interval_days: Option<i32>,
pub object_types: Option<Vec<String>>,
pub path: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
allowed_algorithms: Option<Vec<String>>Specify allowed key algorithms (e.g., [RSA2048,AES128GCM])
allowed_key_names: Option<Vec<String>>Specify allowed protection key names. To enforce using the account’s default protection key, use ‘default-account-key’
allowed_key_types: Option<Vec<String>>Specify allowed key protection types (dfc, classic-key)
id: StringPolicy id
json: Option<bool>Set output format to JSON
max_rotation_interval_days: Option<i32>Set the maximum rotation interval for automatic key rotation.
object_types: Option<Vec<String>>The object type this policy will apply to (items, targets)
path: Option<String>The path the policy refers to
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl PolicyUpdateKeys
impl PolicyUpdateKeys
pub fn new(id: String) -> PolicyUpdateKeys