pub struct RegexpTokenizerInfo {
pub alphabet: Option<String>,
pub decoding_template: Option<String>,
pub encoding_template: Option<String>,
pub pattern: Option<String>,
}Expand description
RegexpTokenizerInfo : RegexpTokenizerInfo represents a general Regexp tokenization template
Fields
alphabet: Option<String>The Alphabet used for the tokenization
decoding_template: Option<String>Transformation to perform on the decrypted data
encoding_template: Option<String>Transformation to perform on the encrypted data, if the required output template doesn’t match the input string The output Should still be valid for the Pattern, otherwise the secret would be able to be decrypted.
pattern: Option<String>Regexp pattern to extract and deposit the text/encdata
Implementations
Sourceimpl RegexpTokenizerInfo
impl RegexpTokenizerInfo
Sourcepub fn new() -> RegexpTokenizerInfo
pub fn new() -> RegexpTokenizerInfo
RegexpTokenizerInfo represents a general Regexp tokenization template