pub struct ReverseRbac {
pub json: Option<bool>,
pub path: String,
pub token: Option<String>,
pub type: String,
pub uid_token: Option<String>,
}Expand description
ReverseRbac : reverseRBAC is a command that shows which auth methods have access to a particular object.
Fields
json: Option<bool>Set output format to JSON
path: StringPath to an object
token: Option<String>Authentication token (see /auth and /configure)
type: StringType of object (item, am, role)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl ReverseRbac
impl ReverseRbac
Sourcepub fn new(path: String, type: String) -> ReverseRbac
pub fn new(path: String, type: String) -> ReverseRbac
reverseRBAC is a command that shows which auth methods have access to a particular object.