pub struct RoleAuthMethodAssociation {
pub assoc_id: Option<String>,
pub auth_method_access_id: Option<String>,
pub auth_method_id: Option<i64>,
pub auth_method_name: Option<String>,
pub auth_method_sub_claims: Option<HashMap<String, Vec<String>>>,
pub is_subclaims_with_operator: Option<bool>,
pub sub_claims_case_sensitive: Option<bool>,
}Expand description
RoleAuthMethodAssociation : RoleAuthMethodAssociation includes details of an association between a role and an auth method.
Fields
assoc_id: Option<String>auth_method_access_id: Option<String>auth_method_id: Option<i64>auth_method_name: Option<String>auth_method_sub_claims: Option<HashMap<String, Vec<String>>>is_subclaims_with_operator: Option<bool>sub_claims_case_sensitive: Option<bool>Implementations
Sourceimpl RoleAuthMethodAssociation
impl RoleAuthMethodAssociation
Sourcepub fn new() -> RoleAuthMethodAssociation
pub fn new() -> RoleAuthMethodAssociation
RoleAuthMethodAssociation includes details of an association between a role and an auth method.