pub struct RotatedSecretCreateAzure {Show 37 fields
pub api_id: Option<String>,
pub api_key: Option<String>,
pub application_id: Option<String>,
pub authentication_credentials: Option<String>,
pub auto_rotate: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub explicitly_set_sa: Option<String>,
pub grace_rotation: Option<String>,
pub grace_rotation_hour: Option<i32>,
pub grace_rotation_interval: Option<String>,
pub grace_rotation_timing: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub password_length: Option<String>,
pub resource_group_name: Option<String>,
pub resource_name: Option<String>,
pub rotate_after_disconnect: Option<String>,
pub rotation_event_in: Option<Vec<String>>,
pub rotation_hour: Option<i32>,
pub rotation_interval: Option<String>,
pub rotator_type: String,
pub secure_access_disable_concurrent_connections: Option<bool>,
pub secure_access_enable: Option<String>,
pub secure_access_url: Option<String>,
pub secure_access_web: Option<bool>,
pub secure_access_web_browsing: Option<bool>,
pub secure_access_web_proxy: Option<bool>,
pub storage_account_key_name: Option<String>,
pub tags: Option<Vec<String>>,
pub target_name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub username: Option<String>,
}Fields
api_id: Option<String>API ID to rotate (relevant only for rotator-type=api-key)
api_key: Option<String>API key to rotate (relevant only for rotator-type=api-key)
application_id: Option<String>Id of the azure app that hold the serect to be rotated (relevant only for rotator-type=api-key & authentication-credentials=use-target-creds)
authentication_credentials: Option<String>The credentials to connect with use-user-creds/use-target-creds
auto_rotate: Option<String>Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
explicitly_set_sa: Option<String>If set, explicitly provide the storage account details [true/false]
grace_rotation: Option<String>Enable graceful rotation (keep both versions temporarily). When enabled, a new secret version is created while the previous version is kept for the grace period, so both versions exist for a limited time. [true/false]
grace_rotation_hour: Option<i32>The Hour of the grace rotation in UTC
grace_rotation_interval: Option<String>The number of days to wait before deleting the old key (must be bigger than rotation-interval)
grace_rotation_timing: Option<String>When to create the new version relative to the rotation date [after/before]
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringRotated secret name
password_length: Option<String>The length of the password to be generated
resource_group_name: Option<String>The resource group name (only relevant when explicitly-set-sa=true)
resource_name: Option<String>The name of the storage account (only relevant when explicitly-set-sa=true)
rotate_after_disconnect: Option<String>Rotate the value of the secret after SRA session ends [true/false]
rotation_event_in: Option<Vec<String>>How many days before the rotation of the item would you like to be notified
rotation_hour: Option<i32>The Hour of the rotation in UTC
rotation_interval: Option<String>The number of days to wait between every automatic key rotation (1-365)
rotator_type: StringThe rotator type. options: [target/password/api-key/azure-storage-account]
secure_access_disable_concurrent_connections: Option<bool>Enable this flag to prevent simultaneous use of the same secret
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_url: Option<String>Destination URL to inject secrets
secure_access_web: Option<bool>Enable Web Secure Remote Access
secure_access_web_browsing: Option<bool>Secure browser via Akeyless’s Secure Remote Access (SRA)
secure_access_web_proxy: Option<bool>Web-Proxy via Akeyless’s Secure Remote Access (SRA)
storage_account_key_name: Option<String>The name of the storage account key to rotate [key1/key2/kerb1/kerb2] (relevat to azure-storage-account)
Add tags attached to this object
target_name: StringThe target name to associate
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
username: Option<String>The user principal name to rotate his password (relevant only for rotator-type=password)
Implementations