pub struct RotatedSecretCreateCustom {Show 37 fields
pub authentication_credentials: Option<String>,
pub auto_rotate: Option<String>,
pub custom_payload: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub enable_password_policy: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub password_length: Option<String>,
pub rotate_after_disconnect: Option<String>,
pub rotation_event_in: Option<Vec<String>>,
pub rotation_hour: Option<i32>,
pub rotation_interval: Option<String>,
pub secure_access_allow_external_user: Option<bool>,
pub secure_access_bastion_issuer: Option<String>,
pub secure_access_certificate_issuer: Option<String>,
pub secure_access_enable: Option<String>,
pub secure_access_host: Option<Vec<String>>,
pub secure_access_rdp_domain: Option<String>,
pub secure_access_rdp_user: Option<String>,
pub secure_access_ssh_user: Option<String>,
pub secure_access_url: Option<String>,
pub secure_access_web: Option<bool>,
pub secure_access_web_browsing: Option<bool>,
pub secure_access_web_proxy: Option<bool>,
pub tags: Option<Vec<String>>,
pub target_name: String,
pub timeout_sec: Option<i64>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub use_capital_letters: Option<String>,
pub use_lower_letters: Option<String>,
pub use_numbers: Option<String>,
pub use_special_characters: Option<String>,
}Fields
authentication_credentials: Option<String>The credentials to connect with use-user-creds/use-target-creds
auto_rotate: Option<String>Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]
custom_payload: Option<String>Secret payload to be sent with rotation request
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
enable_password_policy: Option<String>Enable password policy
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringRotated secret name
password_length: Option<String>The length of the password to be generated
rotate_after_disconnect: Option<String>Rotate the value of the secret after SRA session ends [true/false]
rotation_event_in: Option<Vec<String>>How many days before the rotation of the item would you like to be notified
rotation_hour: Option<i32>The Hour of the rotation in UTC
rotation_interval: Option<String>The number of days to wait between every automatic key rotation (1-365)
secure_access_allow_external_user: Option<bool>Allow providing external user for a domain users
secure_access_bastion_issuer: Option<String>Deprecated. use secure-access-certificate-issuer
secure_access_certificate_issuer: Option<String>Path to the SSH Certificate Issuer for your Akeyless Secure Access
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_host: Option<Vec<String>>Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)
secure_access_rdp_domain: Option<String>Default domain name server. i.e. microsoft.com
secure_access_rdp_user: Option<String>Override the RDP Domain username
secure_access_ssh_user: Option<String>Override the SSH username as indicated in SSH Certificate Issuer
secure_access_url: Option<String>Destination URL to inject secrets
secure_access_web: Option<bool>Enable Web Secure Remote Access
secure_access_web_browsing: Option<bool>Secure browser via Akeyless’s Secure Remote Access (SRA)
secure_access_web_proxy: Option<bool>Web-Proxy via Akeyless’s Secure Remote Access (SRA)
Add tags attached to this object
target_name: StringThe target name to associate
timeout_sec: Option<i64>Maximum allowed time in seconds for the custom rotator to return the results
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
use_capital_letters: Option<String>Password must contain capital letters [true/false]
use_lower_letters: Option<String>Password must contain lower case letters [true/false]
use_numbers: Option<String>Password must contain numbers [true/false]
use_special_characters: Option<String>Password must contain special characters [true/false]
Implementations
Sourceimpl RotatedSecretCreateCustom
impl RotatedSecretCreateCustom
pub fn new(name: String, target_name: String) -> RotatedSecretCreateCustom