pub struct RotatedSecretCreateOpenAi {Show 20 fields
pub api_key: Option<String>,
pub api_key_id: Option<String>,
pub authentication_credentials: Option<String>,
pub auto_rotate: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub password_length: Option<String>,
pub rotation_event_in: Option<Vec<String>>,
pub rotation_hour: Option<i32>,
pub rotation_interval: Option<String>,
pub rotator_type: String,
pub tags: Option<Vec<String>>,
pub target_name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
RotatedSecretCreateOpenAi : rotatedSecretCreateOpenAI is a command that creates a rotated secret for an OpenAI target by rotating the admin API key configured on the target.
Fields
api_key: Option<String>Admin API key value to rotate (relevant only for rotator-type=api-key)
api_key_id: Option<String>Admin API key ID to rotate (relevant only for rotator-type=api-key)
authentication_credentials: Option<String>The credentials to connect with use-user-creds/use-target-creds
auto_rotate: Option<String>Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringRotated secret name
password_length: Option<String>The length of the password to be generated
rotation_event_in: Option<Vec<String>>How many days before the rotation of the item would you like to be notified
rotation_hour: Option<i32>The Hour of the rotation in UTC
rotation_interval: Option<String>The number of days to wait between every automatic key rotation (1-365)
rotator_type: StringThe rotator type. options: [target/api-key]
Add tags attached to this object
target_name: StringThe target name to associate
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations