pub struct RotatedSecretCreateSnowflake {Show 22 fields
pub authentication_credentials: Option<String>,
pub auto_rotate: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub password_length: Option<String>,
pub private_key: Option<String>,
pub private_key_file_name: Option<String>,
pub rotated_password: Option<String>,
pub rotated_username: Option<String>,
pub rotation_event_in: Option<Vec<String>>,
pub rotation_hour: Option<i32>,
pub rotation_interval: Option<String>,
pub rotator_type: String,
pub tags: Option<Vec<String>>,
pub target_name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
authentication_credentials: Option<String>The credentials to connect with use-user-creds/use-target-creds
auto_rotate: Option<String>Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringRotated secret name
password_length: Option<String>The length of the password to be generated
private_key: Option<String>RSA Private key (base64 encoded) to rotate (relevant only for rotator-type=key)
private_key_file_name: Option<String>The path to the file containing the private key (relevant only for rotator-type=key)
rotated_password: Option<String>rotated-username password (relevant only for rotator-type=password)
rotated_username: Option<String>username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=password or rotator-type=key)
rotation_event_in: Option<Vec<String>>How many days before the rotation of the item would you like to be notified
rotation_hour: Option<i32>The Hour of the rotation in UTC
rotation_interval: Option<String>The number of days to wait between every automatic key rotation (1-365)
rotator_type: StringThe rotator type. options: [target/password/key]
Add tags attached to this object
target_name: StringThe target name to associate
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations