pub struct RotatedSecretDelete {
pub json: Option<bool>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: Option<i32>,
}Expand description
RotatedSecretDelete : rotatedSecretDelete is a command that deletes a rotated secret
Fields
json: Option<bool>Set output format to JSON
name: StringRotated secret name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: Option<i32>The specific version you want to delete, -1=entire item with all versions (default)
Implementations
Sourceimpl RotatedSecretDelete
impl RotatedSecretDelete
Sourcepub fn new(name: String) -> RotatedSecretDelete
pub fn new(name: String) -> RotatedSecretDelete
rotatedSecretDelete is a command that deletes a rotated secret