pub struct RotatedSecretSync {
pub delete_remote: Option<bool>,
pub filter_secret_value: Option<String>,
pub json: Option<bool>,
pub name: String,
pub namespace: Option<String>,
pub remote_secret_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub usc_name: Option<String>,
}Fields
delete_remote: Option<bool>Delete the secret from remote secret manager (for association create/update)
filter_secret_value: Option<String>JQ expression to filter or transform the secret value
json: Option<bool>Set output format to JSON
name: StringRotated secret name
namespace: Option<String>Vault namespace, releavnt only for Hashicorp Vault Target
remote_secret_name: Option<String>Remote Secret Name that will be synced on the remote endpoint
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
usc_name: Option<String>Universal Secret Connector name, If not provided all attached USC’s will be synced
Implementations
Sourceimpl RotatedSecretSync
impl RotatedSecretSync
pub fn new(name: String) -> RotatedSecretSync