pub struct RotatedSecretUpdateSplunk {Show 24 fields
pub add_tag: Option<Vec<String>>,
pub audience: Option<String>,
pub authentication_credentials: Option<String>,
pub auto_rotate: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_date: Option<String>,
pub hec_token: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub password_length: Option<String>,
pub rm_tag: Option<Vec<String>>,
pub rotation_event_in: Option<Vec<String>>,
pub rotation_hour: Option<i32>,
pub rotation_interval: Option<String>,
pub splunk_token: Option<String>,
pub token: Option<String>,
pub token_owner: Option<String>,
pub uid_token: Option<String>,
}Expand description
RotatedSecretUpdateSplunk : rotatedSecretUpdateSplunk is a command that updates a rotated secret for a Splunk target. It reuses the rotator type chosen at create time.
Fields
add_tag: Option<Vec<String>>List of the new tags that will be attached to this item
audience: Option<String>Token audience for Splunk token creation (relevant only for rotator-type=token)
authentication_credentials: Option<String>The credentials to connect with use-user-creds/use-target-creds
auto_rotate: Option<String>Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
expiration_date: Option<String>Token expiration date in YYYY-MM-DD format (relevant only for rotator-type=token when manual rotation is selected). Time will be set to 00:00 UTC.
hec_token: Option<String>For rotator-type=hec-token, optionally set/replace the stored HEC token value.
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringRotated secret name
new_name: Option<String>New item name
password_length: Option<String>The length of the password to be generated
rm_tag: Option<Vec<String>>List of the existent tags that will be removed from this item
rotation_event_in: Option<Vec<String>>How many days before the rotation of the item would you like to be notified
rotation_hour: Option<i32>The Hour of the rotation in UTC
rotation_interval: Option<String>The number of days to wait between every automatic key rotation (1-365)
splunk_token: Option<String>For rotator-type=token, optionally set/replace the stored Splunk authentication token value.
token: Option<String>Authentication token (see /auth and /configure)
token_owner: Option<String>For rotator-type=token, specify the Splunk username that the new token should be issued for. (Splunk 10 requires name=
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl RotatedSecretUpdateSplunk
impl RotatedSecretUpdateSplunk
Sourcepub fn new(name: String) -> RotatedSecretUpdateSplunk
pub fn new(name: String) -> RotatedSecretUpdateSplunk
rotatedSecretUpdateSplunk is a command that updates a rotated secret for a Splunk target. It reuses the rotator type chosen at create time.