pub struct SectigoTargetDetails {
pub certificate_profile_id: Option<i64>,
pub customer_uri: Option<String>,
pub external_requester: Option<String>,
pub org_id: Option<i64>,
pub password: Option<String>,
pub timeout: Option<i64>,
pub username: Option<String>,
}Expand description
SectigoTargetDetails : SectigoTargetDetails
Fields
certificate_profile_id: Option<i64>customer_uri: Option<String>external_requester: Option<String>org_id: Option<i64>password: Option<String>timeout: Option<i64>A Duration represents the elapsed time between two instants as an int64 nanosecond count. The representation limits the largest representable duration to approximately 290 years.
username: Option<String>Implementations
Sourceimpl SectigoTargetDetails
impl SectigoTargetDetails
Sourcepub fn new() -> SectigoTargetDetails
pub fn new() -> SectigoTargetDetails
SectigoTargetDetails