pub struct SignDataWithClassicKey {
pub data: String,
pub display_id: String,
pub hashed: Option<bool>,
pub hashing_method: Option<String>,
pub ignore_cache: Option<String>,
pub json: Option<bool>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: i32,
}Fields
data: StringData
display_id: StringThe name of the key to use in the sign data process
hashed: Option<bool>Defines whether the data should be hashed as part of the signing. If true, the data will not be hashed
hashing_method: Option<String>HashingMethod
ignore_cache: Option<String>Retrieve the Secret value without checking the Gateway’s cache [true/false]. This flag is only relevant when using the RestAPI
json: Option<bool>Set output format to JSON
name: StringClassicKey name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: i32classic key version
Implementations