pub struct SignEcDsa {
pub accessibility: Option<String>,
pub display_id: Option<String>,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub key_name: Option<String>,
pub message: String,
pub prehashed: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: Option<i32>,
}Expand description
SignEcDsa : signEcDsa Calculates the signature of a given message using ECDSA and a sha hash algorithm matching the key size
Fields
accessibility: Option<String>for personal password manager
display_id: Option<String>The display id of the EC key to use for the signing process
item_id: Option<i64>The item id of the EC key to use for the signing process
json: Option<bool>Set output format to JSON
key_name: Option<String>The name of the EC key to use for the signing process
message: StringThe input message to sign in a base64 format
prehashed: Option<bool>Markes that the message is already hashed
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: Option<i32>The version of the key to use for signing
Implementations