pub struct SignPkcs1 {
pub display_id: Option<String>,
pub hash_function: Option<String>,
pub input_format: Option<String>,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub key_name: Option<String>,
pub message: String,
pub prehashed: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: Option<i32>,
}Expand description
SignPkcs1 : signPKCS1 is a command that calculates the signature of hashed data using RSASSA-PKCS1-V1_5-SIGN from RSA PKCS#1 v1.5.
Fields
display_id: Option<String>The display id of the key to use in the signing process
hash_function: Option<String>HashFunction defines the hash function (e.g. sha-256)
input_format: Option<String>Select default assumed format for the plaintext message. Currently supported options: [base64]
item_id: Option<i64>The item id of the key to use in the signing process
json: Option<bool>Set output format to JSON
key_name: Option<String>The name of the RSA key to use in the signing process
message: StringThe message to be signed
prehashed: Option<bool>Markes that the message is already hashed
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: Option<i32>The version of the key to use for signing
Implementations