pub struct SplunkTargetDetails {
pub audience: Option<String>,
pub auth_mode: Option<String>,
pub password: Option<String>,
pub splunk_payload: Option<Box<SplunkPayload>>,
pub splunk_url: Option<String>,
pub token: Option<String>,
pub token_owner: Option<String>,
pub use_tls: Option<bool>,
pub username: Option<String>,
}Expand description
SplunkTargetDetails : SplunkTargetDetails defines details related to connecting to a Splunk server
Fields
audience: Option<String>Token audience
auth_mode: Option<String>Authentication mode: "username" or "token"
password: Option<String>splunk_payload: Option<Box<SplunkPayload>>splunk_url: Option<String>Splunk server URL
token: Option<String>Token is used when AuthMode == "token"
token_owner: Option<String>Token owner (the Splunk user who owns the token, required for token rotation)
use_tls: Option<bool>Use TLS certificate verification when connecting to the Splunk management API.
username: Option<String>Username & Password are used when AuthMode == "username"
Implementations
Sourceimpl SplunkTargetDetails
impl SplunkTargetDetails
Sourcepub fn new() -> SplunkTargetDetails
pub fn new() -> SplunkTargetDetails
SplunkTargetDetails defines details related to connecting to a Splunk server