pub struct StaticCredsAuth {
pub access_id: Option<String>,
pub admin_email: Option<String>,
pub creds: Option<String>,
pub json: Option<bool>,
}Expand description
StaticCredsAuth : staticCredsAuth is a command that creates a temporary access profile using the provided static credentials.
Fields
access_id: Option<String>Akeyless JWT token
admin_email: Option<String>Akeyless JWT token
creds: Option<String>Akeyless JWT token
json: Option<bool>Set output format to JSON
Implementations
Sourceimpl StaticCredsAuth
impl StaticCredsAuth
Sourcepub fn new() -> StaticCredsAuth
pub fn new() -> StaticCredsAuth
staticCredsAuth is a command that creates a temporary access profile using the provided static credentials.