pub struct TargetCreateAzure {Show 16 fields
pub azure_cloud: Option<String>,
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub connection_type: Option<String>,
pub description: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub resource_group_name: Option<String>,
pub resource_name: Option<String>,
pub subscription_id: Option<String>,
pub tenant_id: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub use_gw_cloud_identity: Option<bool>,
}Fields
azure_cloud: Option<String>Azure cloud environment to use. Values: AzureCloud (default), AzureUSGovernment, AzureChinaCloud.
client_id: Option<String>Azure client/application id
client_secret: Option<String>Azure client secret
connection_type: Option<String>Type of connection [credentials/cloud-identity]
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
resource_group_name: Option<String>The Resource Group name in your Azure subscription
resource_name: Option<String>The name of the relevant Resource
subscription_id: Option<String>Azure Subscription Id
tenant_id: Option<String>Azure tenant id
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
use_gw_cloud_identity: Option<bool>Use the GW’s Cloud IAM [Deprecated: Use connection-type=cloud-identity]
Implementations
Sourceimpl TargetCreateAzure
impl TargetCreateAzure
pub fn new(name: String) -> TargetCreateAzure