TargetCreateDb

Struct TargetCreateDb 

pub struct TargetCreateDb {
Show 38 fields pub azure_client_id: Option<String>, pub azure_client_secret: Option<String>, pub azure_tenant_id: Option<String>, pub cloud_service_provider: Option<String>, pub cluster_mode: Option<bool>, pub comment: Option<String>, pub connection_type: String, pub db_name: Option<String>, pub db_server_certificates: Option<String>, pub db_server_name: Option<String>, pub db_type: String, pub description: Option<String>, pub host: Option<String>, pub json: Option<bool>, pub key: Option<String>, pub max_versions: Option<String>, pub mongodb_atlas: Option<bool>, pub mongodb_atlas_api_private_key: Option<String>, pub mongodb_atlas_api_public_key: Option<String>, pub mongodb_atlas_project_id: Option<String>, pub mongodb_default_auth_db: Option<String>, pub mongodb_uri_options: Option<String>, pub name: String, pub oracle_service_name: Option<String>, pub oracle_wallet_login_type: Option<String>, pub oracle_wallet_p12_file_data: Option<String>, pub oracle_wallet_sso_file_data: Option<String>, pub parent_target_name: Option<String>, pub port: Option<String>, pub pwd: Option<String>, pub snowflake_account: Option<String>, pub snowflake_api_private_key: Option<String>, pub snowflake_api_private_key_password: Option<String>, pub ssl: Option<bool>, pub ssl_certificate: Option<String>, pub token: Option<String>, pub uid_token: Option<String>, pub user_name: Option<String>,
}

Fields

azure_client_id: Option<String>

(Optional) Client id (relevant for "cloud-service-provider" only)

azure_client_secret: Option<String>

(Optional) Client secret (relevant for "cloud-service-provider" only)

azure_tenant_id: Option<String>

(Optional) Tenant id (relevant for "cloud-service-provider" only)

cloud_service_provider: Option<String>

(Optional) Cloud service provider (currently only supports Azure)

cluster_mode: Option<bool>

Cluster Mode

comment: Option<String>

Deprecated - use description

connection_type: String

Type of connection to mssql database [credentials/cloud-identity/wallet/parent-target]

db_name: Option<String>db_server_certificates: Option<String>

(Optional) DB server certificates

db_server_name: Option<String>

(Optional) Server name for certificate verification

db_type: Stringdescription: Option<String>

Description of the object

host: Option<String>json: Option<bool>

Set output format to JSON

key: Option<String>

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)

max_versions: Option<String>

Set the maximum number of versions, limited by the account settings defaults.

mongodb_atlas: Option<bool>mongodb_atlas_api_private_key: Option<String>

MongoDB Atlas private key

mongodb_atlas_api_public_key: Option<String>

MongoDB Atlas public key

mongodb_atlas_project_id: Option<String>

MongoDB Atlas project ID

mongodb_default_auth_db: Option<String>

MongoDB server default authentication database

mongodb_uri_options: Option<String>

MongoDB server URI options

name: String

Target name

oracle_service_name: Option<String>

Oracle db service name

oracle_wallet_login_type: Option<String>

Oracle Wallet login type (password/mtls)

oracle_wallet_p12_file_data: Option<String>

Oracle wallet p12 file data in base64

oracle_wallet_sso_file_data: Option<String>

Oracle wallet sso file data in base64

parent_target_name: Option<String>

Name of the parent target, relevant only when connection-type is parent-target

port: Option<String>pwd: Option<String>snowflake_account: Option<String>snowflake_api_private_key: Option<String>

RSA Private key (base64 encoded)

snowflake_api_private_key_password: Option<String>

The Private key passphrase

ssl: Option<bool>

Enable/Disable SSL [true/false]

ssl_certificate: Option<String>

SSL connection certificate

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

user_name: Option<String>

Implementations

Source

impl TargetCreateDb

pub fn new( connection_type: String, db_type: String, name: String, ) -> TargetCreateDb