pub struct TargetCreateGcp {
pub description: Option<String>,
pub gcp_key: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub use_gw_cloud_identity: Option<bool>,
}Fields
description: Option<String>Description of the object
gcp_key: Option<String>Base64-encoded service account private key text
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
use_gw_cloud_identity: Option<bool>Implementations
Sourceimpl TargetCreateGcp
impl TargetCreateGcp
pub fn new(name: String) -> TargetCreateGcp