pub struct TargetCreateGitlab {
pub description: Option<String>,
pub gitlab_access_token: Option<String>,
pub gitlab_certificate: Option<String>,
pub gitlab_url: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
description: Option<String>Description of the object
gitlab_access_token: Option<String>Gitlab access token
gitlab_certificate: Option<String>Gitlab tls certificate (base64 encoded)
gitlab_url: Option<String>Gitlab base url
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetCreateGitlab
impl TargetCreateGitlab
pub fn new(name: String) -> TargetCreateGitlab