pub struct TargetCreateGlobalSignAtlas {
pub api_key: String,
pub api_secret: String,
pub description: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub mtls_cert_data_base64: Option<String>,
pub mtls_key_data_base64: Option<String>,
pub name: String,
pub timeout: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
api_key: StringAPI Key of the GlobalSign Atlas account
api_secret: StringAPI Secret of the GlobalSign Atlas account
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
mtls_cert_data_base64: Option<String>Mutual TLS Certificate contents of the GlobalSign Atlas account encoded in base64, either mtls-cert-file-path or mtls-cert-data-base64 must be supplied
mtls_key_data_base64: Option<String>Mutual TLS Key contents of the GlobalSign Atlas account encoded in base64, either mtls-key-file-path or mtls-data-base64 must be supplied
name: StringTarget name
timeout: Option<String>Timeout waiting for certificate validation in Duration format (1h - 1 Hour, 20m - 20 Minutes, 33m3s - 33 Minutes and 3 Seconds), maximum 1h.
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations