pub struct TargetCreateLdap {Show 13 fields
pub bind_dn: String,
pub bind_dn_password: String,
pub description: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub ldap_ca_cert: Option<String>,
pub ldap_url: String,
pub max_versions: Option<String>,
pub name: String,
pub server_type: Option<String>,
pub token: Option<String>,
pub token_expiration: Option<String>,
pub uid_token: Option<String>,
}Expand description
TargetCreateLdap : targetCreateLdap is a command that creates a new ldap target
Fields
bind_dn: StringBind DN
bind_dn_password: StringBind DN Password
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
ldap_ca_cert: Option<String>CA Certificate File Content
ldap_url: StringLDAP Server URL
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
server_type: Option<String>Set Ldap server type, Options:[OpenLDAP, ActiveDirectory]. Default is OpenLDAP
token: Option<String>Authentication token (see /auth and /configure)
token_expiration: Option<String>Token expiration
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations