pub struct TargetCreateOpenAi {
pub api_key: Option<String>,
pub api_key_id: Option<String>,
pub description: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub model: Option<String>,
pub name: String,
pub openai_url: Option<String>,
pub organization_id: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
TargetCreateOpenAi : targetCreateOpenAI is a command that creates a new openai target
Fields
api_key: Option<String>API key for OpenAI
api_key_id: Option<String>API key ID
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
model: Option<String>Default model to use with OpenAI
name: StringTarget name
openai_url: Option<String>Base URL of the OpenAI API
organization_id: Option<String>Organization ID
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetCreateOpenAi
impl TargetCreateOpenAi
Sourcepub fn new(name: String) -> TargetCreateOpenAi
pub fn new(name: String) -> TargetCreateOpenAi
targetCreateOpenAI is a command that creates a new openai target