pub struct TargetCreatePing {
pub administrative_port: Option<String>,
pub authorization_port: Option<String>,
pub description: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub password: Option<String>,
pub ping_url: Option<String>,
pub privileged_user: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
TargetCreatePing : targetCreatePing is a command that creates a new ping target
Fields
administrative_port: Option<String>Ping Federate administrative port
Ping Federate authorization port
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
password: Option<String>Ping Federate privileged user password
ping_url: Option<String>Ping URL
privileged_user: Option<String>Ping Federate privileged user
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetCreatePing
impl TargetCreatePing
Sourcepub fn new(name: String) -> TargetCreatePing
pub fn new(name: String) -> TargetCreatePing
targetCreatePing is a command that creates a new ping target