pub struct TargetCreateSectigo {Show 14 fields
pub certificate_profile_id: i64,
pub customer_uri: String,
pub description: Option<String>,
pub external_requester: String,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub organization_id: i64,
pub password: String,
pub timeout: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub username: String,
}Expand description
TargetCreateSectigo : targetCreateSectigo is a command that creates a new Sectigo target
Fields
certificate_profile_id: i64Certificate Profile ID in Sectigo account
customer_uri: StringCustomer Uri of the Sectigo account
description: Option<String>Description of the object
external_requester: StringExternal Requester - a comma separated list of emails
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
organization_id: i64Organization ID in Sectigo account
password: StringPassword of the Sectigo account user
timeout: Option<String>Timeout waiting for certificate validation in Duration format (1h - 1 Hour, 20m - 20 Minutes, 33m3s - 33 Minutes and 3 Seconds), maximum 1h.
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
username: StringUsername of the Sectigo account
Implementations