pub struct TargetCreateSplunk {Show 13 fields
pub audience: Option<String>,
pub description: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub password: Option<String>,
pub token: Option<String>,
pub token_owner: Option<String>,
pub uid_token: Option<String>,
pub url: String,
pub use_tls: Option<bool>,
pub username: Option<String>,
}Expand description
TargetCreateSplunk : targetCreateSplunk is a command that creates a new splunk target
Fields
audience: Option<String>Splunk token audience (required when using token authentication for rotation)
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
password: Option<String>Splunk Password (used when authenticating with username/password)
token: Option<String>Splunk Token (used when authenticating with token)
token_owner: Option<String>Splunk Token Owner (required when using token authentication for rotation)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
url: StringSplunk server URL
use_tls: Option<bool>Use TLS certificate verification when connecting to the Splunk management API
username: Option<String>Splunk Username (used when authenticating with username/password)
Implementations
Sourceimpl TargetCreateSplunk
impl TargetCreateSplunk
Sourcepub fn new(name: String, url: String) -> TargetCreateSplunk
pub fn new(name: String, url: String) -> TargetCreateSplunk
targetCreateSplunk is a command that creates a new splunk target