pub struct TargetCreateSsh {Show 13 fields
pub description: Option<String>,
pub host: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub port: Option<String>,
pub private_key: Option<String>,
pub private_key_password: Option<String>,
pub ssh_password: Option<String>,
pub ssh_username: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
TargetCreateSsh : targetCreateSsh is a command that creates a new ssh target
Fields
description: Option<String>Description of the object
host: Option<String>SSH host name
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
port: Option<String>SSH port
private_key: Option<String>SSH private key
private_key_password: Option<String>SSH private key password
ssh_password: Option<String>SSH password to rotate
ssh_username: Option<String>SSH username
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetCreateSsh
impl TargetCreateSsh
Sourcepub fn new(name: String) -> TargetCreateSsh
pub fn new(name: String) -> TargetCreateSsh
targetCreateSsh is a command that creates a new ssh target