pub struct TargetCreateWeb {
pub description: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub url: Option<String>,
}Expand description
TargetCreateWeb : targetCreateWeb is a command that creates a new web target
Fields
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
url: Option<String>The url
Implementations
Sourceimpl TargetCreateWeb
impl TargetCreateWeb
Sourcepub fn new(name: String) -> TargetCreateWeb
pub fn new(name: String) -> TargetCreateWeb
targetCreateWeb is a command that creates a new web target