pub struct TargetItemAssociation {
pub assoc_id: Option<String>,
pub attributes: Option<HashMap<String, String>>,
pub cluster_id: Option<i64>,
pub item_id: Option<i64>,
pub item_name: Option<String>,
pub item_type: Option<String>,
pub relationship: Option<String>,
}Expand description
TargetItemAssociation : TargetItemAssociation includes details of an association between a target and an item. Also, between targets in case of child target or Linked target.
Fields
assoc_id: Option<String>attributes: Option<HashMap<String, String>>cluster_id: Option<i64>item_id: Option<i64>item_name: Option<String>item_type: Option<String>relationship: Option<String>Implementations
Sourceimpl TargetItemAssociation
impl TargetItemAssociation
Sourcepub fn new() -> TargetItemAssociation
pub fn new() -> TargetItemAssociation
TargetItemAssociation includes details of an association between a target and an item. Also, between targets in case of child target or Linked target.