pub struct TargetList {
pub filter: Option<String>,
pub json: Option<bool>,
pub pagination_token: Option<String>,
pub token: Option<String>,
pub type: Option<Vec<String>>,
pub uid_token: Option<String>,
}Expand description
TargetList : targetList is a command that returns a list of targets
Fields
filter: Option<String>Filter by auth method name or part of it
json: Option<bool>Set output format to JSON
pagination_token: Option<String>Next page reference
token: Option<String>Authentication token (see /auth and /configure)
type: Option<Vec<String>>The target types list . In case it is empty, all types of targets will be returned. options: [hanadb cassandra aws ssh gke eks mysql mongodb snowflake mssql redshift artifactory azure rabbitmq k8s venafi gcp oracle dockerhub ldap github chef web salesforce postgres]
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetList
impl TargetList
Sourcepub fn new() -> TargetList
pub fn new() -> TargetList
targetList is a command that returns a list of targets