pub struct TargetUpdateDockerhub {
pub description: Option<String>,
pub dockerhub_password: Option<String>,
pub dockerhub_username: Option<String>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
description: Option<String>Description of the object
dockerhub_password: Option<String>Password for docker repository
dockerhub_username: Option<String>Username for docker repository
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetUpdateDockerhub
impl TargetUpdateDockerhub
pub fn new(name: String) -> TargetUpdateDockerhub