pub struct TargetUpdateGemini {
pub api_key: Option<String>,
pub description: Option<String>,
pub gemini_url: Option<String>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_comment: Option<String>,
pub new_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
TargetUpdateGemini : targetUpdateGemini is a command that updates an existing gemini target
Fields
api_key: Option<String>API key for Gemini
description: Option<String>Description of the object
gemini_url: Option<String>Base URL of the Gemini API
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_comment: Option<String>Deprecated - use description
new_name: Option<String>New target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetUpdateGemini
impl TargetUpdateGemini
Sourcepub fn new(name: String) -> TargetUpdateGemini
pub fn new(name: String) -> TargetUpdateGemini
targetUpdateGemini is a command that updates an existing gemini target