pub struct TargetUpdateGithub {
pub description: Option<String>,
pub github_app_id: Option<i64>,
pub github_app_private_key: Option<String>,
pub github_base_url: Option<String>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
description: Option<String>Description of the object
github_app_id: Option<i64>Github app id
github_app_private_key: Option<String>App private key
github_base_url: Option<String>Base URL
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetUpdateGithub
impl TargetUpdateGithub
pub fn new(name: String) -> TargetUpdateGithub