pub struct TargetUpdateK8s {Show 17 fields
pub description: Option<String>,
pub json: Option<bool>,
pub k8s_auth_type: Option<String>,
pub k8s_client_certificate: Option<String>,
pub k8s_client_key: Option<String>,
pub k8s_cluster_ca_cert: Option<String>,
pub k8s_cluster_endpoint: Option<String>,
pub k8s_cluster_name: Option<String>,
pub k8s_cluster_token: Option<String>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub use_gw_service_account: Option<bool>,
}Expand description
TargetUpdateK8s : targetUpdateK8s is a command that updates an existing k8s target
Fields
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
k8s_auth_type: Option<String>K8S auth type [token/certificate]
k8s_client_certificate: Option<String>Content of the k8 client certificate (PEM format) in a Base64 format
k8s_client_key: Option<String>Content of the k8 client private key (PEM format) in a Base64 format
k8s_cluster_ca_cert: Option<String>K8S cluster CA certificate
k8s_cluster_endpoint: Option<String>K8S cluster URL endpoint
k8s_cluster_name: Option<String>K8S cluster name
k8s_cluster_token: Option<String>K8S cluster Bearer token
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
use_gw_service_account: Option<bool>Use the GW’s service account
Implementations
Sourceimpl TargetUpdateK8s
impl TargetUpdateK8s
Sourcepub fn new(name: String) -> TargetUpdateK8s
pub fn new(name: String) -> TargetUpdateK8s
targetUpdateK8s is a command that updates an existing k8s target