pub struct TargetUpdateLetsEncrypt {Show 17 fields
pub acme_challenge: Option<String>,
pub description: Option<String>,
pub dns_target_creds: Option<String>,
pub email: Option<String>,
pub gcp_project: Option<String>,
pub hosted_zone: Option<String>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub lets_encrypt_url: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub resource_group: Option<String>,
pub timeout: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
TargetUpdateLetsEncrypt : targetUpdateLetsEncrypt is a command that updates an existing Let’s Encrypt target
Fields
acme_challenge: Option<String>description: Option<String>Description of the object
dns_target_creds: Option<String>Name of existing cloud target for DNS credentials. Required when acme-challenge=dns. Supported: AWS, Azure, GCP targets
email: Option<String>Email address for ACME account registration
gcp_project: Option<String>GCP Cloud DNS: Project ID. Optional - can be derived from service account
hosted_zone: Option<String>AWS Route53 hosted zone ID. Required when dns-target-creds points to AWS target
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
lets_encrypt_url: Option<String>max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
resource_group: Option<String>Azure resource group name. Required when dns-target-creds points to Azure target
timeout: Option<String>token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetUpdateLetsEncrypt
impl TargetUpdateLetsEncrypt
Sourcepub fn new(name: String) -> TargetUpdateLetsEncrypt
pub fn new(name: String) -> TargetUpdateLetsEncrypt
targetUpdateLetsEncrypt is a command that updates an existing Let’s Encrypt target