pub struct TargetUpdateLinked {
pub add_hosts: Option<String>,
pub description: Option<String>,
pub hosts: Option<String>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub parent_target_name: Option<String>,
pub rm_hosts: Option<String>,
pub token: Option<String>,
pub type: Option<String>,
pub uid_token: Option<String>,
}Fields
add_hosts: Option<String>A comma seperated list of new server hosts and server descriptions joined by semicolon ‘;’ that will be added to the Linked Target hosts.
description: Option<String>Description of the object
hosts: Option<String>A comma seperated list of server hosts and server descriptions joined by semicolon ‘;’ (i.e. ‘server-dev.com;My Dev server,server-prod.com;My Prod server description’)
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
name: StringLinked Target name
new_name: Option<String>New Linked Target name
parent_target_name: Option<String>The parent Target name
rm_hosts: Option<String>Comma separated list of existing hosts that will be removed from Linked Target hosts.
token: Option<String>Authentication token (see /auth and /configure)
type: Option<String>Specifies the hosts type, relevant only when working without parent target
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetUpdateLinked
impl TargetUpdateLinked
pub fn new(name: String) -> TargetUpdateLinked