pub struct TargetUpdateRabbitMq {
pub description: Option<String>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub rabbitmq_server_password: Option<String>,
pub rabbitmq_server_uri: Option<String>,
pub rabbitmq_server_user: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
TargetUpdateRabbitMq : targetUpdateRabbitMq is a command that updates an existing rabbitmq target
Fields
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
rabbitmq_server_password: Option<String>rabbitmq_server_uri: Option<String>rabbitmq_server_user: Option<String>token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl TargetUpdateRabbitMq
impl TargetUpdateRabbitMq
Sourcepub fn new(name: String) -> TargetUpdateRabbitMq
pub fn new(name: String) -> TargetUpdateRabbitMq
targetUpdateRabbitMq is a command that updates an existing rabbitmq target