pub struct TargetUpdateWindows {Show 18 fields
pub certificate: Option<String>,
pub connection_type: Option<String>,
pub description: Option<String>,
pub domain: Option<String>,
pub hostname: String,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub parent_target_name: Option<String>,
pub password: String,
pub port: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub use_tls: Option<String>,
pub username: String,
}Expand description
TargetUpdateWindows : GatewayUpdateProducerWindowsCmd is a command that updates an existing windows target
Fields
certificate: Option<String>SSL CA certificate in base64 encoding generated from a trusted Certificate Authority (CA)
connection_type: Option<String>Type of connection to Windows Server [credentials/parent-target]
description: Option<String>Description of the object
domain: Option<String>User domain name
hostname: StringServer hostname
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
parent_target_name: Option<String>Name of the parent target, relevant only when connection-type is parent-target
password: StringPrivileged user password
port: Option<String>Server WinRM port
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
use_tls: Option<String>Enable/Disable TLS for WinRM over HTTPS [true/false]
username: StringPrivileged username
Implementations