pub struct TargetUpdateZeroSsl {Show 16 fields
pub api_key: String,
pub description: Option<String>,
pub imap_fqdn: String,
pub imap_password: String,
pub imap_port: Option<String>,
pub imap_target_email: Option<String>,
pub imap_username: String,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub timeout: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
TargetUpdateZeroSsl : targetUpdateZeroSSL is a command that updates an existing ZeroSSL target
Fields
api_key: StringAPI Key of the ZeroSSLTarget account
description: Option<String>Description of the object
imap_fqdn: StringImapFQDN of the IMAP service, FQDN or IPv4 address. Must be FQDN if the IMAP is using TLS
imap_password: StringImapPassword to access the IMAP service
imap_port: Option<String>ImapPort of the IMAP service
imap_target_email: Option<String>ImapValidationEmail to use when asking ZeroSSL to send a validation email, if empty will user imap-username
imap_username: StringImapUsername to access the IMAP service
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
timeout: Option<String>Timeout waiting for certificate validation in Duration format (1h - 1 Hour, 20m - 20 Minutes, 33m3s - 33 Minutes and 3 Seconds), maximum 1h.
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations