pub struct UidCreateChildToken {
pub auth_method_name: Option<String>,
pub child_deny_inheritance: Option<bool>,
pub child_deny_rotate: Option<bool>,
pub child_ttl: Option<i32>,
pub comment: Option<String>,
pub description: Option<String>,
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub uid_token_id: Option<String>,
}Expand description
UidCreateChildToken : uidCreateChildToken is a command that creates a new child token using Akeyless Universal Identity.
Fields
auth_method_name: Option<String>The universal identity auth method name, required only when uid-token is not provided
child_deny_inheritance: Option<bool>Deny from new child to create their own children
child_deny_rotate: Option<bool>Deny from new child to rotate
child_ttl: Option<i32>New child token ttl
comment: Option<String>Deprecated - use description
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
uid_token_id: Option<String>The ID of the uid-token, required only when uid-token is not provided
Implementations
Sourceimpl UidCreateChildToken
impl UidCreateChildToken
Sourcepub fn new() -> UidCreateChildToken
pub fn new() -> UidCreateChildToken
uidCreateChildToken is a command that creates a new child token using Akeyless Universal Identity.