pub struct UidGenerateToken {
pub auth_method_name: String,
pub json: Option<bool>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
UidGenerateToken : uidGenerateToken is a command that generates a new token using Akeyless Universal Identity.
Fields
auth_method_name: StringThe universal identity auth method name
json: Option<bool>Set output format to JSON
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl UidGenerateToken
impl UidGenerateToken
Sourcepub fn new(auth_method_name: String) -> UidGenerateToken
pub fn new(auth_method_name: String) -> UidGenerateToken
uidGenerateToken is a command that generates a new token using Akeyless Universal Identity.