pub struct UidRotateToken {
pub fork: Option<bool>,
pub json: Option<bool>,
pub send_manual_ack_token: Option<String>,
pub uid_token: Option<String>,
pub with_manual_ack: Option<bool>,
}Expand description
UidRotateToken : uidRotateToken is a command that rotates an Akeyless Universal Identity token.
Fields
fork: Option<bool>Create a new child token with default parameters
json: Option<bool>Set output format to JSON
send_manual_ack_token: Option<String>The new rotated token to send manual ack for (with uid-token=the-orig-token)
uid_token: Option<String>The Universal identity token
with_manual_ack: Option<bool>Disable automatic ack
Implementations
Sourceimpl UidRotateToken
impl UidRotateToken
Sourcepub fn new() -> UidRotateToken
pub fn new() -> UidRotateToken
uidRotateToken is a command that rotates an Akeyless Universal Identity token.