pub struct UpdateAssoc {
pub assoc_id: String,
pub case_sensitive: Option<String>,
pub json: Option<bool>,
pub sub_claims: Option<HashMap<String, String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
UpdateAssoc : updateAssoc is a command that updates the sub-claims of an association between role and auth method.
Fields
assoc_id: StringThe association id to be updated
case_sensitive: Option<String>Treat sub claims as case-sensitive [true/false]
json: Option<bool>Set output format to JSON
sub_claims: Option<HashMap<String, String>>key/val of sub claims, e.g group=admins,developers
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl UpdateAssoc
impl UpdateAssoc
Sourcepub fn new(assoc_id: String) -> UpdateAssoc
pub fn new(assoc_id: String) -> UpdateAssoc
updateAssoc is a command that updates the sub-claims of an association between role and auth method.