Module update_auth_method_awsiam

Module update_auth_method_awsiam 

Structs

UpdateAuthMethodAwsiam
UpdateAuthMethodAwsiam : updateAuthMethodAWSIAM is a command that updates a new Auth Method that will be able to authenticate using AWS IAM credentials. [Deprecated: Use auth-method-update-aws-iam command]