Module update_auth_method_cert

Module update_auth_method_cert 

Structs

UpdateAuthMethodCert
UpdateAuthMethodCert : updateAuthMethodCert is a command that updates a new auth method that will be able to authenticate using a client certificate. [Deprecated: Use auth-method-update-cert command]