Module update_auth_method_gcp

Module update_auth_method_gcp 

Structs

UpdateAuthMethodGcp
UpdateAuthMethodGcp : updateAuthMethodGCP is a command that updates a new auth method that will be able to authenticate using GCP IAM Service Account credentials or GCE instance credentials. [Deprecated: Use auth-method-update-gcp command]