pub struct UpdateAuthMethodGcp {Show 25 fields
pub access_expires: Option<i64>,
pub allowed_client_type: Option<Vec<String>>,
pub audience: String,
pub audit_logs_claims: Option<Vec<String>>,
pub bound_ips: Option<Vec<String>>,
pub bound_labels: Option<Vec<String>>,
pub bound_projects: Option<Vec<String>>,
pub bound_regions: Option<Vec<String>>,
pub bound_service_accounts: Option<Vec<String>>,
pub bound_zones: Option<Vec<String>>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub force_sub_claims: Option<bool>,
pub gw_bound_ips: Option<Vec<String>>,
pub json: Option<bool>,
pub jwt_ttl: Option<i64>,
pub name: String,
pub new_name: Option<String>,
pub product_type: Option<Vec<String>>,
pub service_account_creds_data: Option<String>,
pub token: Option<String>,
pub type: String,
pub uid_token: Option<String>,
pub unique_identifier: Option<String>,
}Expand description
UpdateAuthMethodGcp : updateAuthMethodGCP is a command that updates a new auth method that will be able to authenticate using GCP IAM Service Account credentials or GCE instance credentials. [Deprecated: Use auth-method-update-gcp command]
Fields
access_expires: Option<i64>Access expiration date in Unix timestamp (select 0 for access without expiry date)
allowed_client_type: Option<Vec<String>>limit the auth method usage for specific client types [cli,ui,gateway-admin,sdk,mobile,extension]
audience: StringThe audience to verify in the JWT received by the client
audit_logs_claims: Option<Vec<String>>Subclaims to include in audit logs, e.g "–audit-logs-claims email –audit-logs-claims username"
bound_ips: Option<Vec<String>>A CIDR whitelist with the IPs that the access is restricted to
bound_labels: Option<Vec<String>>A comma-separated list of GCP labels formatted as "key:value" strings that must be set on authorized GCE instances. TODO: Because GCP labels are not currently ACL’d ….
bound_projects: Option<Vec<String>>=== Human and Machine authentication section === Array of GCP project IDs. Only entities belonging to any of the provided projects can authenticate.
bound_regions: Option<Vec<String>>List of regions that a GCE instance must belong to in order to be authenticated. TODO: If bound_instance_groups is provided, it is assumed to be a regional group and the group must belong to this region. If bound_zones are provided, this attribute is ignored.
bound_service_accounts: Option<Vec<String>>List of service accounts the service account must be part of in order to be authenticated.
bound_zones: Option<Vec<String>>=== Machine authentication section === List of zones that a GCE instance must belong to in order to be authenticated. TODO: If bound_instance_groups is provided, it is assumed to be a zonal group and the group must belong to this zone.
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Auth Method description
expiration_event_in: Option<Vec<String>>How many days before the expiration of the auth method would you like to be notified.
force_sub_claims: Option<bool>if true: enforce role-association must include sub claims
gw_bound_ips: Option<Vec<String>>A CIDR whitelist with the GW IPs that the access is restricted to
json: Option<bool>Set output format to JSON
jwt_ttl: Option<i64>Jwt TTL
name: StringAuth Method name
new_name: Option<String>Auth Method new name
product_type: Option<Vec<String>>Choose the relevant product type for the auth method [sm, sra, pm, dp, ca]
service_account_creds_data: Option<String>ServiceAccount credentials data instead of giving a file path, base64 encoded
token: Option<String>Authentication token (see /auth and /configure)
type: StringType of the GCP Access Rules
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
unique_identifier: Option<String>A unique identifier (ID) value which is a "sub claim" name that contains details uniquely identifying that resource. This "sub claim" is used to distinguish between different identities.
Implementations
Sourceimpl UpdateAuthMethodGcp
impl UpdateAuthMethodGcp
Sourcepub fn new(audience: String, name: String, type: String) -> UpdateAuthMethodGcp
pub fn new(audience: String, name: String, type: String) -> UpdateAuthMethodGcp
updateAuthMethodGCP is a command that updates a new auth method that will be able to authenticate using GCP IAM Service Account credentials or GCE instance credentials. [Deprecated: Use auth-method-update-gcp command]