Module update_auth_method_k8_s

Module update_auth_method_k8_s 

Structs

UpdateAuthMethodK8S
UpdateAuthMethodK8S : updateAuthMethodK8S is a command that updates a new auth method that will be able to authenticate using K8S. [Deprecated: Use auth-method-update-k8s command]