pub struct UpdateAuthMethodK8S {Show 22 fields
pub access_expires: Option<i64>,
pub allowed_client_type: Option<Vec<String>>,
pub audience: Option<String>,
pub audit_logs_claims: Option<Vec<String>>,
pub bound_ips: Option<Vec<String>>,
pub bound_namespaces: Option<Vec<String>>,
pub bound_pod_names: Option<Vec<String>>,
pub bound_sa_names: Option<Vec<String>>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub force_sub_claims: Option<bool>,
pub gen_key: Option<String>,
pub gw_bound_ips: Option<Vec<String>>,
pub json: Option<bool>,
pub jwt_ttl: Option<i64>,
pub name: String,
pub new_name: Option<String>,
pub product_type: Option<Vec<String>>,
pub public_key: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
UpdateAuthMethodK8S : updateAuthMethodK8S is a command that updates a new auth method that will be able to authenticate using K8S. [Deprecated: Use auth-method-update-k8s command]
Fields
access_expires: Option<i64>Access expiration date in Unix timestamp (select 0 for access without expiry date)
allowed_client_type: Option<Vec<String>>limit the auth method usage for specific client types [cli,ui,gateway-admin,sdk,mobile,extension]
audience: Option<String>The audience in the Kubernetes JWT that the access is restricted to
audit_logs_claims: Option<Vec<String>>Subclaims to include in audit logs, e.g "–audit-logs-claims email –audit-logs-claims username"
bound_ips: Option<Vec<String>>A CIDR whitelist with the IPs that the access is restricted to
bound_namespaces: Option<Vec<String>>A list of namespaces that the access is restricted to
bound_pod_names: Option<Vec<String>>A list of pod names that the access is restricted to
bound_sa_names: Option<Vec<String>>A list of service account names that the access is restricted to
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Auth Method description
expiration_event_in: Option<Vec<String>>How many days before the expiration of the auth method would you like to be notified.
force_sub_claims: Option<bool>if true: enforce role-association must include sub claims
gen_key: Option<String>Automatically generate key-pair for K8S configuration. If set to false, a public key needs to be provided [true/false]
gw_bound_ips: Option<Vec<String>>A CIDR whitelist with the GW IPs that the access is restricted to
json: Option<bool>Set output format to JSON
jwt_ttl: Option<i64>Jwt TTL
name: StringAuth Method name
new_name: Option<String>Auth Method new name
product_type: Option<Vec<String>>Choose the relevant product type for the auth method [sm, sra, pm, dp, ca]
public_key: Option<String>Base64-encoded or PEM formatted public key data for K8S authentication method is required [RSA2048]
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl UpdateAuthMethodK8S
impl UpdateAuthMethodK8S
Sourcepub fn new(name: String) -> UpdateAuthMethodK8S
pub fn new(name: String) -> UpdateAuthMethodK8S
updateAuthMethodK8S is a command that updates a new auth method that will be able to authenticate using K8S. [Deprecated: Use auth-method-update-k8s command]