Module update_auth_method_ldap

Module update_auth_method_ldap 

Structs

UpdateAuthMethodLdap
UpdateAuthMethodLdap : updateAuthMethodLDAP is a command that updates a new auth method that will be able to authenticate using LDAP. [Deprecated: Use auth-method-update-ldap command]