Module update_auth_method_o_auth2

Module update_auth_method_o_auth2 

Structs

UpdateAuthMethodOAuth2
UpdateAuthMethodOAuth2 : updateAuthMethodOAuth2 is a command that updates a new auth method that will be able to authenticate using Oauth2. [Deprecated: Use auth-method-update-oauth2 command]