Module update_auth_method_oci

Module update_auth_method_oci 

Structs

UpdateAuthMethodOci
UpdateAuthMethodOci : updateAuthMethodOCI is a command that updates an auth method that will be used in the account using OCI principle and groups. [Deprecated: Use auth-method-update-oci command]