Module update_auth_method_oidc

Module update_auth_method_oidc 

Structs

UpdateAuthMethodOidc
UpdateAuthMethodOidc : updateAuthMethodOIDC is a command that updates a new auth method that will be available to authenticate using OIDC. [Deprecated: Use auth-method-update-oidc command]