Module update_auth_method_saml

Module update_auth_method_saml 

Structs

UpdateAuthMethodSaml
UpdateAuthMethodSaml : updateAuthMethodSAML is a command that updates a new auth method that will be available to authenticate using SAML. [Deprecated: Use auth-method-update-saml command]