pub struct UpdateAuthMethodSaml {Show 21 fields
pub access_expires: Option<i64>,
pub allowed_client_type: Option<Vec<String>>,
pub allowed_redirect_uri: Option<Vec<String>>,
pub audit_logs_claims: Option<Vec<String>>,
pub bound_ips: Option<Vec<String>>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub force_sub_claims: Option<bool>,
pub gw_bound_ips: Option<Vec<String>>,
pub idp_metadata_url: Option<String>,
pub idp_metadata_xml_data: Option<String>,
pub json: Option<bool>,
pub jwt_ttl: Option<i64>,
pub name: String,
pub new_name: Option<String>,
pub product_type: Option<Vec<String>>,
pub subclaims_delimiters: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub unique_identifier: String,
}Expand description
UpdateAuthMethodSaml : updateAuthMethodSAML is a command that updates a new auth method that will be available to authenticate using SAML. [Deprecated: Use auth-method-update-saml command]
Fields
access_expires: Option<i64>Access expiration date in Unix timestamp (select 0 for access without expiry date)
allowed_client_type: Option<Vec<String>>limit the auth method usage for specific client types [cli,ui,gateway-admin,sdk,mobile,extension]
allowed_redirect_uri: Option<Vec<String>>Allowed redirect URIs after the authentication
audit_logs_claims: Option<Vec<String>>Subclaims to include in audit logs, e.g "–audit-logs-claims email –audit-logs-claims username"
bound_ips: Option<Vec<String>>A CIDR whitelist with the IPs that the access is restricted to
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Auth Method description
expiration_event_in: Option<Vec<String>>How many days before the expiration of the auth method would you like to be notified.
force_sub_claims: Option<bool>if true: enforce role-association must include sub claims
gw_bound_ips: Option<Vec<String>>A CIDR whitelist with the GW IPs that the access is restricted to
idp_metadata_url: Option<String>IDP metadata url
idp_metadata_xml_data: Option<String>IDP metadata xml data
json: Option<bool>Set output format to JSON
jwt_ttl: Option<i64>Jwt TTL
name: StringAuth Method name
new_name: Option<String>Auth Method new name
product_type: Option<Vec<String>>Choose the relevant product type for the auth method [sm, sra, pm, dp, ca]
subclaims_delimiters: Option<Vec<String>>A list of additional sub claims delimiters (relevant only for SAML, OIDC, OAuth2/JWT)
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
unique_identifier: StringA unique identifier (ID) value should be configured for OAuth2, LDAP and SAML authentication method types and is usually a value such as the email, username, or upn for example. Whenever a user logs in with a token, these authentication types issue a "sub claim" that contains details uniquely identifying that user. This sub claim includes a key containing the ID value that you configured, and is used to distinguish between different users from within the same organization.
Implementations
Sourceimpl UpdateAuthMethodSaml
impl UpdateAuthMethodSaml
Sourcepub fn new(name: String, unique_identifier: String) -> UpdateAuthMethodSaml
pub fn new(name: String, unique_identifier: String) -> UpdateAuthMethodSaml
updateAuthMethodSAML is a command that updates a new auth method that will be available to authenticate using SAML. [Deprecated: Use auth-method-update-saml command]