Module update_auth_method_universal_identity

Module update_auth_method_universal_identity 

Structs

UpdateAuthMethodUniversalIdentity
UpdateAuthMethodUniversalIdentity : updateAuthMethodUniversalIdentity is a command that updates a new auth method that will be able to authenticate using Akeyless Universal Identity. [Deprecated: Use auth-method-update-universal-identity command]