pub struct UpdateAuthMethodUniversalIdentity {Show 19 fields
pub access_expires: Option<i64>,
pub allowed_client_type: Option<Vec<String>>,
pub audit_logs_claims: Option<Vec<String>>,
pub bound_ips: Option<Vec<String>>,
pub delete_protection: Option<String>,
pub deny_inheritance: Option<bool>,
pub deny_rotate: Option<bool>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub force_sub_claims: Option<bool>,
pub gw_bound_ips: Option<Vec<String>>,
pub json: Option<bool>,
pub jwt_ttl: Option<i64>,
pub name: String,
pub new_name: Option<String>,
pub product_type: Option<Vec<String>>,
pub token: Option<String>,
pub ttl: Option<i32>,
pub uid_token: Option<String>,
}Expand description
UpdateAuthMethodUniversalIdentity : updateAuthMethodUniversalIdentity is a command that updates a new auth method that will be able to authenticate using Akeyless Universal Identity. [Deprecated: Use auth-method-update-universal-identity command]
Fields
access_expires: Option<i64>Access expiration date in Unix timestamp (select 0 for access without expiry date)
allowed_client_type: Option<Vec<String>>limit the auth method usage for specific client types [cli,ui,gateway-admin,sdk,mobile,extension]
audit_logs_claims: Option<Vec<String>>Subclaims to include in audit logs, e.g "–audit-logs-claims email –audit-logs-claims username"
bound_ips: Option<Vec<String>>A CIDR whitelist with the IPs that the access is restricted to
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
deny_inheritance: Option<bool>Deny from root to create children
deny_rotate: Option<bool>Deny from the token to rotate
description: Option<String>Auth Method description
expiration_event_in: Option<Vec<String>>How many days before the expiration of the auth method would you like to be notified.
force_sub_claims: Option<bool>if true: enforce role-association must include sub claims
gw_bound_ips: Option<Vec<String>>A CIDR whitelist with the GW IPs that the access is restricted to
json: Option<bool>Set output format to JSON
jwt_ttl: Option<i64>Jwt TTL
name: StringAuth Method name
new_name: Option<String>Auth Method new name
product_type: Option<Vec<String>>Choose the relevant product type for the auth method [sm, sra, pm, dp, ca]
token: Option<String>Authentication token (see /auth and /configure)
ttl: Option<i32>Token ttl
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl UpdateAuthMethodUniversalIdentity
impl UpdateAuthMethodUniversalIdentity
Sourcepub fn new(name: String) -> UpdateAuthMethodUniversalIdentity
pub fn new(name: String) -> UpdateAuthMethodUniversalIdentity
updateAuthMethodUniversalIdentity is a command that updates a new auth method that will be able to authenticate using Akeyless Universal Identity. [Deprecated: Use auth-method-update-universal-identity command]