pub struct UpdateDbTargetDetails {Show 14 fields
pub db_type: Option<String>,
pub host: Option<String>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub mongo_db_name: Option<String>,
pub mongo_uri: Option<String>,
pub name: String,
pub new_version: Option<bool>,
pub port: Option<String>,
pub protection_key: Option<String>,
pub pwd: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_name: Option<String>,
}Fields
db_type: Option<String>host: Option<String>json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
mongo_db_name: Option<String>mongo_uri: Option<String>name: StringTarget name
new_version: Option<bool>Deprecated
port: Option<String>protection_key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
pwd: Option<String>token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_name: Option<String>Implementations
Sourceimpl UpdateDbTargetDetails
impl UpdateDbTargetDetails
pub fn new(name: String) -> UpdateDbTargetDetails