pub struct UpdateEksTarget {Show 18 fields
pub comment: Option<String>,
pub description: Option<String>,
pub eks_access_key_id: String,
pub eks_cluster_ca_cert: String,
pub eks_cluster_endpoint: String,
pub eks_cluster_name: String,
pub eks_region: Option<String>,
pub eks_secret_access_key: String,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub update_version: Option<bool>,
pub use_gw_cloud_identity: Option<bool>,
}Expand description
UpdateEksTarget : updateEKSTarget is a command that updates an existing target. [Deprecated: Use target-update-eks command]
Fields
comment: Option<String>Deprecated - use description
description: Option<String>Description of the object
eks_access_key_id: StringAccess Key ID
eks_cluster_ca_cert: StringEKS cluster CA certificate
eks_cluster_endpoint: StringEKS cluster URL endpoint
eks_cluster_name: StringEKS cluster name
eks_region: Option<String>Region
eks_secret_access_key: StringSecret Access Key
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
update_version: Option<bool>Deprecated
use_gw_cloud_identity: Option<bool>Implementations
Sourceimpl UpdateEksTarget
impl UpdateEksTarget
Sourcepub fn new(
eks_access_key_id: String,
eks_cluster_ca_cert: String,
eks_cluster_endpoint: String,
eks_cluster_name: String,
eks_secret_access_key: String,
name: String,
) -> UpdateEksTarget
pub fn new( eks_access_key_id: String, eks_cluster_ca_cert: String, eks_cluster_endpoint: String, eks_cluster_name: String, eks_secret_access_key: String, name: String, ) -> UpdateEksTarget
updateEKSTarget is a command that updates an existing target. [Deprecated: Use target-update-eks command]