pub struct UpdateEventForwarder {Show 16 fields
pub admin_name: Option<String>,
pub auth_type: Option<String>,
pub client_id: Option<String>,
pub description: Option<String>,
pub email_to: Option<String>,
pub enable: Option<String>,
pub event_source_locations: Option<Vec<String>>,
pub event_types: Option<Vec<String>>,
pub host: Option<String>,
pub json: Option<bool>,
pub name: String,
pub new_comment: Option<String>,
pub new_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_email: Option<String>,
}Expand description
UpdateEventForwarder : updateEventForwarder is a command that updates an event forwarder [Deprecated - please use event-forwarder-update-* command]
Fields
admin_name: Option<String>Workstation Admin Name
auth_type: Option<String>The authentication type to use when connecting to ServiceNow (user-pass / jwt)
client_id: Option<String>The client ID to use when connecting to ServiceNow with jwt authentication
description: Option<String>Description of the object
email_to: Option<String>A comma seperated list of email addresses to send event to (relevant only for "email" Event Forwarder)
enable: Option<String>Enable/Disable Event Forwarder [true/false]
event_source_locations: Option<Vec<String>>Event sources
event_types: Option<Vec<String>>Event types
host: Option<String>Workstation Host
json: Option<bool>Set output format to JSON
name: StringEventForwarder name
new_comment: Option<String>Deprecated - use description
new_name: Option<String>New EventForwarder name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_email: Option<String>The user email to use when connecting to ServiceNow with jwt authentication
Implementations
Sourceimpl UpdateEventForwarder
impl UpdateEventForwarder
Sourcepub fn new(name: String) -> UpdateEventForwarder
pub fn new(name: String) -> UpdateEventForwarder
updateEventForwarder is a command that updates an event forwarder [Deprecated - please use event-forwarder-update-* command]