UpdateGkeTarget

Struct UpdateGkeTarget 

pub struct UpdateGkeTarget {
Show 17 fields pub comment: Option<String>, pub description: Option<String>, pub gke_account_key: Option<String>, pub gke_cluster_cert: Option<String>, pub gke_cluster_endpoint: Option<String>, pub gke_cluster_name: Option<String>, pub gke_service_account_email: Option<String>, pub json: Option<bool>, pub keep_prev_version: Option<String>, pub key: Option<String>, pub max_versions: Option<String>, pub name: String, pub new_name: Option<String>, pub token: Option<String>, pub uid_token: Option<String>, pub update_version: Option<bool>, pub use_gw_cloud_identity: Option<bool>,
}
UpdateGkeTarget : updateGKETarget is a command that updates an existing target. [Deprecated: Use target-update-gke command]

Fields

comment: Option<String>

Deprecated - use description

description: Option<String>

Description of the object

gke_account_key: Option<String>

GKE Service Account key file path

gke_cluster_cert: Option<String>

GKE cluster CA certificate

gke_cluster_endpoint: Option<String>

GKE cluster URL endpoint

gke_cluster_name: Option<String>

GKE cluster name

gke_service_account_email: Option<String>

GKE service account email

json: Option<bool>

Set output format to JSON

keep_prev_version: Option<String>

Whether to keep previous version [true/false]. If not set, use default according to account settings

key: Option<String>

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)

max_versions: Option<String>

Set the maximum number of versions, limited by the account settings defaults.

name: String

Target name

new_name: Option<String>

New target name

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

update_version: Option<bool>

Deprecated

use_gw_cloud_identity: Option<bool>

Implementations

Source

impl UpdateGkeTarget

pub fn new(name: String) -> UpdateGkeTarget

updateGKETarget is a command that updates an existing target. [Deprecated: Use target-update-gke command]