pub struct UpdateGlobalSignTarget {Show 19 fields
pub comment: Option<String>,
pub contact_email: String,
pub contact_first_name: String,
pub contact_last_name: String,
pub contact_phone: String,
pub description: Option<String>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub password: String,
pub profile_id: String,
pub timeout: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub update_version: Option<bool>,
pub username: String,
}Expand description
UpdateGlobalSignTarget : updateGlobalSignTarget is a command that updates an existing target. [Deprecated: Use target-update-globalsign command]
Fields
comment: Option<String>Deprecated - use description
contact_email: StringEmail of the GlobalSign GCC account contact
contact_first_name: StringFirst name of the GlobalSign GCC account contact
contact_last_name: StringLast name of the GlobalSign GCC account contact
contact_phone: StringTelephone of the GlobalSign GCC account contact
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
password: StringPassword of the GlobalSign GCC account
profile_id: StringProfile ID of the GlobalSign GCC account
timeout: Option<String>Timeout waiting for certificate validation in Duration format (1h - 1 Hour, 20m - 20 Minutes, 33m3s - 33 Minutes and 3 Seconds), maximum 1h.
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
update_version: Option<bool>Deprecated
username: StringUsername of the GlobalSign GCC account
Implementations
Sourceimpl UpdateGlobalSignTarget
impl UpdateGlobalSignTarget
Sourcepub fn new(
contact_email: String,
contact_first_name: String,
contact_last_name: String,
contact_phone: String,
name: String,
password: String,
profile_id: String,
username: String,
) -> UpdateGlobalSignTarget
pub fn new( contact_email: String, contact_first_name: String, contact_last_name: String, contact_phone: String, name: String, password: String, profile_id: String, username: String, ) -> UpdateGlobalSignTarget
updateGlobalSignTarget is a command that updates an existing target. [Deprecated: Use target-update-globalsign command]