UpdateItem

Struct UpdateItem 

pub struct UpdateItem {
Show 51 fields pub provider_type: Option<String>, pub accessibility: Option<String>, pub add_tag: Option<Vec<String>>, pub cert_file_data: Option<String>, pub certificate_format: Option<String>, pub change_event: Option<String>, pub delete_protection: Option<String>, pub description: Option<String>, pub expiration_event_in: Option<Vec<String>>, pub gcp_sm_regions: Option<String>, pub host_provider: Option<String>, pub item_custom_fields: Option<HashMap<String, String>>, pub json: Option<bool>, pub max_versions: Option<String>, pub name: String, pub new_metadata: Option<String>, pub new_name: Option<String>, pub rm_tag: Option<Vec<String>>, pub rotate_after_disconnect: Option<String>, pub secure_access_add_host: Option<Vec<String>>, pub secure_access_allow_external_user: Option<String>, pub secure_access_allow_port_forwading: Option<bool>, pub secure_access_api: Option<String>, pub secure_access_aws_account_id: Option<String>, pub secure_access_aws_native_cli: Option<bool>, pub secure_access_aws_region: Option<String>, pub secure_access_bastion_api: Option<String>, pub secure_access_bastion_issuer: Option<String>, pub secure_access_bastion_ssh: Option<String>, pub secure_access_certificate_issuer: Option<String>, pub secure_access_cluster_endpoint: Option<String>, pub secure_access_dashboard_url: Option<String>, pub secure_access_db_name: Option<String>, pub secure_access_db_schema: Option<String>, pub secure_access_enable: Option<String>, pub secure_access_gateway: Option<String>, pub secure_access_host: Option<Vec<String>>, pub secure_access_rd_gateway_server: Option<String>, pub secure_access_rdp_domain: Option<String>, pub secure_access_rdp_user: Option<String>, pub secure_access_rm_host: Option<Vec<String>>, pub secure_access_ssh: Option<String>, pub secure_access_ssh_creds: Option<String>, pub secure_access_ssh_creds_user: Option<String>, pub secure_access_url: Option<String>, pub secure_access_use_internal_bastion: Option<bool>, pub secure_access_use_internal_ssh_access: Option<bool>, pub secure_access_web_browsing: Option<bool>, pub secure_access_web_proxy: Option<bool>, pub token: Option<String>, pub uid_token: Option<String>,
}

Fields

provider_type: Option<String>accessibility: Option<String>

for personal password manager

add_tag: Option<Vec<String>>

List of the new tags that will be attached to this item

cert_file_data: Option<String>

PEM Certificate in a Base64 format. Used for updating RSA keys’ certificates.

certificate_format: Option<String>change_event: Option<String>

Trigger an event when a secret value changed [true/false] (Relevant only for Static Secret)

delete_protection: Option<String>

Protection from accidental deletion of this object [true/false]

description: Option<String>

Description of the object

expiration_event_in: Option<Vec<String>>

How many days before the expiration of the certificate would you like to be notified.

gcp_sm_regions: Option<String>

GCP Secret Manager regions to query for regional secrets (comma-separated, e.g., us-east1,us-west1). Max 12 regions. USC with GCP targets only.

host_provider: Option<String>

Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret

item_custom_fields: Option<HashMap<String, String>>

Additional custom fields to associate with the item

json: Option<bool>

Set output format to JSON

max_versions: Option<String>

Set the maximum number of versions, limited by the account settings defaults.

name: String

Current item name

new_metadata: Option<String>

Deprecated - use description

new_name: Option<String>

New item name

rm_tag: Option<Vec<String>>

List of the existent tags that will be removed from this item

rotate_after_disconnect: Option<String>

Rotate the value of the secret after SRA session ends [true/false]

secure_access_add_host: Option<Vec<String>>

List of the new hosts that will be attached to SRA servers host

secure_access_allow_external_user: Option<String>

Allow providing external user for a domain users [true/false]

secure_access_allow_port_forwading: Option<bool>

Enable Port forwarding while using CLI access (relevant only for EKS/GKE/K8s Dynamic-Secret)

secure_access_api: Option<String>

Bastion’s SSH control API endpoint. E.g. https://my.sra-server:9900 (relevant only for ssh cert issuer)

secure_access_aws_account_id: Option<String>

The AWS account id (relevant only for aws)

secure_access_aws_native_cli: Option<bool>

The AWS native cli (relevant only for aws)

secure_access_aws_region: Option<String>

The AWS region (relevant only for aws)

secure_access_bastion_api: Option<String>

Deprecated. use secure-access-api

secure_access_bastion_issuer: Option<String>

Deprecated. use secure-access-certificate-issuer

secure_access_bastion_ssh: Option<String>

Deprecated. use secure-access-ssh

secure_access_certificate_issuer: Option<String>

Path to the SSH Certificate Issuer for your Akeyless Secure Access

secure_access_cluster_endpoint: Option<String>

The K8s cluster endpoint URL (relevant only for EKS/GKE/K8s Dynamic-Secret)

secure_access_dashboard_url: Option<String>

The K8s dashboard url (relevant only for k8s)

secure_access_db_name: Option<String>

The DB name (relevant only for DB Dynamic-Secret)

secure_access_db_schema: Option<String>

The DB schema (relevant only for DB Dynamic-Secret)

secure_access_enable: Option<String>

Enable/Disable secure remote access [true/false]

secure_access_gateway: Option<String>secure_access_host: Option<Vec<String>>

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)

secure_access_rd_gateway_server: Option<String>

RD Gateway server (relevant only for rdp)

secure_access_rdp_domain: Option<String>

Required when the Dynamic Secret is used for a domain user (relevant only for RDP Dynamic-Secret)

secure_access_rdp_user: Option<String>

Override the RDP Domain username

secure_access_rm_host: Option<Vec<String>>

List of the existent hosts that will be removed from SRA servers host

secure_access_ssh: Option<String>

Bastion’s SSH server. E.g. my.sra-server:22 (relevant only for ssh cert issuer)

secure_access_ssh_creds: Option<String>

Secret values contains SSH Credentials, either Private Key or Password [password/private-key] (relevant only for Static-Secret or Rotated-secret)

secure_access_ssh_creds_user: Option<String>

SSH username to connect to target server, must be in ‘Allowed Users’ list (relevant only for ssh cert issuer)

secure_access_url: Option<String>

Destination URL to inject secrets

secure_access_use_internal_bastion: Option<bool>

Deprecated. Use secure-access-use-internal-ssh-access

secure_access_use_internal_ssh_access: Option<bool>

Use internal SSH Access

secure_access_web_browsing: Option<bool>

Secure browser via Akeyless’s Secure Remote Access (SRA)

secure_access_web_proxy: Option<bool>

Web-Proxy via Akeyless’s Secure Remote Access (SRA)

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

Implementations