pub struct UpdateOidcApp {
pub audience: Option<String>,
pub json: Option<bool>,
pub key: Option<String>,
pub name: String,
pub permission_assignment: Option<String>,
pub public: Option<bool>,
pub redirect_uris: Option<String>,
pub scopes: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
audience: Option<String>A comma separated list of allowed audiences
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the OIDC application (if empty, the account default protectionKey key will be used)
name: StringOIDC application name
permission_assignment: Option<String>A json string defining the access permission assignment for this app
public: Option<bool>Set to true if the app is public (cannot keep secrets)
redirect_uris: Option<String>A comma separated list of allowed redirect uris
scopes: Option<String>A comma separated list of allowed scopes
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl UpdateOidcApp
impl UpdateOidcApp
pub fn new(name: String) -> UpdateOidcApp