pub struct UpdatePingTarget {Show 16 fields
pub administrative_port: Option<String>,
pub authorization_port: Option<String>,
pub comment: Option<String>,
pub description: Option<String>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub password: Option<String>,
pub ping_url: Option<String>,
pub privileged_user: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub update_version: Option<bool>,
}Expand description
UpdatePingTarget : updatePingTarget is a command that updates an existing target. [Deprecated: Use target-update-ping command]
Fields
administrative_port: Option<String>Ping Federate administrative port
Ping Federate authorization port
comment: Option<String>Deprecated - use description
description: Option<String>Description of the object
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
password: Option<String>Ping Federate privileged user password
ping_url: Option<String>Ping URL
privileged_user: Option<String>Ping Federate privileged user
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
update_version: Option<bool>Deprecated
Implementations
Sourceimpl UpdatePingTarget
impl UpdatePingTarget
Sourcepub fn new(name: String) -> UpdatePingTarget
pub fn new(name: String) -> UpdatePingTarget
updatePingTarget is a command that updates an existing target. [Deprecated: Use target-update-ping command]