pub struct UpdateRole {Show 16 fields
pub analytics_access: Option<String>,
pub audit_access: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub event_center_access: Option<String>,
pub event_forwarder_access: Option<String>,
pub gw_analytics_access: Option<String>,
pub json: Option<bool>,
pub name: String,
pub new_comment: Option<String>,
pub new_name: Option<String>,
pub reverse_rbac_access: Option<String>,
pub sra_reports_access: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub usage_reports_access: Option<String>,
}Fields
analytics_access: Option<String>Allow this role to view analytics. Currently only ‘none’, ‘own’, ‘all’ values are supported, allowing associated auth methods to view reports produced by the same auth methods.
audit_access: Option<String>Allow this role to view audit logs. Currently only ‘none’, ‘own’, ‘scoped’ and ‘all’ values are supported, allowing associated auth methods to view audit logs produced by the same auth methods.
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
event_center_access: Option<String>Allow this role to view Event Center. Currently only ‘none’, ‘scoped’ and ‘all’ values are supported
event_forwarder_access: Option<String>Allow this role to manage Event Forwarders. Currently only ‘none’ and ‘all’ values are supported.
gw_analytics_access: Option<String>Allow this role to view gw analytics. Currently only ‘none’, ‘scoped’, ‘all’ values are supported, allowing associated auth methods to view reports produced by the same auth methods.
json: Option<bool>Set output format to JSON
name: StringRole name
new_comment: Option<String>Deprecated - use description
new_name: Option<String>New Role name
reverse_rbac_access: Option<String>Allow this role to view Reverse RBAC. Supported values: ‘scoped’, ‘all’.
sra_reports_access: Option<String>Allow this role to view SRA Clusters. Currently only ‘none’, ‘scoped’, ‘all’ values are supported.
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
usage_reports_access: Option<String>Allow this role to view Usage Report. Currently only ‘none’ and ‘all’ values are supported.
Implementations
Sourceimpl UpdateRole
impl UpdateRole
pub fn new(name: String) -> UpdateRole