UpdateRotatedSecret

Struct UpdateRotatedSecret 

pub struct UpdateRotatedSecret {
Show 50 fields pub provider_type: Option<String>, pub add_tag: Option<Vec<String>>, pub api_id: Option<String>, pub api_key: Option<String>, pub auto_rotate: Option<String>, pub aws_region: Option<String>, pub custom_payload: Option<String>, pub description: Option<String>, pub gcp_key: Option<String>, pub grace_rotation: Option<String>, pub host_provider: Option<String>, pub json: Option<bool>, pub keep_prev_version: Option<String>, pub key: Option<String>, pub name: String, pub new_metadata: Option<String>, pub new_name: Option<String>, pub new_version: Option<bool>, pub rm_tag: Option<Vec<String>>, pub rotate_after_disconnect: Option<String>, pub rotated_password: Option<String>, pub rotated_username: Option<String>, pub rotation_hour: Option<i32>, pub rotation_interval: Option<String>, pub rotator_creds_type: Option<String>, pub rotator_custom_cmd: Option<String>, pub same_password: Option<String>, pub secure_access_allow_external_user: Option<bool>, pub secure_access_aws_account_id: Option<String>, pub secure_access_aws_native_cli: Option<bool>, pub secure_access_bastion_issuer: Option<String>, pub secure_access_certificate_issuer: Option<String>, pub secure_access_db_name: Option<String>, pub secure_access_db_schema: Option<String>, pub secure_access_disable_concurrent_connections: Option<bool>, pub secure_access_enable: Option<String>, pub secure_access_host: Option<Vec<String>>, pub secure_access_rdp_domain: Option<String>, pub secure_access_rdp_user: Option<String>, pub secure_access_url: Option<String>, pub secure_access_web: Option<bool>, pub secure_access_web_browsing: Option<bool>, pub secure_access_web_proxy: Option<bool>, pub ssh_password: Option<String>, pub ssh_username: Option<String>, pub storage_account_key_name: Option<String>, pub token: Option<String>, pub uid_token: Option<String>, pub user_attribute: Option<String>, pub user_dn: Option<String>,
}
UpdateRotatedSecret : updateRotatedSecret is a command that updates rotated secret. [Deprecated: Use rotated-secret update commands]

Fields

provider_type: Option<String>add_tag: Option<Vec<String>>

List of the new tags that will be attached to this item

api_id: Option<String>

API ID to rotate

api_key: Option<String>

API key to rotate

auto_rotate: Option<String>

Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]

aws_region: Option<String>

Aws Region (relevant only for aws)

custom_payload: Option<String>

Secret payload to be sent with rotation request (relevant only for rotator-type=custom)

description: Option<String>

Description of the object

gcp_key: Option<String>

Base64-encoded service account private key text

grace_rotation: Option<String>

Create a new access key without deleting the old key from AWS for backup (relevant only for AWS) [true/false]

host_provider: Option<String>

Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret

json: Option<bool>

Set output format to JSON

keep_prev_version: Option<String>

Whether to keep previous version [true/false]. If not set, use default according to account settings

key: Option<String>

The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)

name: String

Secret name

new_metadata: Option<String>

Deprecated - use description

new_name: Option<String>

New item name

new_version: Option<bool>

Deprecated

rm_tag: Option<Vec<String>>

List of the existent tags that will be removed from this item

rotate_after_disconnect: Option<String>

Rotate the value of the secret after SRA session ends [true/false]

rotated_password: Option<String>

rotated-username password

rotated_username: Option<String>

username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password

rotation_hour: Option<i32>

The Hour of the rotation in UTC

rotation_interval: Option<String>

The number of days to wait between every automatic key rotation (7-365)

rotator_creds_type: Option<String>

The credentials to connect with use-self-creds/use-target-creds

rotator_custom_cmd: Option<String>

"Custom rotation command (relevant only for ssh target)

same_password: Option<String>

Rotate same password for each host from the Linked Target (relevant only for Linked Target)

secure_access_allow_external_user: Option<bool>

Allow providing external user for a domain users (relevant only for rdp)

secure_access_aws_account_id: Option<String>

The AWS account id (relevant only for aws)

secure_access_aws_native_cli: Option<bool>

The AWS native cli

secure_access_bastion_issuer: Option<String>

Deprecated. use secure-access-certificate-issuer

secure_access_certificate_issuer: Option<String>

Path to the SSH Certificate Issuer for your Akeyless Secure Access

secure_access_db_name: Option<String>

The DB name (relevant only for DB Dynamic-Secret)

secure_access_db_schema: Option<String>

The db schema (relevant only for mssql or postgresql)

secure_access_disable_concurrent_connections: Option<bool>

Enable this flag to prevent simultaneous use of the same secret

secure_access_enable: Option<String>

Enable/Disable secure remote access [true/false]

secure_access_host: Option<Vec<String>>

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)

secure_access_rdp_domain: Option<String>

Required when the Dynamic Secret is used for a domain user (relevant only for RDP Dynamic-Secret)

secure_access_rdp_user: Option<String>

Override the RDP Domain username (relevant only for rdp)

secure_access_url: Option<String>

Destination URL to inject secrets

secure_access_web: Option<bool>

Enable Web Secure Remote Access

secure_access_web_browsing: Option<bool>

Secure browser viaAkeyless’s Secure Remote Access (SRA) (relevant only for aws or azure)

secure_access_web_proxy: Option<bool>

Web-Proxy via Akeyless’s Secure Remote Access (SRA) (relevant only for aws or azure)

ssh_password: Option<String>

Deprecated: use RotatedPassword

ssh_username: Option<String>

Deprecated: use RotatedUser

storage_account_key_name: Option<String>

The name of the storage account key to rotate [key1/key2/kerb1/kerb2]

token: Option<String>

Authentication token (see /auth and /configure)

uid_token: Option<String>

The universal identity token, Required only for universal_identity authentication

user_attribute: Option<String>

LDAP User Attribute, Default value "cn"

user_dn: Option<String>

LDAP User Base DN

Implementations

Source

impl UpdateRotatedSecret

pub fn new(name: String) -> UpdateRotatedSecret

updateRotatedSecret is a command that updates rotated secret. [Deprecated: Use rotated-secret update commands]