pub struct UpdateRotationSettings {
pub auto_rotate: bool,
pub json: Option<bool>,
pub name: String,
pub rotation_event_in: Option<Vec<String>>,
pub rotation_interval: Option<i64>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Expand description
UpdateRotationSettings : updateRotationSettings is a command that updates rotations settings of an existing key
Fields
auto_rotate: boolWhether to automatically rotate every –rotation-interval days, or disable existing automatic rotation
json: Option<bool>Set output format to JSON
name: StringKey name
rotation_event_in: Option<Vec<String>>How many days before the rotation of the item would you like to be notified
rotation_interval: Option<i64>The number of days to wait between every automatic key rotation (7-365)
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl UpdateRotationSettings
impl UpdateRotationSettings
Sourcepub fn new(auto_rotate: bool, name: String) -> UpdateRotationSettings
pub fn new(auto_rotate: bool, name: String) -> UpdateRotationSettings
updateRotationSettings is a command that updates rotations settings of an existing key