pub struct UpdateSalesforceTarget {Show 21 fields
pub app_private_key_data: Option<String>,
pub auth_flow: String,
pub ca_cert_data: Option<String>,
pub ca_cert_name: Option<String>,
pub client_id: String,
pub client_secret: Option<String>,
pub comment: Option<String>,
pub description: Option<String>,
pub email: String,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub new_name: Option<String>,
pub password: Option<String>,
pub security_token: Option<String>,
pub tenant_url: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub update_version: Option<bool>,
}Expand description
UpdateSalesforceTarget : updateSalesforceTarget is a command that updates a new target. [Deprecated: Use target-update-salesforce command]
Fields
app_private_key_data: Option<String>Base64 encoded PEM of the connected app private key (relevant for JWT auth only)
auth_flow: Stringtype of the auth flow (‘jwt’ / ‘user-password’)
ca_cert_data: Option<String>Base64 encoded PEM cert to use when uploading a new key to Salesforce
ca_cert_name: Option<String>name of the certificate in Salesforce tenant to use when uploading new key
client_id: StringClient ID of the oauth2 app to use for connecting to Salesforce
client_secret: Option<String>Client secret of the oauth2 app to use for connecting to Salesforce (required for password flow)
comment: Option<String>Deprecated - use description
description: Option<String>Description of the object
email: StringThe email of the user attached to the oauth2 app used for connecting to Salesforce
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringTarget name
new_name: Option<String>New target name
password: Option<String>The password of the user attached to the oauth2 app used for connecting to Salesforce (required for user-password flow)
security_token: Option<String>The security token of the user attached to the oauth2 app used for connecting to Salesforce (required for user-password flow)
tenant_url: StringUrl of the Salesforce tenant
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
update_version: Option<bool>Deprecated
Implementations