pub struct UpdateSecretVal {Show 16 fields
pub accessibility: Option<String>,
pub custom_field: Option<HashMap<String, String>>,
pub format: Option<String>,
pub inject_url: Option<Vec<String>>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub key: Option<String>,
pub last_version: Option<i32>,
pub multiline: Option<bool>,
pub name: String,
pub new_version: Option<bool>,
pub password: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub username: Option<String>,
pub value: String,
}Fields
accessibility: Option<String>for personal password manager
custom_field: Option<HashMap<String, String>>For Password Management use, additional fields
format: Option<String>Secret format [text/json/key-value] (relevant only for type ‘generic’)
inject_url: Option<Vec<String>>For Password Management use, reflect the website context
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
key: Option<String>The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
last_version: Option<i32>The last version number before the update
multiline: Option<bool>The provided value is a multiline value (separated by ‘\n’)
name: StringSecret name
new_version: Option<bool>Deprecated
password: Option<String>For Password Management use, additional fields
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
username: Option<String>For Password Management use
value: StringThe secret value (relevant only for type ‘generic’)
Implementations
Sourceimpl UpdateSecretVal
impl UpdateSecretVal
pub fn new(name: String, value: String) -> UpdateSecretVal