pub struct UpdateSshTargetDetails {Show 13 fields
pub host: Option<String>,
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub name: String,
pub new_version: Option<bool>,
pub port: Option<String>,
pub private_key: Option<String>,
pub private_key_password: Option<String>,
pub protection_key: Option<String>,
pub ssh_password: Option<String>,
pub ssh_username: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
host: Option<String>The ssh host name
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
name: StringTarget name
new_version: Option<bool>Deprecated
port: Option<String>ssh port
private_key: Option<String>ssh private key
private_key_password: Option<String>The ssh private key password
protection_key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
ssh_password: Option<String>ssh pawssword to rotate
ssh_username: Option<String>ssh username
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl UpdateSshTargetDetails
impl UpdateSshTargetDetails
pub fn new(name: String) -> UpdateSshTargetDetails