pub struct UpdateTargetDetails {
pub json: Option<bool>,
}Expand description
UpdateTargetDetails : updateTargetDetails is a command that updates an existing target. [Deprecated]
Fields
json: Option<bool>Set output format to JSON
Implementations
Sourceimpl UpdateTargetDetails
impl UpdateTargetDetails
Sourcepub fn new() -> UpdateTargetDetails
pub fn new() -> UpdateTargetDetails
updateTargetDetails is a command that updates an existing target. [Deprecated]