pub struct UpdateWebTargetDetails {
pub json: Option<bool>,
pub keep_prev_version: Option<String>,
pub name: String,
pub new_version: Option<bool>,
pub protection_key: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub url: Option<String>,
}Fields
json: Option<bool>Set output format to JSON
keep_prev_version: Option<String>Whether to keep previous version [true/false]. If not set, use default according to account settings
name: StringTarget name
new_version: Option<bool>Deprecated
protection_key: Option<String>The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
url: Option<String>Implementations
Sourceimpl UpdateWebTargetDetails
impl UpdateWebTargetDetails
pub fn new(name: String) -> UpdateWebTargetDetails