pub struct UploadRsa {Show 17 fields
pub alg: String,
pub cert_file_data: Option<String>,
pub certificate_format: Option<String>,
pub customer_frg_id: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub metadata: Option<String>,
pub name: String,
pub overwrite: Option<String>,
pub rsa_file_data: Option<String>,
pub split_level: Option<i64>,
pub tag: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
alg: StringKey type. options: [RSA1024, RSA2048, RSA3072, RSA4096]
cert_file_data: Option<String>Certificate in a PEM format.
certificate_format: Option<String>customer_frg_id: Option<String>The customer fragment ID that will be used to split the key (if empty, the key will be created independently of a customer fragment)
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
expiration_event_in: Option<Vec<String>>How many days before the expiration of the certificate would you like to be notified.
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
metadata: Option<String>Deprecated - use description
name: StringName of key to be created
overwrite: Option<String>When the overwrite flag is set, this command will only update an existing key [true/false]
rsa_file_data: Option<String>RSA private key data, base64 encoded
split_level: Option<i64>The number of fragments that the item will be split into
tag: Option<Vec<String>>List of the tags attached to this key
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication