pub struct UscCreate {Show 14 fields
pub binary_value: Option<bool>,
pub description: Option<String>,
pub json: Option<bool>,
pub namespace: Option<String>,
pub object_type: Option<String>,
pub pfx_password: Option<String>,
pub region: Option<String>,
pub secret_name: String,
pub tags: Option<HashMap<String, String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub usc_encryption_key: Option<String>,
pub usc_name: String,
pub value: String,
}Expand description
UscCreate : uscCreate is a command that creates a new secret in a Universal Secrets Connector
Fields
binary_value: Option<bool>Use this option if the universal secrets value is a base64 encoded binary
description: Option<String>Description of the universal secrets
json: Option<bool>Set output format to JSON
namespace: Option<String>The namespace (relevant for Hashi vault target)
object_type: Option<String>pfx_password: Option<String>Optional, the passphrase that protects the private key within the pfx certificate (Relevant only for Azure KV certificates)
region: Option<String>Optional, create secret in a specific region (GCP only). If empty, a global secret will be created (provider default).
secret_name: StringName for the new universal secrets
Tags for the universal secrets
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
usc_encryption_key: Option<String>Optional, The name of the remote key that used to encrypt the secret value (if empty, the default key will be used)
usc_name: StringName of the Universal Secrets Connector item
value: StringValue of the universal secrets item, either text or base64 encoded binary