pub struct UscGet {
pub json: Option<bool>,
pub namespace: Option<String>,
pub secret_id: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub usc_name: String,
pub version_id: Option<String>,
}Expand description
UscGet : uscGet is a command that gets the value and internal details of a secret from a Universal Secrets Connector
Fields
json: Option<bool>Set output format to JSON
namespace: Option<String>The namespace (relevant for Hashi vault target)
secret_id: StringThe secret id (or name, for AWS, Azure, K8s or Hashi vault targets) to get from the Universal Secrets Connector
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
usc_name: StringName of the Universal Secrets Connector item
version_id: Option<String>The version id (if not specified, will retrieve the last version)
Implementations