pub struct VerifyDataWithClassicKey {
pub data: String,
pub display_id: Option<String>,
pub hashed: Option<bool>,
pub hashing_method: Option<String>,
pub json: Option<bool>,
pub name: String,
pub signature: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: i32,
}Fields
data: StringData
display_id: Option<String>The display id of the key to use in the verification process
hashed: Option<bool>Defines whether the data should be hashed as part of the signing. If true, the data will not be hashed
hashing_method: Option<String>HashingMethod
json: Option<bool>Set output format to JSON
name: StringThe name of the key to use in the verification process
signature: StringThe data’s signature in a Base64 format.
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: i32classic key version
Implementations