pub struct VerifyEcDsa {
pub display_id: Option<String>,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub key_name: Option<String>,
pub message: String,
pub prehashed: Option<bool>,
pub signature: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub version: Option<i32>,
}Expand description
VerifyEcDsa : verifyEcDsa is a command that verifies an ECDSA signature using a sha hash algorithm matching the key size
Fields
display_id: Option<String>The display id of the EC key to use for the verification process
item_id: Option<i64>The item id of the EC key to use for the verification process
json: Option<bool>Set output format to JSON
key_name: Option<String>The name of the EC key to use for the verification process
message: StringThe message to be verified in a base64 format
prehashed: Option<bool>Markes that the message is already hashed
signature: StringThe message’s signature
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
version: Option<i32>The version of the key to use for verification
Implementations
Sourceimpl VerifyEcDsa
impl VerifyEcDsa
Sourcepub fn new(message: String, signature: String) -> VerifyEcDsa
pub fn new(message: String, signature: String) -> VerifyEcDsa
verifyEcDsa is a command that verifies an ECDSA signature using a sha hash algorithm matching the key size