pub struct VerifyGpg {
pub display_id: Option<String>,
pub item_id: Option<i64>,
pub json: Option<bool>,
pub key_name: String,
pub passphrase: Option<String>,
pub signature: String,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
display_id: Option<String>The display id of the key to use in the encryption process
item_id: Option<i64>The item id of the key to use in the encryption process
json: Option<bool>Set output format to JSON
key_name: StringThe name of the key to use in the encryption process
passphrase: Option<String>Passphrase that was used to generate the key
signature: StringThe signature to be verified in base64 format
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations