pub struct ZeroSslTargetDetails {
pub api_key: Option<String>,
pub imap_fqdn: Option<String>,
pub imap_password: Option<String>,
pub imap_port: Option<String>,
pub imap_user: Option<String>,
pub timeout: Option<i64>,
pub validation_email: Option<String>,
}Expand description
ZeroSslTargetDetails : ZeroSSLTargetDetails
Fields
api_key: Option<String>imap_fqdn: Option<String>imap_password: Option<String>imap_port: Option<String>imap_user: Option<String>timeout: Option<i64>A Duration represents the elapsed time between two instants as an int64 nanosecond count. The representation limits the largest representable duration to approximately 290 years.
validation_email: Option<String>Implementations
Sourceimpl ZeroSslTargetDetails
impl ZeroSslTargetDetails
Sourcepub fn new() -> ZeroSslTargetDetails
pub fn new() -> ZeroSslTargetDetails
ZeroSSLTargetDetails