pub struct CertAccessRules {
pub allowed_cors: Option<Vec<String>>,
pub bound_common_names: Option<Vec<String>>,
pub bound_dns_sans: Option<Vec<String>>,
pub bound_email_sans: Option<Vec<String>>,
pub bound_extensions: Option<Vec<String>>,
pub bound_organizational_units: Option<Vec<String>>,
pub bound_uri_sans: Option<Vec<String>>,
pub certificate: Option<String>,
pub require_crl_dp: Option<bool>,
pub revoked_cert_ids: Option<Vec<String>>,
pub unique_identifier: Option<String>,
}Fields
allowed_cors: Option<Vec<String>>a list of allowed cors domains if used for browser authentication
bound_common_names: Option<Vec<String>>A list of names. At least one must exist in the Common Name. Supports globbing.
bound_dns_sans: Option<Vec<String>>A list of DNS names. At least one must exist in the SANs. Supports globbing.
bound_email_sans: Option<Vec<String>>A list of Email Addresses. At least one must exist in the SANs. Supports globbing.
bound_extensions: Option<Vec<String>>A list of extensions formatted as "oid:value". Expects the extension value to be some type of ASN1 encoded string. All values must match. Supports globbing on "value".
bound_organizational_units: Option<Vec<String>>A list of Organizational Units names. At least one must exist in the OU field.
bound_uri_sans: Option<Vec<String>>A list of URIs. At least one must exist in the SANs. Supports globbing.
certificate: Option<String>Base64 encdoed PEM certificate
require_crl_dp: Option<bool>RequireCrlDp indicates whether CRL distribution points are required on the leaf client certificate, and whether CRL validation must be enforced during authentication.
revoked_cert_ids: Option<Vec<String>>A list of revoked cert ids
unique_identifier: Option<String>A unique identifier to distinguish different users
Implementations
Sourceimpl CertAccessRules
impl CertAccessRules
pub fn new() -> CertAccessRules