Structs
- Create
Auth Method Azure Ad - CreateAuthMethodAzureAd : createAuthMethodAzureAD is a command that creates a new auth method that will be able to authenticate using Azure Active Directory credentials. [Deprecated: Use auth-method-create-azure-ad command]