Module create_auth_method_k8_s
akeyless_
api
0.1.1
Module create_
auth_
method_
k8_
s
Module Items
Structs
In akeyless_
api::
models
akeyless_api
::
models
Module
create_
auth_
method_
k8_
s
Structs

Create
Auth
Method
K8S
CreateAuthMethodK8S : createAuthMethodK8S is a command that creates a new auth method that will be able to authenticate using K8S. [Deprecated: Use auth-method-create-k8s command]