Structs
- Create
Auth Method Universal Identity - CreateAuthMethodUniversalIdentity : createAuthMethodUniversalIdentity is a command that creates a new auth method that will be able to authenticate using Akeyless Universal Identity. [Deprecated: Use auth-method-create-universal-identity command]