pub struct CreateDfcKey {Show 27 fields
pub alg: String,
pub auto_rotate: Option<String>,
pub certificate_common_name: Option<String>,
pub certificate_country: Option<String>,
pub certificate_digest_algo: Option<String>,
pub certificate_format: Option<String>,
pub certificate_locality: Option<String>,
pub certificate_organization: Option<String>,
pub certificate_province: Option<String>,
pub certificate_ttl: Option<i64>,
pub conf_file_data: Option<String>,
pub customer_frg_id: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub expiration_event_in: Option<Vec<String>>,
pub generate_self_signed_certificate: Option<bool>,
pub hash_algorithm: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub metadata: Option<String>,
pub name: String,
pub rotation_event_in: Option<Vec<String>>,
pub rotation_interval: Option<String>,
pub split_level: Option<i64>,
pub tag: Option<Vec<String>>,
pub token: Option<String>,
pub uid_token: Option<String>,
}Fields
alg: StringDFCKey type; options: [AES128GCM, AES256GCM, AES128SIV, AES256SIV, AES128CBC, AES256CBC, RSA1024, RSA2048, RSA3072, RSA4096]
auto_rotate: Option<String>Whether to automatically rotate every rotation_interval days, or disable existing automatic rotation [true/false]
certificate_common_name: Option<String>Common name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_country: Option<String>Country name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_digest_algo: Option<String>Digest algorithm to be used for the certificate key signing.
certificate_format: Option<String>certificate_locality: Option<String>Locality for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_organization: Option<String>Organization name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_province: Option<String>Province name for the generated certificate. Relevant only for generate-self-signed-certificate.
certificate_ttl: Option<i64>TTL in days for the generated certificate. Required only for generate-self-signed-certificate.
conf_file_data: Option<String>The csr config data in base64 encoding
customer_frg_id: Option<String>The customer fragment ID that will be used to create the DFC key (if empty, the key will be created independently of a customer fragment)
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
expiration_event_in: Option<Vec<String>>How many days before the expiration of the certificate would you like to be notified.
generate_self_signed_certificate: Option<bool>Whether to generate a self signed certificate with the key. If set, –certificate-ttl must be provided.
hash_algorithm: Option<String>Specifies the hash algorithm used for the encryption key’s operations, available options: [SHA256, SHA384, SHA512]
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
metadata: Option<String>Deprecated - use description
name: StringDFCKey name
rotation_event_in: Option<Vec<String>>How many days before the rotation of the item would you like to be notified
rotation_interval: Option<String>The number of days to wait between every automatic rotation (7-365)
split_level: Option<i64>The number of fragments that the item will be split into (not includes customer fragment)
tag: Option<Vec<String>>List of the tags attached to this DFC key
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
Implementations
Sourceimpl CreateDfcKey
impl CreateDfcKey
pub fn new(alg: String, name: String) -> CreateDfcKey