Module data_protection_section
akeyless_
api
0.1.1
Module data_
protection_
section
Module Items
Structs
In akeyless_
api::
models
akeyless_api
::
models
Module
data_
protection_
section
Structs

Data
Protection
Section
DataProtectionSection : We need the fields to be pointers as we use the same struct for partial updates as well