pub struct DynamicSecretCreatePing {Show 27 fields
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub ping_administrative_port: Option<String>,
pub ping_atm_id: Option<String>,
pub ping_authorization_port: Option<String>,
pub ping_cert_subject_dn: Option<String>,
pub ping_client_authentication_type: Option<String>,
pub ping_enforce_replay_prevention: Option<String>,
pub ping_grant_types: Option<Vec<String>>,
pub ping_issuer_dn: Option<String>,
pub ping_jwks: Option<String>,
pub ping_jwks_url: Option<String>,
pub ping_password: Option<String>,
pub ping_privileged_user: Option<String>,
pub ping_redirect_uris: Option<Vec<String>>,
pub ping_restricted_scopes: Option<Vec<String>>,
pub ping_signing_algo: Option<String>,
pub ping_url: Option<String>,
pub producer_encryption_key_name: Option<String>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretCreatePing : dynamicSecretCreatePing is a command that creates ping dynamic secret
Fields
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
ping_administrative_port: Option<String>Ping Federate administrative port
ping_atm_id: Option<String>Set a specific Access Token Management (ATM) instance for the created OAuth Client by providing the ATM Id. If no explicit value is given, the default pingfederate server ATM will be set.
Ping Federate authorization port
ping_cert_subject_dn: Option<String>The subject DN of the client certificate. If no explicit value is given, the producer will create CA certificate and matched client certificate and return it as value. Used in conjunction with ping-issuer-dn (relevant for CLIENT_TLS_CERTIFICATE authentication method)
ping_client_authentication_type: Option<String>OAuth Client Authentication Type [CLIENT_SECRET, PRIVATE_KEY_JWT, CLIENT_TLS_CERTIFICATE]
ping_enforce_replay_prevention: Option<String>Determines whether PingFederate requires a unique signed JWT from the client for each action (relevant for PRIVATE_KEY_JWT authentication method) [true/false]
ping_grant_types: Option<Vec<String>>List of OAuth client grant types [IMPLICIT, AUTHORIZATION_CODE, CLIENT_CREDENTIALS, TOKEN_EXCHANGE, REFRESH_TOKEN, ASSERTION_GRANTS, PASSWORD, RESOURCE_OWNER_CREDENTIALS]. If no explicit value is given, AUTHORIZATION_CODE will be selected as default.
ping_issuer_dn: Option<String>Issuer DN of trusted CA certificate that imported into Ping Federate server. You may select \"Trust Any\" to trust all the existing issuers in Ping Federate server. Used in conjunction with ping-cert-subject-dn (relevant for CLIENT_TLS_CERTIFICATE authentication method)
ping_jwks: Option<String>Base64-encoded JSON Web Key Set (JWKS). If no explicit value is given, the producer will create JWKs and matched signed JWT (Sign Algo: RS256) and return it as value (relevant for PRIVATE_KEY_JWT authentication method)
ping_jwks_url: Option<String>The URL of the JSON Web Key Set (JWKS). If no explicit value is given, the producer will create JWKs and matched signed JWT and return it as value (relevant for PRIVATE_KEY_JWT authentication method)
ping_password: Option<String>Ping Federate privileged user password
ping_privileged_user: Option<String>Ping Federate privileged user
ping_redirect_uris: Option<Vec<String>>List of URIs to which the OAuth authorization server may redirect the resource owner’s user agent after authorization is obtained. At least one redirection URI is required for the AUTHORIZATION_CODE and IMPLICIT grant types.
ping_restricted_scopes: Option<Vec<String>>Limit the OAuth client to specific scopes list
ping_signing_algo: Option<String>The signing algorithm that the client must use to sign its request objects [RS256,RS384,RS512,ES256,ES384,ES512,PS256,PS384,PS512] If no explicit value is given, the client can use any of the supported signing algorithms (relevant for PRIVATE_KEY_JWT authentication method)
ping_url: Option<String>Ping URL
producer_encryption_key_name: Option<String>Dynamic producer encryption key
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>The time from dynamic secret creation to expiration.
Implementations
Sourceimpl DynamicSecretCreatePing
impl DynamicSecretCreatePing
Sourcepub fn new(name: String) -> DynamicSecretCreatePing
pub fn new(name: String) -> DynamicSecretCreatePing
dynamicSecretCreatePing is a command that creates ping dynamic secret