pub struct DynamicSecretCreatePostgreSql {Show 29 fields
pub creation_statements: Option<String>,
pub custom_username_template: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub password_length: Option<String>,
pub postgresql_db_name: Option<String>,
pub postgresql_host: Option<String>,
pub postgresql_password: Option<String>,
pub postgresql_port: Option<String>,
pub postgresql_username: Option<String>,
pub producer_encryption_key: Option<String>,
pub revocation_statement: Option<String>,
pub secure_access_bastion_issuer: Option<String>,
pub secure_access_certificate_issuer: Option<String>,
pub secure_access_db_name: Option<String>,
pub secure_access_db_schema: Option<String>,
pub secure_access_delay: Option<i64>,
pub secure_access_enable: Option<String>,
pub secure_access_host: Option<Vec<String>>,
pub secure_access_web: Option<bool>,
pub ssl: Option<bool>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
}Expand description
DynamicSecretCreatePostgreSql : dynamicSecretCreatePostgreSql is a command that creates postgresql dynamic secret
Fields
creation_statements: Option<String>PostgreSQL Creation statements
custom_username_template: Option<String>Customize how temporary usernames are generated using go template
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
password_length: Option<String>The length of the password to be generated
postgresql_db_name: Option<String>PostgreSQL DB Name
postgresql_host: Option<String>PostgreSQL Host
postgresql_password: Option<String>PostgreSQL Password
postgresql_port: Option<String>PostgreSQL Port
postgresql_username: Option<String>PostgreSQL Username
producer_encryption_key: Option<String>Dynamic producer encryption key
revocation_statement: Option<String>PostgreSQL Revocation statements
secure_access_bastion_issuer: Option<String>Deprecated. use secure-access-certificate-issuer
secure_access_certificate_issuer: Option<String>Path to the SSH Certificate Issuer for your Akeyless Secure Access
secure_access_db_name: Option<String>The DB name (relevant only for DB Dynamic-Secret)
secure_access_db_schema: Option<String>The DB schema
secure_access_delay: Option<i64>The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_host: Option<Vec<String>>Target DB servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts)
secure_access_web: Option<bool>Enable Web Secure Remote Access
ssl: Option<bool>Enable/Disable SSL [true/false]
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL
Implementations
Sourceimpl DynamicSecretCreatePostgreSql
impl DynamicSecretCreatePostgreSql
Sourcepub fn new(name: String) -> DynamicSecretCreatePostgreSql
pub fn new(name: String) -> DynamicSecretCreatePostgreSql
dynamicSecretCreatePostgreSql is a command that creates postgresql dynamic secret