pub struct DynamicSecretUpdateVenafi {Show 28 fields
pub admin_rotation_interval_days: Option<i64>,
pub allow_subdomains: Option<bool>,
pub allowed_domains: Option<Vec<String>>,
pub auto_generated_folder: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub enable_admin_rotation: Option<bool>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub name: String,
pub new_name: Option<String>,
pub producer_encryption_key_name: Option<String>,
pub root_first_in_chain: Option<bool>,
pub sign_using_akeyless_pki: Option<bool>,
pub signer_key_name: Option<String>,
pub store_private_key: Option<bool>,
pub tags: Option<Vec<String>>,
pub target_name: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_ttl: Option<String>,
pub venafi_access_token: Option<String>,
pub venafi_api_key: Option<String>,
pub venafi_baseurl: Option<String>,
pub venafi_client_id: Option<String>,
pub venafi_refresh_token: Option<String>,
pub venafi_use_tpp: Option<bool>,
pub venafi_zone: Option<String>,
}Expand description
DynamicSecretUpdateVenafi : dynamicSecretUpdateVenafi is a command that updates a Venafi dynamic secret to dynamically update certificates generated by Venafi or have Akeyless generated certificates using PKI be monitored by Venafi
Fields
admin_rotation_interval_days: Option<i64>Admin credentials rotation interval (days)
allow_subdomains: Option<bool>Allow subdomains
allowed_domains: Option<Vec<String>>Allowed domains
auto_generated_folder: Option<String>Auto generated folder
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
enable_admin_rotation: Option<bool>Automatic admin credentials rotation
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
name: StringDynamic secret name
new_name: Option<String>Dynamic secret name
producer_encryption_key_name: Option<String>Dynamic producer encryption key
root_first_in_chain: Option<bool>Root first in chain
sign_using_akeyless_pki: Option<bool>Use Akeyless PKI issuer or Venafi issuer
signer_key_name: Option<String>Signer key name
store_private_key: Option<bool>Store private key
Add tags attached to this object
target_name: Option<String>Target name
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_ttl: Option<String>User TTL in time.Duration format (2160h / 129600m / etc…). When using sign-using-akeyless-pki certificates created will have this validity period, otherwise the user-ttl is taken from the Validity Period field of the Zone’s’ Issuing Template. When using cert-manager it is advised to have a TTL of above 60 days (1440h). For more information - https://cert-manager.io/docs/usage/certificate/
venafi_access_token: Option<String>Venafi Access Token to use to access the TPP environment (Relevant when using TPP)
venafi_api_key: Option<String>Venafi API key
venafi_baseurl: Option<String>Venafi Baseurl
venafi_client_id: Option<String>Venafi Client ID that was used when the access token was generated
venafi_refresh_token: Option<String>Venafi Refresh Token to use when the Access Token is expired (Relevant when using TPP)
venafi_use_tpp: Option<bool>Venafi using TPP
venafi_zone: Option<String>Venafi Zone
Implementations
Sourceimpl DynamicSecretUpdateVenafi
impl DynamicSecretUpdateVenafi
Sourcepub fn new(name: String) -> DynamicSecretUpdateVenafi
pub fn new(name: String) -> DynamicSecretUpdateVenafi
dynamicSecretUpdateVenafi is a command that updates a Venafi dynamic secret to dynamically update certificates generated by Venafi or have Akeyless generated certificates using PKI be monitored by Venafi