pub struct GeneralConfigPart {Show 17 fields
pub akeyless_url: Option<String>,
pub api_token_ttl: Option<String>,
pub display_name: Option<String>,
pub enable_sni_proxy: Option<bool>,
pub enable_tls: Option<bool>,
pub enable_tls_configure: Option<bool>,
pub enable_tls_curl: Option<bool>,
pub enable_tls_hvp: Option<bool>,
pub gw_cluster_url: Option<String>,
pub hvp_route_version: Option<i64>,
pub notify_on_status_change: Option<bool>,
pub tcp_port: Option<String>,
pub tls_cert: Option<String>,
pub tls_cert_common_name: Option<String>,
pub tls_cert_expiration_date: Option<String>,
pub tls_cert_expiration_events: Option<Vec<CertificateExpirationEvent>>,
pub tls_key: Option<String>,
}Fields
akeyless_url: Option<String>AkeylessUrl is here for BC only. Gator will still return it if it exists in the configuration, but new clients (>=2.34.0) will ignore it and override it with what exists in their local file. It will no longer be sent to Gator for update, so new clusters will only have the default value saved in the DB.
api_token_ttl: Option<String>display_name: Option<String>enable_sni_proxy: Option<bool>enable_tls: Option<bool>enable_tls_configure: Option<bool>enable_tls_curl: Option<bool>enable_tls_hvp: Option<bool>gw_cluster_url: Option<String>hvp_route_version: Option<i64>notify_on_status_change: Option<bool>tcp_port: Option<String>tls_cert: Option<String>tls_cert_common_name: Option<String>tls_cert_expiration_date: Option<String>tls_cert_expiration_events: Option<Vec<CertificateExpirationEvent>>tls_key: Option<String>Implementations
Sourceimpl GeneralConfigPart
impl GeneralConfigPart
pub fn new() -> GeneralConfigPart