pub struct RotatedSecretCreateLdap {Show 35 fields
pub provider_type: Option<String>,
pub authentication_credentials: Option<String>,
pub auto_rotate: Option<String>,
pub delete_protection: Option<String>,
pub description: Option<String>,
pub host_provider: Option<String>,
pub item_custom_fields: Option<HashMap<String, String>>,
pub json: Option<bool>,
pub key: Option<String>,
pub max_versions: Option<String>,
pub name: String,
pub password_length: Option<String>,
pub rotate_after_disconnect: Option<String>,
pub rotated_password: Option<String>,
pub rotated_username: Option<String>,
pub rotation_event_in: Option<Vec<String>>,
pub rotation_hour: Option<i32>,
pub rotation_interval: Option<String>,
pub rotator_type: String,
pub secure_access_bastion_issuer: Option<String>,
pub secure_access_certificate_issuer: Option<String>,
pub secure_access_enable: Option<String>,
pub secure_access_host: Option<Vec<String>>,
pub secure_access_rdp_domain: Option<String>,
pub secure_access_url: Option<String>,
pub secure_access_web: Option<bool>,
pub secure_access_web_browsing: Option<bool>,
pub secure_access_web_proxy: Option<bool>,
pub tags: Option<Vec<String>>,
pub target: Option<Vec<String>>,
pub target_name: String,
pub token: Option<String>,
pub uid_token: Option<String>,
pub user_attribute: Option<String>,
pub user_dn: Option<String>,
}Fields
provider_type: Option<String>authentication_credentials: Option<String>The credentials to connect with use-user-creds/use-target-creds
auto_rotate: Option<String>Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]
delete_protection: Option<String>Protection from accidental deletion of this object [true/false]
description: Option<String>Description of the object
host_provider: Option<String>Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret
item_custom_fields: Option<HashMap<String, String>>Additional custom fields to associate with the item
json: Option<bool>Set output format to JSON
key: Option<String>The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
max_versions: Option<String>Set the maximum number of versions, limited by the account settings defaults.
name: StringRotated secret name
password_length: Option<String>The length of the password to be generated
rotate_after_disconnect: Option<String>Rotate the value of the secret after SRA session ends [true/false]
rotated_password: Option<String>rotated-username password (relevant only for rotator-type=ldap)
rotated_username: Option<String>username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=ldap)
rotation_event_in: Option<Vec<String>>How many days before the rotation of the item would you like to be notified
rotation_hour: Option<i32>The Hour of the rotation in UTC
rotation_interval: Option<String>The number of days to wait between every automatic key rotation (1-365)
rotator_type: StringThe rotator type. options: [target/ldap]
secure_access_bastion_issuer: Option<String>Deprecated. use secure-access-certificate-issuer
secure_access_certificate_issuer: Option<String>Path to the SSH Certificate Issuer for your Akeyless Secure Access
secure_access_enable: Option<String>Enable/Disable secure remote access [true/false]
secure_access_host: Option<Vec<String>>Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)
secure_access_rdp_domain: Option<String>Default domain name server. i.e. microsoft.com
secure_access_url: Option<String>Destination URL to inject secrets
secure_access_web: Option<bool>Enable Web Secure Remote Access
secure_access_web_browsing: Option<bool>Secure browser via Akeyless’s Secure Remote Access (SRA)
secure_access_web_proxy: Option<bool>Web-Proxy via Akeyless’s Secure Remote Access (SRA)
Add tags attached to this object
target: Option<Vec<String>>A list of linked targets to be associated, Relevant only for Secure Remote Access for ssh cert issuer, ldap rotated secret and ldap dynamic secret, To specify multiple targets use argument multiple times
target_name: StringThe target name to associate
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
user_attribute: Option<String>LDAP User Attribute, Default value "cn"
user_dn: Option<String>Base DN to Perform User Search
Implementations