pub struct UpdateAccountSettings {Show 50 fields
pub address: Option<String>,
pub allowed_client_type: Option<Vec<String>>,
pub allowed_email_domains: Option<Vec<String>>,
pub bound_ips: Option<Vec<String>>,
pub city: Option<String>,
pub company_name: Option<String>,
pub country: Option<String>,
pub default_certificate_expiration_notification_days: Option<Vec<String>>,
pub default_key_name: Option<String>,
pub default_share_link_ttl_minutes: Option<String>,
pub default_versioning: Option<String>,
pub dp_enable_classic_key_protection: Option<String>,
pub dynamic_secret_max_ttl: Option<i64>,
pub dynamic_secret_max_ttl_enable: Option<String>,
pub enable_ai_insights: Option<String>,
pub enable_default_certificate_expiration_event: Option<String>,
pub enable_item_sharing: Option<String>,
pub enable_password_expiration: Option<String>,
pub force_new_versions: Option<String>,
pub gw_bound_ips: Option<Vec<String>>,
pub hide_personal_folder: Option<String>,
pub hide_static_password: Option<String>,
pub invalid_characters: Option<String>,
pub item_type: Option<String>,
pub items_deletion_protection: Option<String>,
pub json: Option<bool>,
pub jwt_ttl_default: Option<i64>,
pub jwt_ttl_max: Option<i64>,
pub jwt_ttl_min: Option<i64>,
pub lock_allowed_client_type: Option<String>,
pub lock_bound_ips: Option<String>,
pub lock_default_key: Option<String>,
pub lock_gw_bound_ips: Option<String>,
pub max_rotation_interval: Option<i32>,
pub max_rotation_interval_enable: Option<String>,
pub max_versions: Option<String>,
pub password_expiration_days: Option<String>,
pub password_expiration_notification_days: Option<String>,
pub password_length: Option<i64>,
pub phone: Option<String>,
pub postal_code: Option<String>,
pub token: Option<String>,
pub uid_token: Option<String>,
pub usage_event_enable: Option<String>,
pub usage_event_interval: Option<i64>,
pub usage_event_object_type: Option<String>,
pub use_capital_letters: Option<String>,
pub use_lower_letters: Option<String>,
pub use_numbers: Option<String>,
pub use_special_characters: Option<String>,
}Fields
address: Option<String>Address
allowed_client_type: Option<Vec<String>>A default list of client types that are allowed to authenticate [cli,ui,gateway-admin,sdk,mobile,extension].
allowed_email_domains: Option<Vec<String>>Limits email sharing to the specified domains. Relevant only when item sharing is enabled. By default, all domains are allowed.
bound_ips: Option<Vec<String>>A default list of comma-separated CIDR block that are allowed to authenticate.
city: Option<String>City
company_name: Option<String>Company name
country: Option<String>Country
default_certificate_expiration_notification_days: Option<Vec<String>>How many days before the expiration of the certificate would you like to be notified. To specify multiple events, use argument multiple times: –default-certificate-expiration-notification-days 1 –default-certificate-expiration-notification-days 5
default_key_name: Option<String>Set the account default key based on the DFC key name. Use "set-original-akeyless-default-key" to revert to using the original default key of the account.
Set the default ttl in minutes for sharing item number between 60 and 43200
default_versioning: Option<String>If set to true, new versions is enabled by default
dp_enable_classic_key_protection: Option<String>Set to update protection with classic keys state [true/false]
dynamic_secret_max_ttl: Option<i64>Set the maximum ttl for dynamic secrets
dynamic_secret_max_ttl_enable: Option<String>Set a maximum ttl for dynamic secrets [true/false]
enable_ai_insights: Option<String>Enable AI insights [true/false]
enable_default_certificate_expiration_event: Option<String>How many days before the expiration of the certificate would you like to be notified. [true/false]
enable_item_sharing: Option<String>Enable sharing items [true/false]
enable_password_expiration: Option<String>Enable password expiration policy [true/false]
force_new_versions: Option<String>If set to true, new version will be created on update
gw_bound_ips: Option<Vec<String>>A default list of comma-separated CIDR block that acts as a trusted Gateway entity.
hide_personal_folder: Option<String>Hide personal folder, if set - users will not be able to use personal folder [true/false]
hide_static_password: Option<String>Hide static secret’s password type [true/false]
invalid_characters: Option<String>Characters that cannot be used for items/targets/roles/auths/event_forwarder names. Empty string will enforce nothing.
item_type: Option<String>VersionSettingsObjectType defines object types for account version settings
items_deletion_protection: Option<String>Set or unset the default behaviour of items deletion protection [true/false]
json: Option<bool>Set output format to JSON
jwt_ttl_default: Option<i64>Default ttl
jwt_ttl_max: Option<i64>Maximum ttl
jwt_ttl_min: Option<i64>Minimum ttl
lock_allowed_client_type: Option<String>Lock allowed-client-type setting in the account [true/false].
lock_bound_ips: Option<String>Lock bound-ips setting globally in the account.
lock_default_key: Option<String>Lock the account’s default protection key, if set - users will not be able to use a different protection key, relevant only if default-key-name is configured [true/false]
lock_gw_bound_ips: Option<String>Lock gw-bound-ips setting in the account.
max_rotation_interval: Option<i32>Set the maximum rotation interval for rotated secrets auto rotation settings
max_rotation_interval_enable: Option<String>Set a maximum rotation interval for rotated secrets auto rotation settings [true/false]
max_versions: Option<String>Max versions
password_expiration_days: Option<String>Specifies the number of days that a password is valid before it must be changed. A default value of 90 days is used.
password_expiration_notification_days: Option<String>Specifies the number of days before a user receives notification that their password will expire. A default value of 14 days is used.
password_length: Option<i64>Password length between 5 - to 50 characters
phone: Option<String>Phone number
postal_code: Option<String>Postal code
token: Option<String>Authentication token (see /auth and /configure)
uid_token: Option<String>The universal identity token, Required only for universal_identity authentication
usage_event_enable: Option<String>Enable event for objects that have not been used or changed [true/false]
usage_event_interval: Option<i64>Interval by days for unused objects. Default and minimum interval is 90 days
usage_event_object_type: Option<String>Usage event is supported for auth method or secrets-and-keys [auth/item]
use_capital_letters: Option<String>Password must contain capital letters [true/false]
use_lower_letters: Option<String>Password must contain lower case letters [true/false]
use_numbers: Option<String>Password must contain numbers [true/false]
use_special_characters: Option<String>Password must contain special characters [true/false]
Implementations
Sourceimpl UpdateAccountSettings
impl UpdateAccountSettings
pub fn new() -> UpdateAccountSettings