Structs
- Update
Auth Method Azure Ad - UpdateAuthMethodAzureAd : updateAuthMethodAzureAD is a command that updates a new auth method that will be able to authenticate using Azure Active Directory credentials. [Deprecated: Use auth-method-update-azure-ad command]