Structs
- Update
Auth Method Universal Identity - UpdateAuthMethodUniversalIdentity : updateAuthMethodUniversalIdentity is a command that updates a new auth method that will be able to authenticate using Akeyless Universal Identity. [Deprecated: Use auth-method-update-universal-identity command]